@@ -32,7 +32,8 @@ import (
 	agentapi "isc.org/stork/api"
 	bind9config "isc.org/stork/daemoncfg/bind9"
 	keactrl "isc.org/stork/daemonctrl/kea"
-	"isc.org/stork/daemondata/bind9stats"
+	"isc.org/stork/datamodel/daemonname"
+	dnsmodel "isc.org/stork/datamodel/dns"
 	"isc.org/stork/pki"
 	storkutil "isc.org/stork/util"
 )
@@ -57,22 +58,29 @@ type StorkAgent struct {
 	shutdownOnce        sync.Once
 	hookManager         *HookManager
 
+	// Permit the agent run the Lease Tracking code.
+	isLeaseTrackingAllowed bool
+	// Limit the maximum number of leases that each daemon will retain in memory.
+	maxLeaseUpdateCount int
+
 	agentapi.UnimplementedAgentServer
 }
 
 // API exposed to Stork Server.
-func NewStorkAgent(host string, port int, monitor Monitor, bind9StatsClient *bind9StatsClient, hookManager *HookManager) *StorkAgent {
+func NewStorkAgent(host string, port int, monitor Monitor, bind9StatsClient *bind9StatsClient, hookManager *HookManager, allowLeaseTracking bool, maxLeaseUpdateCount int) *StorkAgent {
 	logTailer := newLogTailer()
 
 	sa := &StorkAgent{
-		Host:             host,
-		Port:             port,
-		Monitor:          monitor,
-		bind9StatsClient: bind9StatsClient,
-		pdnsClient:       newPDNSClient(),
-		logTailer:        logTailer,
-		keaInterceptor:   newKeaInterceptor(),
-		hookManager:      hookManager,
+		Host:                   host,
+		Port:                   port,
+		Monitor:                monitor,
+		bind9StatsClient:       bind9StatsClient,
+		pdnsClient:             newPDNSClient(),
+		logTailer:              logTailer,
+		keaInterceptor:         newKeaInterceptor(),
+		hookManager:            hookManager,
+		isLeaseTrackingAllowed: allowLeaseTracking,
+		maxLeaseUpdateCount:    maxLeaseUpdateCount,
 	}
 
 	registerKeaInterceptFns(sa)
@@ -80,6 +88,15 @@ func NewStorkAgent(host string, port int, monitor Monitor, bind9StatsClient *bin
 	return sa
 }
 
+// Return whether Lease Tracking is allowed. The boolean return value is true
+// if Lease Tracking is allowed, and false if it isn't. If the boolean return
+// value is true, the integer return value indicates the maximum number of
+// lease updates that any one keaDaemon can retain in memory. The meaning of the
+// integer return value is unspecified when the boolean is false.
+func (sa *StorkAgent) allowLeaseTracking() (bool, int) {
+	return sa.isLeaseTrackingAllowed, sa.maxLeaseUpdateCount
+}
+
 // Creates the GRPC server callback using the provided cert store. The callback
 // returns the root CA on demand.
 func createGetRootCertificatesHandler(certStore *CertStore) func(*advancedtls.ConnectionInfo) (*advancedtls.RootCertificates, error) {
@@ -235,7 +252,19 @@ func (sa *StorkAgent) GetState(ctx context.Context, in *agentapi.GetStateReq) (*
 
 	for _, daemon := range sa.Monitor.GetDaemons() {
 		var accessPoints []*agentapi.AccessPoint
+		accessPointTypes := map[string]struct{}{}
+		// TODO: Handle multiple access points on the server side.
+		// The server expects only one access point with a given type per daemon.
+		// This rule is enforced by the database constraints, so handling it
+		// requires deep changes in the server code. For now, we share only the
+		// first access point for the daemon and use other quietly.
+		// See #2237.
 		for _, point := range daemon.GetAccessPoints() {
+			if _, ok := accessPointTypes[point.Type]; ok {
+				continue
+			}
+			accessPointTypes[point.Type] = struct{}{}
+
 			accessPoints = append(accessPoints, &agentapi.AccessPoint{
 				Type:              point.Type,
 				Address:           point.Address,
@@ -682,10 +711,26 @@ func (sa *StorkAgent) ReceiveZones(req *agentapi.ReceiveZonesReq, server grpc.Se
 		// zone inventory initialized.
 		return status.New(codes.FailedPrecondition, "attempted to receive DNS zones from a daemon for which zone inventory was not instantiated").Err()
 	}
+
+	if req.ForcePopulate {
+		// Refresh the zone inventory if requested by the Stork server. This
+		// operation will block until the zone inventory is populated.
+		ch, err := inventory.populate(true)
+		if err != nil {
+			return status.Error(codes.Internal, err.Error())
+		}
+		if ch != nil {
+			s := <-ch
+			if s.err != nil {
+				return status.Error(codes.Internal, s.err.Error())
+			}
+		}
+	}
+
 	// Set filtering rules based on the request.
-	var filter *bind9stats.ZoneFilter
+	var filter *dnsmodel.ZoneFilter
 	if req.ViewName != "" || req.Limit > 0 || req.LoadedAfter > 0 || req.LowerBound != "" {
-		filter = bind9stats.NewZoneFilter()
+		filter = dnsmodel.NewZoneFilter()
 		if req.ViewName != "" {
 			filter.SetView(req.ViewName)
 		}
@@ -903,6 +948,39 @@ func (sa *StorkAgent) ReceiveBind9Config(req *agentapi.ReceiveBind9ConfigReq, se
 	return
 }
 
+// Stream a point-in-time snapshot of all the active leases that all monitored
+// Kea daemons know about.
+func (sa *StorkAgent) ReceiveKeaLeases(req *agentapi.ReceiveKeaLeasesReq, server grpc.ServerStreamingServer[agentapi.ReceiveKeaLeasesRsp]) error {
+	if !sa.isLeaseTrackingAllowed {
+		return errors.New("This feature is not enabled. Pass `--enable-lease-tracking` or set `STORK_AGENT_ENABLE_LEASE_TRACKING` when starting the agent.")
+	}
+	daemons := sa.Monitor.GetDaemons()
+	for _, daemon := range daemons {
+		name := daemon.GetName()
+		switch name {
+		case daemonname.DHCPv4, daemonname.DHCPv6:
+			keadaemon, ok := daemon.(*keaDaemon)
+			if !ok {
+				log.Warn("Answering GetKeaLeases; found a daemon with DHCP daemonname, but which could not be cast to keaDaemon")
+				continue
+			}
+			leases := keadaemon.GetLeaseSnapshot()
+			for _, lease := range leases {
+				grpcLease := lease.ToGRPC()
+				err := server.Send(&agentapi.ReceiveKeaLeasesRsp{
+					Lease: &grpcLease,
+				})
+				if err != nil {
+					return err
+				}
+			}
+		default:
+			continue
+		}
+	}
+	return nil
+}
+
 // Starts the gRPC and HTTP listeners.
 func (sa *StorkAgent) Serve() error {
 	// Install gRPC API handlers.
