@@ -2,21 +2,160 @@ package agent
 
 import (
 	"fmt"
+	"os"
 	"path"
+	"path/filepath"
 	"strings"
 	"testing"
+	"time"
 
 	"github.com/pkg/errors"
 	"github.com/stretchr/testify/require"
 	gomock "go.uber.org/mock/gomock"
 	bind9config "isc.org/stork/daemoncfg/bind9"
 	"isc.org/stork/datamodel/daemonname"
+	"isc.org/stork/datamodel/protocoltype"
 	"isc.org/stork/testutil"
 	storkutil "isc.org/stork/util"
 )
 
+var _ = (os.FileInfo)((*testFileInfo)(nil))
+
 //go:generate mockgen -package=agent -destination=bind9mock_test.go -mock_names=bind9FileParser=MockBind9FileParser,zoneInventory=MockZoneInventory isc.org/stork/agent bind9FileParser,zoneInventory
 
+// Test that the function correctly checks if two BIND 9 daemons are the same.
+// Note that it is not checking them for equality. It merely checks if they
+// represent the same daemon in terms of their name, access points, and detected
+// files.
+func TestBind9DaemonIsSame(t *testing.T) {
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+
+	executor := NewMockCommandExecutor(ctrl)
+	executor.EXPECT().GetFileInfo("/etc/bind/named.conf").AnyTimes().Return(&testFileInfo{}, nil)
+
+	detectedFiles := newDetectedDaemonFiles("", "")
+	err := detectedFiles.addFile(detectedFileTypeConfig, "/etc/bind/named.conf", executor)
+	require.NoError(t, err)
+
+	comparedDaemon := &Bind9Daemon{
+		dnsDaemonImpl: dnsDaemonImpl{
+			daemon: daemon{
+				Name: daemonname.Bind9,
+				AccessPoints: []AccessPoint{
+					{
+						Type:     AccessPointControl,
+						Address:  "127.0.0.1",
+						Port:     8081,
+						Protocol: protocoltype.HTTP,
+					},
+				},
+			},
+			detectedFiles: detectedFiles,
+		},
+	}
+
+	t.Run("same daemon", func(t *testing.T) {
+		otherDaemon := &Bind9Daemon{
+			dnsDaemonImpl: dnsDaemonImpl{
+				daemon: daemon{
+					Name: daemonname.Bind9,
+					AccessPoints: []AccessPoint{
+						{
+							Type:     AccessPointControl,
+							Address:  "127.0.0.1",
+							Port:     8081,
+							Protocol: protocoltype.HTTP,
+						},
+					},
+				},
+				detectedFiles: detectedFiles,
+			},
+		}
+		require.True(t, comparedDaemon.IsSame(otherDaemon))
+	})
+
+	t.Run("different daemon name", func(t *testing.T) {
+		otherDaemon := &Bind9Daemon{
+			dnsDaemonImpl: dnsDaemonImpl{
+				daemon: daemon{
+					Name: daemonname.PDNS,
+					AccessPoints: []AccessPoint{
+						{
+							Type:     AccessPointControl,
+							Address:  "127.0.0.1",
+							Port:     8081,
+							Protocol: protocoltype.HTTP,
+						},
+					},
+				},
+				detectedFiles: detectedFiles,
+			},
+		}
+		require.False(t, comparedDaemon.IsSame(otherDaemon))
+	})
+
+	t.Run("different access points", func(t *testing.T) {
+		otherDaemon := &Bind9Daemon{
+			dnsDaemonImpl: dnsDaemonImpl{
+				daemon: daemon{
+					Name: daemonname.Bind9,
+					AccessPoints: []AccessPoint{
+						{
+							Type:     AccessPointControl,
+							Address:  "127.0.0.1",
+							Port:     8082,
+							Protocol: protocoltype.HTTP,
+						},
+					},
+				},
+				detectedFiles: detectedFiles,
+			},
+		}
+		require.False(t, comparedDaemon.IsSame(otherDaemon))
+	})
+
+	t.Run("different detected files", func(t *testing.T) {
+		otherDaemon := &Bind9Daemon{
+			dnsDaemonImpl: dnsDaemonImpl{
+				daemon: daemon{
+					Name: daemonname.Bind9,
+					AccessPoints: []AccessPoint{
+						{
+							Type:     AccessPointControl,
+							Address:  "127.0.0.1",
+							Port:     8081,
+							Protocol: protocoltype.HTTP,
+						},
+					},
+				},
+				detectedFiles: nil,
+			},
+		}
+		require.False(t, comparedDaemon.IsSame(otherDaemon))
+	})
+
+	t.Run("not a BIND 9 daemon", func(t *testing.T) {
+		otherDaemon := &pdnsDaemon{
+			dnsDaemonImpl: dnsDaemonImpl{
+				daemon: daemon{
+					Name: daemonname.Bind9,
+					AccessPoints: []AccessPoint{
+						{
+							Type:     AccessPointControl,
+							Address:  "127.0.0.1",
+							Port:     8081,
+							Protocol: protocoltype.HTTP,
+						},
+					},
+				},
+				detectedFiles: detectedFiles,
+			},
+		}
+		require.False(t, comparedDaemon.IsSame(otherDaemon))
+	})
+}
+
 // Test the state is refreshed properly. It should fetch the zone inventory
 // data.
 func TestBind9RefreshState(t *testing.T) {
@@ -142,6 +281,42 @@ threads support is enabled`
 	require.Equal(t, "", namedConf)
 }
 
+// A mock implementation of the os.FileInfo interface for the testing purposes.
+type testFileInfo struct {
+	size    int64
+	modTime time.Time
+}
+
+// Returns empty file name.
+func (t *testFileInfo) Name() string {
+	return ""
+}
+
+// Returns false indicating that the file is not a directory.
+func (t *testFileInfo) IsDir() bool {
+	return false
+}
+
+// Returns 0 as a file mode.
+func (t *testFileInfo) Mode() os.FileMode {
+	return 0
+}
+
+// Returns configured modification time of the file.
+func (t *testFileInfo) ModTime() time.Time {
+	return t.modTime
+}
+
+// Returns configured size of the file.
+func (t *testFileInfo) Size() int64 {
+	return t.size
+}
+
+// Returns nil as the system interface is not implemented.
+func (t *testFileInfo) Sys() any {
+	return nil
+}
+
 // The command executor implementation for the testing purposes.
 // It implements the builder pattern for the configuration methods.
 type testCommandExecutor struct {
@@ -149,6 +324,7 @@ type testCommandExecutor struct {
 	checkConfOutputs        map[string]string
 	rndcStatusError         error
 	rndcStatus              string
+	fileInfos               map[string]os.FileInfo
 }
 
 // Constructs a new instance of the test command executor.
@@ -156,6 +332,7 @@ func newTestCommandExecutor() *testCommandExecutor {
 	return &testCommandExecutor{
 		checkConfOutputs: map[string]string{},
 		rndcStatus:       "Server is up and running",
+		fileInfos:        map[string]os.FileInfo{},
 	}
 }
 
@@ -261,6 +438,21 @@ func (e *testCommandExecutor) IsFileExist(path string) bool {
 	return false
 }
 
+// Adds file information for a given path.
+func (e *testCommandExecutor) addFileInfo(path string, info os.FileInfo) *testCommandExecutor {
+	e.fileInfos[path] = info
+	return e
+}
+
+// Returns file information for a given path.
+func (e *testCommandExecutor) GetFileInfo(path string) (os.FileInfo, error) {
+	info, ok := e.fileInfos[path]
+	if !ok {
+		return nil, errors.New("file not found")
+	}
+	return info, nil
+}
+
 // Checks detection STEP 1: if BIND9 detection takes -c parameter into consideration.
 func TestDetectBind9Step1ProcessCmdLine(t *testing.T) {
 	// Create alternate config files for each step.
@@ -273,8 +465,10 @@ func TestDetectBind9Step1ProcessCmdLine(t *testing.T) {
 	require.NoError(t, err)
 
 	// Check BIND 9 daemon detection.
-	executor := newTestCommandExecutor().
-		addCheckConfOutput(config1Path, config1)
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addCheckConfOutput(config1Path, config1).
+		addFileInfo(config1Path, &testFileInfo{})
 
 	// Now run the detection as usual.
 	ctrl := gomock.NewController(t)
@@ -283,18 +477,17 @@ func TestDetectBind9Step1ProcessCmdLine(t *testing.T) {
 	absolutePath := path.Join(sandbox.BasePath, "named")
 	process.EXPECT().getCmdline().Return(fmt.Sprintf("%s -c %s", absolutePath, config1Path), nil)
 	process.EXPECT().getCwd().Return("", nil)
-	process.EXPECT().getPid().Return(int32(1234))
-	daemon, err := detectBind9Daemon(process, executor, "", bind9config.NewParser())
+
+	detectedFiles, err := monitor.detectBind9ConfigPaths(process)
 	require.NoError(t, err)
-	require.NotNil(t, daemon)
-	require.Equal(t, daemonname.Bind9, daemon.GetName())
-	require.Len(t, daemon.GetAccessPoints(), 1)
-	point := daemon.GetAccessPoints()[0]
-	require.Equal(t, AccessPointControl, point.Type)
-	require.Equal(t, "1.1.1.1", point.Address)
-	require.EqualValues(t, 1111, point.Port)
-	require.EqualValues(t, "foo:hmac-sha256:abcd", point.Key)
-	require.EqualValues(t, 1234, daemon.(*Bind9Daemon).pid)
+	require.NotNil(t, detectedFiles)
+	require.Len(t, detectedFiles.files, 1)
+
+	require.Equal(t, config1Path, detectedFiles.getFirstFilePathByType(detectedFileTypeConfig))
+	require.Empty(t, detectedFiles.getFirstFilePathByType(detectedFileTypeRndcKey))
+	require.Empty(t, detectedFiles.chrootDir)
+	expectedBaseDir, _ := filepath.Split(sandbox.BasePath)
+	require.Equal(t, filepath.Clean(expectedBaseDir), detectedFiles.baseDir)
 }
 
 // Checks detection with chroot STEP 1: if BIND9 detection takes -c parameter
@@ -311,8 +504,10 @@ func TestDetectBind9ChrootStep1ProcessCmdLine(t *testing.T) {
 	require.NoError(t, err)
 
 	// Check BIND 9 daemon detection.
-	executor := newTestCommandExecutor().
-		addCheckConfOutput(path.Join(chrootPath, config1Path), config1)
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addCheckConfOutput(path.Join(chrootPath, config1Path), config1).
+		addFileInfo(path.Join(chrootPath, config1Path), &testFileInfo{})
 
 	// Now run the detection as usual.
 	ctrl := gomock.NewController(t)
@@ -321,17 +516,17 @@ func TestDetectBind9ChrootStep1ProcessCmdLine(t *testing.T) {
 	absolutePath := path.Join(sandbox.BasePath, "named")
 	process.EXPECT().getCmdline().Return(fmt.Sprintf("%s -t %s -c %s", absolutePath, chrootPath, config1Path), nil)
 	process.EXPECT().getCwd().Return("", nil)
-	process.EXPECT().getPid().Return(int32(1234))
-	daemon, err := detectBind9Daemon(process, executor, "", bind9config.NewParser())
+	detectedFiles, err := monitor.detectBind9ConfigPaths(process)
 	require.NoError(t, err)
-	require.NotNil(t, daemon)
-	require.Equal(t, daemonname.Bind9, daemon.GetName())
-	require.Len(t, daemon.GetAccessPoints(), 1)
-	point := daemon.GetAccessPoints()[0]
-	require.Equal(t, AccessPointControl, point.Type)
-	require.Equal(t, "1.1.1.1", point.Address)
-	require.EqualValues(t, 1111, point.Port)
-	require.EqualValues(t, "foo:hmac-sha256:abcd", point.Key)
+	require.NotNil(t, detectedFiles)
+	require.Len(t, detectedFiles.files, 1)
+	path := detectedFiles.getFirstFilePathByType(detectedFileTypeConfig)
+	require.Equal(t, config1Path, path)
+	rndcKeyPath := detectedFiles.getFirstFilePathByType(detectedFileTypeRndcKey)
+	require.Empty(t, rndcKeyPath)
+	require.Equal(t, chrootPath, detectedFiles.chrootDir)
+	expectedBaseDir, _ := filepath.Split(sandbox.BasePath)
+	require.Equal(t, filepath.Clean(expectedBaseDir), detectedFiles.baseDir)
 }
 
 // Checks detection STEP 2: if BIND9 detection takes the explicit config path
@@ -352,8 +547,10 @@ func TestDetectBind9Step2ExplicitPath(t *testing.T) {
 	require.NoError(t, err)
 
 	// Check BIND 9 daemon detection.
-	executor := newTestCommandExecutor().
-		addCheckConfOutput(confPath, config)
+	monitor := newMonitor(confPath, "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addCheckConfOutput(confPath, config).
+		addFileInfo(confPath, &testFileInfo{})
 
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -361,17 +558,17 @@ func TestDetectBind9Step2ExplicitPath(t *testing.T) {
 	absolutePath := path.Join(sandbox.BasePath, "usr", "sbin", "named")
 	process.EXPECT().getCmdline().Return(fmt.Sprintf("%s -some -params", absolutePath), nil)
 	process.EXPECT().getCwd().Return("", nil)
-	process.EXPECT().getPid().Return(int32(1234))
-	daemon, err := detectBind9Daemon(process, executor, confPath, bind9config.NewParser())
+
+	detectedFiles, err := monitor.detectBind9ConfigPaths(process)
 	require.NoError(t, err)
-	require.NotNil(t, daemon)
-	require.Equal(t, daemonname.Bind9, daemon.GetName())
-	require.Len(t, daemon.GetAccessPoints(), 1)
-	point := daemon.GetAccessPoints()[0]
-	require.Equal(t, AccessPointControl, point.Type)
-	require.Equal(t, "192.0.2.1", point.Address)
-	require.EqualValues(t, 1234, point.Port)
-	require.EqualValues(t, "foo:hmac-sha256:abcd", point.Key)
+	require.NotNil(t, detectedFiles)
+	require.Len(t, detectedFiles.files, 1)
+	path := detectedFiles.getFirstFilePathByType(detectedFileTypeConfig)
+	require.Equal(t, confPath, path)
+	rndcKeyPath := detectedFiles.getFirstFilePathByType(detectedFileTypeRndcKey)
+	require.Empty(t, rndcKeyPath)
+	require.Empty(t, detectedFiles.chrootDir)
+	require.Equal(t, sandbox.BasePath+"/usr", detectedFiles.baseDir)
 }
 
 // Checks detection with chroot STEP 2: if BIND9 detection takes
@@ -394,8 +591,10 @@ func TestDetectBind9ChrootStep2ExplicitPath(t *testing.T) {
 	require.NoError(t, err)
 
 	// Check BIND 9 daemon detection.
-	executor := newTestCommandExecutor().
-		addCheckConfOutput(fullConfPath, config)
+	monitor := newMonitor(fullConfPath, "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addCheckConfOutput(fullConfPath, config).
+		addFileInfo(fullConfPath, &testFileInfo{})
 
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -403,17 +602,18 @@ func TestDetectBind9ChrootStep2ExplicitPath(t *testing.T) {
 	absolutePath := path.Join(sandbox.BasePath, "named")
 	process.EXPECT().getCmdline().Return(fmt.Sprintf("%s -t %s -some -params", absolutePath, chrootPath), nil)
 	process.EXPECT().getCwd().Return("", nil)
-	process.EXPECT().getPid().Return(int32(1234))
-	daemon, err := detectBind9Daemon(process, executor, fullConfPath, bind9config.NewParser())
+
+	detectedFiles, err := monitor.detectBind9ConfigPaths(process)
 	require.NoError(t, err)
-	require.NotNil(t, daemon)
-	require.Equal(t, daemonname.Bind9, daemon.GetName())
-	require.Len(t, daemon.GetAccessPoints(), 1)
-	point := daemon.GetAccessPoints()[0]
-	require.Equal(t, AccessPointControl, point.Type)
-	require.Equal(t, "192.0.2.1", point.Address)
-	require.EqualValues(t, 1234, point.Port)
-	require.EqualValues(t, "foo:hmac-sha256:abcd", point.Key)
+	require.NotNil(t, detectedFiles)
+	require.Len(t, detectedFiles.files, 1)
+	path := detectedFiles.getFirstFilePathByType(detectedFileTypeConfig)
+	require.Equal(t, confPath, path)
+	rndcKeyPath := detectedFiles.getFirstFilePathByType(detectedFileTypeRndcKey)
+	require.Empty(t, rndcKeyPath)
+	require.Equal(t, chrootPath, detectedFiles.chrootDir)
+	expectedBaseDir, _ := filepath.Split(sandbox.BasePath)
+	require.Equal(t, filepath.Clean(expectedBaseDir), detectedFiles.baseDir)
 }
 
 // Checks detection with chroot STEP 2: the explicit config path must be
@@ -436,8 +636,10 @@ func TestDetectBind9ChrootStep2ExplicitPathNotPrefixed(t *testing.T) {
 	require.NoError(t, err)
 
 	// Check BIND 9 daemon detection.
-	executor := newTestCommandExecutor().
-		addCheckConfOutput(fullConfPath, config)
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addCheckConfOutput(fullConfPath, config).
+		addFileInfo(fullConfPath, &testFileInfo{})
 
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -445,9 +647,9 @@ func TestDetectBind9ChrootStep2ExplicitPathNotPrefixed(t *testing.T) {
 	absolutePath := path.Join(sandbox.BasePath, "named")
 	process.EXPECT().getCmdline().Return(fmt.Sprintf("%s -t %s -some -params", absolutePath, chrootPath), nil)
 	process.EXPECT().getCwd().Return("", nil)
-	daemon, err := detectBind9Daemon(process, executor, confPath, bind9config.NewParser())
-	require.ErrorContains(t, err, "cannot find config file for BIND 9")
-	require.Nil(t, daemon)
+	detectedFiles, err := monitor.detectBind9ConfigPaths(process)
+	require.ErrorContains(t, err, "BIND 9 config file not found")
+	require.Nil(t, detectedFiles)
 }
 
 // Checks detection STEP 3: parse output of the named -V command.
@@ -467,9 +669,11 @@ func TestDetectBind9Step3BindVOutput(t *testing.T) {
 	require.NoError(t, err)
 
 	// ... and tell the fake executor to return it as the output of named -V.
-	executor := newTestCommandExecutor().
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
 		addCheckConfOutput(varPath, config).
-		setConfigPathInNamedOutput(varPath)
+		setConfigPathInNamedOutput(varPath).
+		addFileInfo(varPath, &testFileInfo{})
 
 	// Now run the detection as usual.
 	ctrl := gomock.NewController(t)
@@ -478,17 +682,17 @@ func TestDetectBind9Step3BindVOutput(t *testing.T) {
 	absolutePath := path.Join(sandbox.BasePath, "named")
 	process.EXPECT().getCmdline().Return(fmt.Sprintf("%s -some -params", absolutePath), nil)
 	process.EXPECT().getCwd().Return("", nil)
-	process.EXPECT().getPid().Return(int32(1234))
-	daemon, err := detectBind9Daemon(process, executor, "", bind9config.NewParser())
+	detectedFiles, err := monitor.detectBind9ConfigPaths(process)
 	require.NoError(t, err)
-	require.NotNil(t, daemon)
-	require.Equal(t, daemonname.Bind9, daemon.GetName())
-	require.Len(t, daemon.GetAccessPoints(), 1)
-	point := daemon.GetAccessPoints()[0]
-	require.Equal(t, AccessPointControl, point.Type)
-	require.Equal(t, "192.0.2.1", point.Address)
-	require.EqualValues(t, 1234, point.Port)
-	require.EqualValues(t, "foo:hmac-sha256:abcd", point.Key)
+	require.NotNil(t, detectedFiles)
+	require.Len(t, detectedFiles.files, 1)
+	path := detectedFiles.getFirstFilePathByType(detectedFileTypeConfig)
+	require.Equal(t, varPath, path)
+	rndcKeyPath := detectedFiles.getFirstFilePathByType(detectedFileTypeRndcKey)
+	require.Empty(t, rndcKeyPath)
+	require.Empty(t, detectedFiles.chrootDir)
+	expectedBaseDir, _ := filepath.Split(sandbox.BasePath)
+	require.Equal(t, filepath.Clean(expectedBaseDir), detectedFiles.baseDir)
 }
 
 // Checks detection with chroot STEP 3: parse output of the named -V command.
@@ -509,10 +713,12 @@ func TestDetectBind9ChrootStep3BindVOutput(t *testing.T) {
 	require.NoError(t, err)
 
 	// ... and tell the fake executor to return it as the output of named -V.
-	executor := newTestCommandExecutor().
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
 		addCheckConfOutput(path.Join(chrootPath, varPath), config).
 		// The named -V returns the path relative to the chroot directory.
-		setConfigPathInNamedOutput(varPath)
+		setConfigPathInNamedOutput(varPath).
+		addFileInfo(path.Join(chrootPath, varPath), &testFileInfo{})
 
 	// Now run the detection as usual.
 	ctrl := gomock.NewController(t)
@@ -521,17 +727,16 @@ func TestDetectBind9ChrootStep3BindVOutput(t *testing.T) {
 	absolutePath := path.Join(sandbox.BasePath, "named")
 	process.EXPECT().getCmdline().Return(fmt.Sprintf("%s -t %s -some -params", absolutePath, chrootPath), nil)
 	process.EXPECT().getCwd().Return("", nil)
-	process.EXPECT().getPid().Return(int32(1234))
-	daemon, err := detectBind9Daemon(process, executor, "", bind9config.NewParser())
+
+	detectedFiles, err := monitor.detectBind9ConfigPaths(process)
 	require.NoError(t, err)
-	require.NotNil(t, daemon)
-	require.Equal(t, daemonname.Bind9, daemon.GetName())
-	require.Len(t, daemon.GetAccessPoints(), 1)
-	point := daemon.GetAccessPoints()[0]
-	require.Equal(t, AccessPointControl, point.Type)
-	require.Equal(t, "192.0.2.1", point.Address)
-	require.EqualValues(t, 1234, point.Port)
-	require.EqualValues(t, "foo:hmac-sha256:abcd", point.Key)
+	require.NotNil(t, detectedFiles)
+	require.Len(t, detectedFiles.files, 1)
+	require.Equal(t, varPath, detectedFiles.getFirstFilePathByType(detectedFileTypeConfig))
+	require.Empty(t, detectedFiles.getFirstFilePathByType(detectedFileTypeRndcKey))
+	require.Equal(t, chrootPath, detectedFiles.chrootDir)
+	expectedBaseDir, _ := filepath.Split(sandbox.BasePath)
+	require.Equal(t, filepath.Clean(expectedBaseDir), detectedFiles.baseDir)
 }
 
 // Checks detection STEP 4: look at the typical locations.
@@ -549,44 +754,40 @@ func TestDetectBind9Step4TypicalLocations(t *testing.T) {
 	_, err := sandbox.Write("testing.conf", config)
 	require.NoError(t, err)
 
-	executor := newTestCommandExecutor()
-
 	for _, expectedPath := range getPotentialNamedConfLocations() {
 		// getPotentialNamedConfLocations now returns dirs, need to append
 		// filename.
 		expectedConfigPath := path.Join(expectedPath, "named.conf")
 
-		executor.
+		monitor := newMonitor("", "", HTTPClientConfig{})
+		monitor.commander = newTestCommandExecutor().
 			clear().
 			addCheckConfOutput(expectedConfigPath, config).
-			setConfigPathInNamedOutput(expectedConfigPath)
+			setConfigPathInNamedOutput(expectedConfigPath).
+			addFileInfo(expectedConfigPath, &testFileInfo{})
 
 		t.Run(expectedConfigPath, func(t *testing.T) {
 			ctrl := gomock.NewController(t)
 			defer ctrl.Finish()
-			parser := NewMockBind9FileParser(ctrl)
-			parser.EXPECT().ParseFile(expectedConfigPath, "").DoAndReturn(func(configPath, rootPath string) (*bind9config.Config, error) {
-				return bind9config.NewParser().ParseFile(path.Join(sandbox.BasePath, "testing.conf"), "")
-			})
 
 			// Act
 			process := NewMockSupportedProcess(ctrl)
 			absolutePath := path.Join(sandbox.BasePath, "named")
 			process.EXPECT().getCmdline().Return(fmt.Sprintf("%s -some -params", absolutePath), nil)
 			process.EXPECT().getCwd().Return("", nil)
-			process.EXPECT().getPid().Return(int32(1234))
-			daemon, err := detectBind9Daemon(process, executor, "", parser)
+			detectedFiles, err := monitor.detectBind9ConfigPaths(process)
 
 			// Assert
 			require.NoError(t, err)
-			require.NotNil(t, daemon)
-			require.Equal(t, daemonname.Bind9, daemon.GetName())
-			require.Len(t, daemon.GetAccessPoints(), 1)
-			point := daemon.GetAccessPoints()[0]
-			require.Equal(t, AccessPointControl, point.Type)
-			require.Equal(t, "192.0.2.1", point.Address)
-			require.EqualValues(t, 1234, point.Port)
-			require.EqualValues(t, "foo:hmac-sha256:abcd", point.Key)
+			require.NotNil(t, detectedFiles)
+			require.Len(t, detectedFiles.files, 1)
+			path := detectedFiles.getFirstFilePathByType(detectedFileTypeConfig)
+			require.Equal(t, expectedConfigPath, path)
+			rndcKeyPath := detectedFiles.getFirstFilePathByType(detectedFileTypeRndcKey)
+			require.Empty(t, rndcKeyPath)
+			require.Empty(t, detectedFiles.chrootDir)
+			expectedBaseDir, _ := filepath.Split(sandbox.BasePath)
+			require.Equal(t, filepath.Clean(expectedBaseDir), detectedFiles.baseDir)
 		})
 	}
 }
@@ -606,52 +807,377 @@ func TestDetectBind9ChrootStep4TypicalLocations(t *testing.T) {
 	_, err := sandbox.Write("chroot/testing.conf", config)
 	require.NoError(t, err)
 
-	executor := newTestCommandExecutor()
 	chrootPath := path.Join(sandbox.BasePath, "chroot")
 	for _, expectedPath := range getPotentialNamedConfLocations() {
 		expectedConfigPath := path.Join(expectedPath, "named.conf")
-		executor.
+		monitor := newMonitor("", "", HTTPClientConfig{})
+		monitor.commander = newTestCommandExecutor().
 			clear().
 			addCheckConfOutput(path.Join(chrootPath, expectedConfigPath), config).
-			setConfigPathInNamedOutput(expectedConfigPath)
+			setConfigPathInNamedOutput(expectedConfigPath).
+			addFileInfo(path.Join(chrootPath, expectedConfigPath), &testFileInfo{})
 
 		t.Run(expectedPath, func(t *testing.T) {
 			ctrl := gomock.NewController(t)
 			defer ctrl.Finish()
-			parser := NewMockBind9FileParser(ctrl)
-			parser.EXPECT().ParseFile(expectedConfigPath, chrootPath).DoAndReturn(func(configPath, rootPath string) (*bind9config.Config, error) {
-				return bind9config.NewParser().ParseFile("testing.conf", rootPath)
-			})
 
 			// Act
 			process := NewMockSupportedProcess(ctrl)
 			absolutePath := path.Join(sandbox.BasePath, "named")
 			process.EXPECT().getCmdline().Return(fmt.Sprintf("%s -t %s -some -params", absolutePath, chrootPath), nil)
 			process.EXPECT().getCwd().Return("", nil)
-			process.EXPECT().getPid().Return(int32(1234))
-			daemon, err := detectBind9Daemon(process, executor, "", parser)
+			detectedFiles, err := monitor.detectBind9ConfigPaths(process)
 
 			// Assert
 			require.NoError(t, err)
-			require.NotNil(t, daemon)
-			require.Equal(t, daemonname.Bind9, daemon.GetName())
-			require.Len(t, daemon.GetAccessPoints(), 1)
-			point := daemon.GetAccessPoints()[0]
-			require.Equal(t, AccessPointControl, point.Type)
-			require.Equal(t, "192.0.2.1", point.Address)
-			require.EqualValues(t, 1234, point.Port)
-			require.EqualValues(t, "foo:hmac-sha256:abcd", point.Key)
+			require.NotNil(t, detectedFiles)
+			require.Len(t, detectedFiles.files, 1)
+			path := detectedFiles.getFirstFilePathByType(detectedFileTypeConfig)
+			require.Equal(t, expectedConfigPath, path)
+			rndcKeyPath := detectedFiles.getFirstFilePathByType(detectedFileTypeRndcKey)
+			require.Empty(t, rndcKeyPath)
+			require.Equal(t, chrootPath, detectedFiles.chrootDir)
+			expectedBaseDir, _ := filepath.Split(sandbox.BasePath)
+			require.Equal(t, filepath.Clean(expectedBaseDir), detectedFiles.baseDir)
 		})
 	}
 }
 
+// Check that an error is returned when detecting the BIND 9 configuration files
+// but an attempt to get the file information fails.
+func TestDetectBind9DaemonGetFileInfoError(t *testing.T) {
+	sandbox := testutil.NewSandbox()
+	defer sandbox.Close()
+	config := `
+		controls {
+			inet 1.1.1.1 port 1111 allow { localhost; } keys { "foo"; "bar"; };
+		};
+	`
+	_, err := sandbox.Write("named.conf", config)
+	require.NoError(t, err)
+
+	configPath := path.Join(sandbox.BasePath, "named.conf")
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+
+	process := NewMockSupportedProcess(ctrl)
+	absolutePath := path.Join(sandbox.BasePath, "named")
+	process.EXPECT().getCmdline().Return(fmt.Sprintf("%s -c %s", absolutePath, configPath), nil)
+	process.EXPECT().getCwd().Return("", nil)
+	process.EXPECT().getPid().Times(0)
+
+	// Create the command executor without adding an expectation for
+	// GetFileInfo call. It should return an error when this call is
+	// made. We want to make sure that this error is propagated to the caller.
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addCheckConfOutput(configPath, config)
+
+	detectedFiles, err := monitor.detectBind9ConfigPaths(process)
+	require.ErrorContains(t, err, "file not found")
+	require.Nil(t, detectedFiles)
+}
+
+// Check that the detected BIND 9 daemon is instantiated and configured
+// when both config and rndc key files are present.
+func TestConfigureBind9DaemonBothConfigRndcKey(t *testing.T) {
+	sandbox := testutil.NewSandbox()
+	defer sandbox.Close()
+
+	// Create config file.
+	configPath := path.Join(sandbox.BasePath, "named.conf")
+	config := `
+		controls {
+			inet 1.1.1.1 port 1111 allow { localhost; } keys { "foo"; "bar"; };
+		};
+		statistics-channels {
+			inet 1.1.1.1 port 1112 allow { localhost; } keys { "foo"; "bar"; };
+		};
+	`
+	_, err := sandbox.Write("named.conf", config)
+	require.NoError(t, err)
+
+	// Create rndc.key file.
+	rndcKeyPath := path.Join(sandbox.BasePath, "rndc.key")
+	rndcKeyConfig := `
+		key "foo" {
+			algorithm "hmac-sha256";
+			secret "abcd";
+		};
+	`
+	_, err = sandbox.Write("rndc.key", rndcKeyConfig)
+	require.NoError(t, err)
+
+	// Check BIND 9 daemon detection.
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addCheckConfOutput(configPath, config).
+		addCheckConfOutput(rndcKeyPath, rndcKeyConfig).
+		addFileInfo(configPath, &testFileInfo{}).
+		addFileInfo(rndcKeyPath, &testFileInfo{})
+
+	// Now run the detection as usual.
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+	process := NewMockSupportedProcess(ctrl)
+	process.EXPECT().getPid().Return(int32(1234))
+
+	files := newDetectedDaemonFiles("", sandbox.BasePath)
+	err = files.addFile(detectedFileTypeConfig, configPath, monitor.commander)
+	require.NoError(t, err)
+
+	daemon, err := monitor.configureBind9Daemon(process, files)
+	require.NoError(t, err)
+	require.NotNil(t, daemon)
+	require.Equal(t, daemonname.Bind9, daemon.GetName())
+	require.Len(t, daemon.GetAccessPoints(), 2)
+
+	// Check control access point.
+	controlPoint := daemon.GetAccessPoints()[0]
+	require.Equal(t, AccessPointControl, controlPoint.Type)
+	require.Equal(t, "1.1.1.1", controlPoint.Address)
+	require.EqualValues(t, 1111, controlPoint.Port)
+
+	// Check statistics access point.
+	statisticsPoint := daemon.GetAccessPoints()[1]
+	require.Equal(t, AccessPointStatistics, statisticsPoint.Type)
+	require.Equal(t, "1.1.1.1", statisticsPoint.Address)
+	require.EqualValues(t, 1112, statisticsPoint.Port)
+	require.Empty(t, statisticsPoint.Key)
+}
+
+// Check that the detected BIND 9 daemon is instantiated and configured
+// when rndc key file is absent.
+func TestConfigureBind9DaemonConfigOnly(t *testing.T) {
+	sandbox := testutil.NewSandbox()
+	defer sandbox.Close()
+
+	// Create config file.
+	configPath := path.Join(sandbox.BasePath, "named.conf")
+	config := `
+		key "foo" {
+			algorithm "hmac-sha256";
+			secret "abcd";
+		};
+		controls {
+			inet 1.1.1.1 port 1111 allow { localhost; } keys { "foo"; "bar"; };
+		};
+		statistics-channels {
+			inet 1.1.1.1 port 1112 allow { localhost; } keys { "foo"; "bar"; };
+		};
+	`
+	_, err := sandbox.Write("named.conf", config)
+	require.NoError(t, err)
+
+	// Check BIND 9 daemon detection.
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addCheckConfOutput(configPath, config).
+		addFileInfo(configPath, &testFileInfo{})
+
+	// Now run the detection as usual.
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+	process := NewMockSupportedProcess(ctrl)
+	process.EXPECT().getPid().Return(int32(1234))
+
+	files := newDetectedDaemonFiles("", sandbox.BasePath)
+	err = files.addFile(detectedFileTypeConfig, configPath, monitor.commander)
+	require.NoError(t, err)
+
+	daemon, err := monitor.configureBind9Daemon(process, files)
+	require.NoError(t, err)
+	require.NotNil(t, daemon)
+	require.Equal(t, daemonname.Bind9, daemon.GetName())
+	require.Len(t, daemon.GetAccessPoints(), 2)
+
+	// Check control access point.
+	controlPoint := daemon.GetAccessPoints()[0]
+	require.Equal(t, AccessPointControl, controlPoint.Type)
+	require.Equal(t, "1.1.1.1", controlPoint.Address)
+	require.EqualValues(t, 1111, controlPoint.Port)
+
+	// Check statistics access point.
+	statisticsPoint := daemon.GetAccessPoints()[1]
+	require.Equal(t, AccessPointStatistics, statisticsPoint.Type)
+	require.Equal(t, "1.1.1.1", statisticsPoint.Address)
+	require.EqualValues(t, 1112, statisticsPoint.Port)
+	require.Empty(t, statisticsPoint.Key)
+}
+
+// Test that the included BIND 9 configuration files are recorded in the set
+// of detected files.
+func TestConfigureBind9DaemonIncludedFiles(t *testing.T) {
+	sandbox := testutil.NewSandbox()
+	defer sandbox.Close()
+
+	// Create config file with two included files.
+	configPath := path.Join(sandbox.BasePath, "named.conf")
+	config := `
+		include "include1.conf";
+		include "include2.conf";
+
+		key "foo" {
+			algorithm "hmac-sha256";
+			secret "abcd";
+		};
+		controls {
+			inet 1.1.1.1 port 1111 allow { localhost; } keys { "foo"; "bar"; };
+		};
+		statistics-channels {
+			inet 1.1.1.1 port 1112 allow { localhost; } keys { "foo"; "bar"; };
+		};
+	`
+	_, err := sandbox.Write("named.conf", config)
+	require.NoError(t, err)
+
+	// First included file.
+	include1Path := path.Join(sandbox.BasePath, "include1.conf")
+	include1Config := `
+		acl first { 1.1.1.1; };
+	`
+	_, err = sandbox.Write("include1.conf", include1Config)
+	require.NoError(t, err)
+
+	// Second included file.
+	include2Path := path.Join(sandbox.BasePath, "include2.conf")
+	include2Config := `
+		acl second { 2.2.2.2; };
+	`
+	_, err = sandbox.Write("include2.conf", include2Config)
+	require.NoError(t, err)
+
+	// Create the monitor with mock command executor.
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addCheckConfOutput(configPath, config).
+		addCheckConfOutput(include1Path, include1Config).
+		addCheckConfOutput(include2Path, include2Config).
+		addFileInfo(configPath, &testFileInfo{}).
+		addFileInfo(include1Path, &testFileInfo{}).
+		addFileInfo(include2Path, &testFileInfo{})
+
+	// Create the mock process.
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+	process := NewMockSupportedProcess(ctrl)
+	process.EXPECT().getPid().Return(int32(1234))
+
+	// Create the set of detected files with one config file
+	// and without the includes.
+	files := newDetectedDaemonFiles("", sandbox.BasePath)
+	err = files.addFile(detectedFileTypeConfig, configPath, monitor.commander)
+	require.NoError(t, err)
+
+	// Parse and expand the configuration files.
+	daemon, err := monitor.configureBind9Daemon(process, files)
+	require.NoError(t, err)
+	require.NotNil(t, daemon)
+	require.Equal(t, daemonname.Bind9, daemon.GetName())
+	require.Len(t, daemon.GetAccessPoints(), 2)
+
+	// We should now have three files recorded. One main config file
+	// and two included files.
+	require.NotNil(t, daemon.detectedFiles)
+	require.Len(t, daemon.detectedFiles.files, 3)
+
+	// Make sure their paths are correct.
+	require.Equal(t, configPath, daemon.detectedFiles.files[0].path)
+	require.Equal(t, include1Path, daemon.detectedFiles.files[1].path)
+	require.Equal(t, include2Path, daemon.detectedFiles.files[2].path)
+}
+
+// Check that the detected BIND 9 daemon is instantiated and configured
+// when the statistics channels are not configured.
+func TestConfigureBind9DaemonNoStatistics(t *testing.T) {
+	sandbox := testutil.NewSandbox()
+	defer sandbox.Close()
+
+	// Create config file.
+	configPath := path.Join(sandbox.BasePath, "named.conf")
+	config := `
+		key "foo" {
+			algorithm "hmac-sha256";
+			secret "abcd";
+		};
+		controls {
+			inet 1.1.1.1 port 1111 allow { localhost; } keys { "foo"; "bar"; };
+		};
+	`
+	_, err := sandbox.Write("named.conf", config)
+	require.NoError(t, err)
+
+	// Check BIND 9 daemon detection.
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addCheckConfOutput(configPath, config).
+		addFileInfo(configPath, &testFileInfo{})
+
+	// Now run the detection as usual.
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+	process := NewMockSupportedProcess(ctrl)
+	process.EXPECT().getPid().Return(int32(1234))
+
+	files := newDetectedDaemonFiles("", sandbox.BasePath)
+	err = files.addFile(detectedFileTypeConfig, configPath, monitor.commander)
+	require.NoError(t, err)
+
+	daemon, err := monitor.configureBind9Daemon(process, files)
+	require.NoError(t, err)
+	require.NotNil(t, daemon)
+	require.Equal(t, daemonname.Bind9, daemon.GetName())
+	require.Len(t, daemon.GetAccessPoints(), 1)
+
+	// Check control access point.
+	controlPoint := daemon.GetAccessPoints()[0]
+	require.Equal(t, AccessPointControl, controlPoint.Type)
+	require.Equal(t, "1.1.1.1", controlPoint.Address)
+	require.EqualValues(t, 1111, controlPoint.Port)
+	require.EqualValues(t, "foo:hmac-sha256:abcd", controlPoint.Key)
+
+	// Check other daemon fields.
+	require.Equal(t, daemon.Name, daemonname.Bind9)
+	require.Nil(t, daemon.zoneInventory)
+	require.NotNil(t, daemon.rndcClient)
+	require.EqualValues(t, 1234, daemon.pid)
+	require.NotNil(t, daemon.bind9Config)
+	require.Nil(t, daemon.rndcKeyConfig)
+}
+
+// Check that an error is returned when parsing the BIND 9 config file fails.
+func TestConfigureBind9DaemonParseError(t *testing.T) {
+	// Now run the detection as usual.
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+	process := NewMockSupportedProcess(ctrl)
+
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addFileInfo("/chroot/etc/bind/named.conf", &testFileInfo{})
+
+	parser := NewMockBind9FileParser(ctrl)
+	parser.EXPECT().ParseFile("/etc/bind/named.conf", "/chroot").Return(nil, errors.New("test error"))
+
+	monitor.bind9FileParser = parser
+
+	files := newDetectedDaemonFiles("/chroot", "")
+	err := files.addFile(detectedFileTypeConfig, "/etc/bind/named.conf", monitor.commander)
+	require.NoError(t, err)
+
+	daemon, err := monitor.configureBind9Daemon(process, files)
+	require.Error(t, err)
+	require.Nil(t, daemon)
+	require.ErrorContains(t, err, "failed to parse BIND 9 config file")
+}
+
 // There is no reliable way to test step 4 (checking typical locations). The
 // code is not mockable. We could check if there's BIND config in any of the
 // typical locations, but what exactly are we supposed to do if we find one?
 // The actual Ubuntu 22.04 system is a good example. I have BIND 9 installed
 // and the detection actually detects the BIND 9 config file. However, it fails
 // to read rndc.key file, because it's set to be read by bind user only.
-// Without rndc the BIND detection fails and returns no apps.
+// Without rndc the BIND detection fails and returns no daemons.
 //
 // An alternative approach would be to enable debug logging, then capture the
 // stdout and parse if the messages mention default locations. We _could_ do
@@ -680,11 +1206,15 @@ func TestDetectBind9DetectOrder(t *testing.T) {
 	config3Path := path.Join(sandbox.BasePath, "step3.conf")
 
 	// ... and tell the fake executor to return it as the output of named -V
-	executor := newTestCommandExecutor().
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
 		addCheckConfOutput(config1Path, config1).
 		addCheckConfOutput(config2Path, config2).
 		addCheckConfOutput(config3Path, config3).
-		setConfigPathInNamedOutput(config3Path)
+		setConfigPathInNamedOutput(config3Path).
+		addFileInfo(config1Path, &testFileInfo{}).
+		addFileInfo(config2Path, &testFileInfo{}).
+		addFileInfo(config3Path, &testFileInfo{})
 
 	// Now run the detection as usual
 	ctrl := gomock.NewController(t)
@@ -694,7 +1224,7 @@ func TestDetectBind9DetectOrder(t *testing.T) {
 	process.EXPECT().getCmdline().Return(fmt.Sprintf("%s -c %s", absolutePath, config1Path), nil)
 	process.EXPECT().getCwd().Return("", nil)
 	process.EXPECT().getPid().Return(int32(1234))
-	daemon, err := detectBind9Daemon(process, executor, config2Path, bind9config.NewParser())
+	daemon, err := monitor.detectBind9Daemon(process)
 	require.NoError(t, err)
 	require.NotNil(t, daemon)
 	require.Equal(t, daemonname.Bind9, daemon.GetName())
