@@ -10,6 +10,7 @@ import (
 	"net/http"
 	"os"
 	"path"
+	"path/filepath"
 	"regexp"
 	"strings"
 
@@ -18,6 +19,7 @@ import (
 
 	keaconfig "isc.org/stork/daemoncfg/kea"
 	keactrl "isc.org/stork/daemonctrl/kea"
+	keadata "isc.org/stork/daemondata/kea"
 	"isc.org/stork/datamodel/daemonname"
 	"isc.org/stork/datamodel/protocoltype"
 	storkutil "isc.org/stork/util"
@@ -29,6 +31,7 @@ var _ Daemon = (*keaDaemon)(nil)
 type keaDaemon struct {
 	daemon
 	connector keaConnector // to communicate with Kea daemon
+	snooper   MemfileSnooper
 }
 
 // Interface to a Kea command that allows overriding the daemon list.
@@ -132,6 +135,33 @@ func (d *keaDaemon) fetchConfig(ctx context.Context) (*keaconfig.Config, error)
 	return config, nil
 }
 
+// Fetches the status of Kea from the daemon by sending the status-get command.
+func (d *keaDaemon) fetchStatus(ctx context.Context) (*keactrl.Status, error) {
+	command := keactrl.NewCommandBase(keactrl.StatusGet, d.GetName())
+	response := keactrl.Response{}
+	err := d.sendCommand(ctx, command, &response)
+	if err != nil {
+		return nil, err
+	}
+
+	if err := response.GetError(); err != nil {
+		return nil, errors.WithMessagef(
+			err, "unsuccessful response received from Kea to status-get command sent to %s", d,
+		)
+	}
+
+	if response.Arguments == nil {
+		return nil, errors.New("status-get response has no arguments")
+	}
+	var status keactrl.Status
+	err = json.Unmarshal(response.Arguments, &status)
+	if err != nil {
+		return nil, errors.WithMessage(err, "status-get response contains arguments which could not be parsed")
+	}
+
+	return &status, nil
+}
+
 // Reads the Kea configuration file, resolves the includes, and parses the content.
 func readKeaConfig(path string) (*keaconfig.Config, error) {
 	text, err := storkutil.ReadFileWithIncludes(path)
@@ -149,6 +179,28 @@ func readKeaConfig(path string) (*keaconfig.Config, error) {
 	return config, err
 }
 
+// Resolves the full socket path from the socket filename and Kea executable
+// path.
+// Meson (build system used by Kea) decides localstatedir (which is part of
+// socket path dir) automatically for Kea:
+// https://github.com/mesonbuild/meson/blob/1.10.1/mesonbuild/options.py#L772
+// Handles a general case (standard Linux distribution, when the Kea
+// installation prefix is /) and special cases: when the installation prefix is
+// /usr, /usr/local (BSDs, MacOS), and custom.
+// See: https://github.com/mesonbuild/meson/blob/master/unittests/allplatformstests.py#L324-L363
+// and https://gitlab.isc.org/isc-projects/stork/-/issues/2166 .
+func resolveKeaSocketPath(socketFilename string, keaExecutablePath string) string {
+	keaInstallPrefix := filepath.Join(filepath.Dir(keaExecutablePath), "..")
+	switch keaInstallPrefix {
+	case "/usr":
+		return filepath.Join("/", "var", "run", "kea", socketFilename)
+	case "/usr/local":
+		return filepath.Join("/", "var", "local", "run", "kea", socketFilename)
+	default:
+		return filepath.Join(keaInstallPrefix, "var", "run", "kea", socketFilename)
+	}
+}
+
 // Detect the Kea daemon(s).
 //
 // The communication model with Kea changed significantly with the release of
@@ -186,8 +238,8 @@ func readKeaConfig(path string) (*keaconfig.Config, error) {
 // The version of the Kea daemon is recognized by calling its executable with
 // the --version flag.
 //
-// The specified httpClientConfig is used to create a new HTTP client instance
-// for the detected Kea app. The client inherits the the general HTTP client
+// The monitor's keaHTTPClientConfig is used to create a new HTTP client instance
+// for the detected Kea daemon. The client inherits the the general HTTP client
 // configuration from the Stork agent configuration and additionally sets the
 // basic authentication credentials if they are provided in the Kea CA
 // configuration. It picks the first credentials with the user name "stork" or
@@ -196,7 +248,7 @@ func readKeaConfig(path string) (*keaconfig.Config, error) {
 //
 // It returns the Kea daemon instance or an error if the Kea is not recognized or
 // any error occurs.
-func detectKeaDaemons(ctx context.Context, p supportedProcess, httpClientConfig HTTPClientConfig, commander storkutil.CommandExecutor) ([]Daemon, error) {
+func (sm *monitor) detectKeaDaemons(ctx context.Context, p supportedProcess) ([]Daemon, error) {
 	// Extract the daemon name from the process.
 	processName, err := p.getName()
 	if err != nil {
@@ -239,7 +291,7 @@ func detectKeaDaemons(ctx context.Context, p supportedProcess, httpClientConfig
 		executablePath = path.Join(cwd, executablePath)
 	}
 
-	versionRaw, err := commander.Output(executablePath, "-v")
+	versionRaw, err := sm.commander.Output(executablePath, "-v")
 	if err != nil {
 		return nil, errors.WithMessagef(err, "cannot get Kea version by executing %s -v", executablePath)
 	}
@@ -267,15 +319,15 @@ func detectKeaDaemons(ctx context.Context, p supportedProcess, httpClientConfig
 		return nil, errors.WithMessagef(err, "invalid Kea %s config: %s", daemonName, configPath)
 	}
 
-	var accessPoints []AccessPoint
-	var connector keaConnector
 	controlSockets := config.GetListeningControlSockets()
-	if len(controlSockets) != 0 {
-		controlSocket := controlSockets[0]
+	var accessPoints []AccessPoint
+	var httpClientConfigs []HTTPClientConfig
 
+	for _, controlSocket := range controlSockets {
 		// Credentials
 		// Key is a user name that Stork uses to authenticate with Kea.
 		var key string
+		httpClientConfig := sm.keaHTTPClientConfig
 		if controlSocket.Authentication != nil {
 			allCredentials, err := readClientCredentials(controlSocket.Authentication)
 			if err != nil {
@@ -299,15 +351,26 @@ func detectKeaDaemons(ctx context.Context, p supportedProcess, httpClientConfig
 			}
 		}
 
+		// Normalize socket path if the socket type is unix. Translate into full path if only name is given.
+		socketAddress := controlSocket.GetAddress()
+		if controlSocket.GetProtocol() == protocoltype.Socket && !strings.Contains(socketAddress, "/") {
+			exe, err := p.getExe()
+			if err != nil {
+				return nil, errors.WithMessagef(err, "could not get path to executable")
+			}
+
+			socketAddress = resolveKeaSocketPath(socketAddress, exe)
+		}
+
 		accessPoint := AccessPoint{
 			Type:     AccessPointControl,
-			Address:  controlSocket.GetAddress(),
+			Address:  socketAddress,
 			Port:     controlSocket.GetPort(),
 			Protocol: controlSocket.GetProtocol(),
 			Key:      key,
 		}
 		accessPoints = append(accessPoints, accessPoint)
-		connector = newKeaConnector(accessPoint, httpClientConfig)
+		httpClientConfigs = append(httpClientConfigs, httpClientConfig)
 	}
 
 	thisDaemon := &keaDaemon{
@@ -315,7 +378,7 @@ func detectKeaDaemons(ctx context.Context, p supportedProcess, httpClientConfig
 			Name:         daemonName,
 			AccessPoints: accessPoints,
 		},
-		connector: connector,
+		connector: newMultiConnector(accessPoints, httpClientConfigs),
 	}
 
 	detectedDaemons := []Daemon{thisDaemon}
@@ -455,7 +518,7 @@ func (d *keaDaemon) Bootstrap() error {
 }
 
 // Called periodically to update the daemon state.
-// Gathers the configured log files for detected apps and enables them
+// Gathers the configured log files for detected daemons and enables them
 // for viewing from the UI.
 func (d *keaDaemon) RefreshState(ctx context.Context, agent agentManager) error {
 	config, err := d.fetchConfig(ctx)
@@ -463,6 +526,13 @@ func (d *keaDaemon) RefreshState(ctx context.Context, agent agentManager) error
 		return errors.WithMessage(err, "cannot fetch Kea configuration")
 	}
 	paths := collectKeaAllowedLogs(config)
+	allowed, maxLeaseUpdates := agent.allowLeaseTracking()
+	if allowed {
+		err = d.ensureWatchingLeasefile(ctx, config, maxLeaseUpdates)
+		if err != nil {
+			return err
+		}
+	}
 
 	for _, p := range paths {
 		agent.allowLog(p)
@@ -470,8 +540,87 @@ func (d *keaDaemon) RefreshState(ctx context.Context, agent agentManager) error
 	return nil
 }
 
+// Ensure that this keaDaemon is watching the lease file it's supposed to be
+// watching. This function will use the get-status API to ask Kea for the
+// current lease file path (so that we don't have to guess based on defaults and
+// whatever's in the config).
+func (d *keaDaemon) ensureWatchingLeasefile(ctx context.Context, config *keaconfig.Config, maxLeaseUpdates int) error {
+	var leaseDBType string
+	var persist bool
+
+	switch d.Name {
+	case daemonname.DHCPv4:
+		if config != nil &&
+			config.DHCPv4Config != nil &&
+			config.DHCPv4Config.LeaseDatabase != nil {
+			leaseDBType = config.DHCPv4Config.LeaseDatabase.Type
+			if config.DHCPv4Config.LeaseDatabase.Persist != nil {
+				persist = *config.DHCPv4Config.LeaseDatabase.Persist
+			} else {
+				// The default when persist is unspecified is true, per https://kea.readthedocs.io/en/stable/arm/dhcp4-srv.html#memfile-basic-storage-for-leases.
+				persist = true
+			}
+		}
+	case daemonname.DHCPv6:
+		if config != nil &&
+			config.DHCPv6Config != nil &&
+			config.DHCPv6Config.LeaseDatabase != nil {
+			leaseDBType = config.DHCPv6Config.LeaseDatabase.Type
+			if config.DHCPv6Config.LeaseDatabase.Persist != nil {
+				persist = *config.DHCPv6Config.LeaseDatabase.Persist
+			} else {
+				// The default when persist is unspecified is true, per https://kea.readthedocs.io/en/stable/arm/dhcp6-srv.html#memfile-basic-storage-for-leases.
+				persist = true
+			}
+		}
+	default:
+		// do nothing, the variables should stay nil so that it doesn't try to look at a leasefile from D2 or something.
+	}
+
+	if leaseDBType == "memfile" && persist {
+		// I should likely be watching a leasefile...
+		status, err := d.fetchStatus(ctx)
+		if err != nil {
+			return err
+		}
+		if status.CSVLeaseFile == nil {
+			return errors.New("Kea's configuration says that it is in memfile mode with persistence on, but its status API did not return the path to the lease memfile.")
+		}
+		if d.snooper == nil {
+			// ...but I am currently not.
+			rs, err := NewRowSource(*status.CSVLeaseFile)
+			if err != nil {
+				return err
+			}
+			d.snooper, err = NewMemfileSnooper(maxLeaseUpdates, d.Name, rs)
+			if err != nil {
+				return err
+			}
+			d.snooper.Start()
+		} else {
+			// ...and I am, but I should make sure I'm looking at the right file.
+			return d.snooper.EnsureWatching(*status.CSVLeaseFile)
+		}
+	} else if d.snooper != nil {
+		// I shouldn't be watching a leasefile, but I currently am, so I should stop.
+		// e.g. Kea was reconfigured to use a lease PostgreSQL lease database.
+		d.snooper.Stop()
+		d.snooper = nil
+	}
+	return nil
+}
+
+// Get a snapshot of all current leases known for this daemon.
+func (d *keaDaemon) GetLeaseSnapshot() []*keadata.Lease {
+	return d.snooper.GetSnapshot()
+}
+
 // Called once before the daemon is removed.
 func (d *keaDaemon) Cleanup() error {
+	if d.snooper != nil {
+		d.snooper.Stop()
+		d.snooper = nil
+	}
 	return nil
 }
 
@@ -563,3 +712,44 @@ func (c *keaHTTPConnector) sendPayload(ctx context.Context, command []byte) ([]b
 
 	return body, nil
 }
+
+// Handles connections to multiple control sockets of a Kea daemon. It tries
+// each connector in order until one succeeds.
+type multiConnector struct {
+	connectors []keaConnector
+}
+
+// Creates a new multiConnector from the list of access points.
+// It instantiates a keaConnector for each access point.
+// It is expected that all access points belong to the same Kea daemon.
+// The httpClientConfigs should match the accessPoints by index.
+func newMultiConnector(accessPoints []AccessPoint, httpClientConfigs []HTTPClientConfig) *multiConnector {
+	var connectors []keaConnector
+	for i, ap := range accessPoints {
+		httpClientConfig := HTTPClientConfig{}
+		if i < len(httpClientConfigs) {
+			httpClientConfig = httpClientConfigs[i]
+		}
+		connector := newKeaConnector(ap, httpClientConfig)
+		connectors = append(connectors, connector)
+	}
+	return &multiConnector{connectors: connectors}
+}
+
+// Sends the command to Kea via one of the connectors and returns the response.
+func (c *multiConnector) sendPayload(ctx context.Context, command []byte) ([]byte, error) {
+	if len(c.connectors) == 0 {
+		return nil, errors.New("no connectors available to send command to Kea")
+	}
+
+	var lastErr error
+	for i, connector := range c.connectors {
+		response, err := connector.sendPayload(ctx, command)
+		if err == nil {
+			return response, nil
+		}
+		log.WithError(err).WithField("index", i).Debug("Connection to Kea failed, trying another control socket")
+		lastErr = err
+	}
+	return nil, errors.WithMessagef(lastErr, "all connectors failed to send command to Kea")
+}
