@@ -255,6 +255,7 @@ func TestKeaAllowedLogs(t *testing.T) {
 	// We should have three log files recorded from the returned configurations.
 	// One from CA, one from DHCPv4 and one from DHCPv6.
 	agentManager.EXPECT().allowLog(gomock.Any()).Times(3)
+	agentManager.EXPECT().allowLeaseTracking().Return(false, 0).AnyTimes()
 
 	monitor.refreshDaemons(t.Context(), agentManager)
 
@@ -395,6 +396,7 @@ func TestKeaAllowedLogsOutputOptionsWithDash(t *testing.T) {
 	// We should have three log files recorded from the returned configurations.
 	// One from CA, one from DHCPv4 and one from DHCPv6.
 	agentManager.EXPECT().allowLog(gomock.Any()).Times(3)
+	agentManager.EXPECT().allowLeaseTracking().Return(false, 0).AnyTimes()
 
 	monitor.refreshDaemons(t.Context(), agentManager)
 
@@ -936,8 +938,11 @@ func TestDetectKeaCAPrior3_0(t *testing.T) {
 	commander := NewMockCommandExecutor(ctrl)
 	commander.EXPECT().Output(exePath, "-v").Return([]byte("2.3.0\n"), nil)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1012,8 +1017,11 @@ func TestDetectKeaCAPost3_0(t *testing.T) {
 	commander := NewMockCommandExecutor(ctrl)
 	commander.EXPECT().Output(exePath, "-v").Return([]byte("3.0.0\n"), nil)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1061,8 +1069,11 @@ func TestDetectKeaDHCPPrior3_0(t *testing.T) {
 	commander := NewMockCommandExecutor(ctrl)
 	commander.EXPECT().Output(exePath, "-v").Return([]byte("2.3.0\n"), nil)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1105,8 +1116,11 @@ func TestDetectKeaDHCPOnSocketPost3_0(t *testing.T) {
 	commander := NewMockCommandExecutor(ctrl)
 	commander.EXPECT().Output(exePath, "-v").Return([]byte("3.0.0\n"), nil)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1124,6 +1138,66 @@ func TestDetectKeaDHCPOnSocketPost3_0(t *testing.T) {
 	require.Equal(t, protocoltype.Socket, accessPoint.Protocol)
 }
 
+// Test that the Kea DHCP listening on socket configured with name only is detected.
+func TestDetectKeaDHCPOnSocketNameOnly(t *testing.T) {
+	// Arrange
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+
+	sb := testutil.NewSandbox()
+	defer sb.Close()
+
+	// Create a configuration file for Kea.
+	configPath, _ := sb.Write("kea-dhcp4.conf", `{
+      "Dhcp4": {
+				"control-socket": {
+					"socket-type": "unix",
+					"socket-name": "kea4-ctrl-socket"
+				}
+			}
+    }`)
+	exePath, _ := sb.Join("bin/kea-dhcp4")
+	socketPath, _ := sb.Join("var/run/kea/kea4-ctrl-socket")
+
+	httpConfig := HTTPClientConfig{}
+
+	// Kea process mock.
+	process := NewMockSupportedProcess(ctrl)
+	process.EXPECT().getName().Return("kea-dhcp4", nil)
+	process.EXPECT().getDaemonName().Return(daemonname.DHCPv4)
+	process.EXPECT().getCmdline().Return(
+		fmt.Sprintf("%s -c %s", exePath, configPath),
+		nil,
+	)
+	process.EXPECT().getCwd().Return(sb.BasePath, nil)
+	process.EXPECT().getExe().Return(exePath, nil)
+
+	// System calls mock.
+	commander := NewMockCommandExecutor(ctrl)
+	commander.EXPECT().Output(exePath, "-v").Return([]byte("3.0.0\n"), nil)
+
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
+	// Act
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
+
+	// Assert
+	require.False(t, gock.HasUnmatchedRequest())
+	require.NoError(t, err)
+
+	require.Len(t, daemons, 1)
+	require.Equal(t, daemonname.DHCPv4, daemons[0].GetName())
+
+	accessPoints := daemons[0].GetAccessPoints()
+	require.Len(t, accessPoints, 1)
+	accessPoint := accessPoints[0]
+	require.Equal(t, AccessPointControl, accessPoint.Type)
+	require.Equal(t, socketPath, accessPoint.Address)
+	require.Zero(t, accessPoint.Port)
+	require.Equal(t, protocoltype.Socket, accessPoint.Protocol)
+}
+
 // Test that the Kea DHCP post 3.0 listening on HTTP is detected.
 func TestDetectKeaDHCPOnHTTPPost3_0(t *testing.T) {
 	// Arrange
@@ -1159,8 +1233,11 @@ func TestDetectKeaDHCPOnHTTPPost3_0(t *testing.T) {
 	commander := NewMockCommandExecutor(ctrl)
 	commander.EXPECT().Output(exePath, "-v").Return([]byte("3.0.0\n"), nil)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1238,8 +1315,11 @@ func TestDetectKeaCAWithCredentials(t *testing.T) {
 	commander := NewMockCommandExecutor(ctrl)
 	commander.EXPECT().Output(exePath, "-v").Return([]byte("3.0.0\n"), nil)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1295,8 +1375,11 @@ func TestDetectKeaDHCPWithCredentials(t *testing.T) {
 	commander := NewMockCommandExecutor(ctrl)
 	commander.EXPECT().Output(exePath, "-v").Return([]byte("3.0.0\n"), nil)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1327,8 +1410,11 @@ func TestDetectKeaProcessNameUnavailable(t *testing.T) {
 
 	commander := NewMockCommandExecutor(ctrl)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1351,8 +1437,11 @@ func TestDetectKeaDaemonNameUnavailable(t *testing.T) {
 
 	commander := NewMockCommandExecutor(ctrl)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1379,8 +1468,11 @@ func TestDetectKeaCommandLineUnavailable(t *testing.T) {
 
 	commander := NewMockCommandExecutor(ctrl)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1417,8 +1509,11 @@ func TestDetectKeaCwdUnavailable(t *testing.T) {
 
 	commander := NewMockCommandExecutor(ctrl)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1454,8 +1549,11 @@ func TestDetectKeaWithDefaultConfigurationPath(t *testing.T) {
 
 	commander := NewMockCommandExecutor(ctrl)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1492,8 +1590,11 @@ func TestDetectKeaUnparsableVersion(t *testing.T) {
 	commander := NewMockCommandExecutor(ctrl)
 	commander.EXPECT().Output(exePath, "-v").Return([]byte("git+dirty\n"), nil)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1550,8 +1651,11 @@ func TestDetectKeaWithRelativeConfigurationPath(t *testing.T) {
 	commander := NewMockCommandExecutor(ctrl)
 	commander.EXPECT().Output(exePath, "-v").Return([]byte("3.0.0\n"), nil)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1640,8 +1744,11 @@ func TestDetectKeaCommunicationError(t *testing.T) {
 	commander := NewMockCommandExecutor(ctrl)
 	commander.EXPECT().Output(exePath, "-v").Return([]byte("2.3.0\n"), nil)
 
+	monitor := newMonitor("", "", httpConfig)
+	monitor.commander = commander
+
 	// Act
-	daemons, err := detectKeaDaemons(t.Context(), process, httpConfig, commander)
+	daemons, err := monitor.detectKeaDaemons(t.Context(), process)
 
 	// Assert
 	require.False(t, gock.HasUnmatchedRequest())
@@ -1680,9 +1787,7 @@ func TestKeaSocketConnectorSendPayload(t *testing.T) {
 	response := []byte(`{"result":0}`)
 
 	var wgServer sync.WaitGroup
-	wgServer.Add(1)
-
-	go func() {
+	wgServer.Go(func() {
 		// Wait for client connection.
 		conn, err := server.Accept()
 		require.NoError(t, err)
@@ -1699,10 +1804,7 @@ func TestKeaSocketConnectorSendPayload(t *testing.T) {
 		n, err = conn.Write(response)
 		require.NoError(t, err)
 		require.Len(t, response, n)
-
-		// Signal that server work is done.
-		wgServer.Done()
-	}()
+	})
 
 	// Construct a socket connector.
 	connector := newKeaConnector(AccessPoint{
@@ -1752,3 +1854,665 @@ func TestKeaHTTPConnectorSendPayload(t *testing.T) {
 	// The response is unwrapped from the array.
 	require.Equal(t, []byte(`{"result":0}`), output)
 }
+
+// Test that the multi-connector sends payload and fallback to the next
+// connector if the first one fails.
+func TestKeaMultiConnectorSendPayload(t *testing.T) {
+	// Arrange
+	// The UNIX socket connector will fail as there is no server listening.
+	sb := testutil.NewSandbox()
+	defer sb.Close()
+	socketPath := path.Join(sb.BasePath, "kea-socket-test.sock")
+
+	command := []byte(`{"command":"ping"}`)
+
+	// The HTTP connector will succeed.
+	defer gock.Off()
+
+	gock.New("http://localhost:45634").
+		MatchHeader("Content-Type", "application/json").
+		Post("/").
+		Reply(200).
+		// The server wraps the response into an array.
+		JSON([]map[string]any{{"result": 0}})
+
+	// Act
+	multiConnector := newMultiConnector(
+		[]AccessPoint{
+			{
+				Type:     AccessPointControl,
+				Address:  socketPath,
+				Protocol: protocoltype.Socket,
+			},
+			{
+				Type:     AccessPointControl,
+				Address:  "localhost",
+				Port:     45634,
+				Protocol: protocoltype.HTTP,
+			},
+		},
+		[]HTTPClientConfig{{}, {Interceptor: gock.InterceptClient}},
+	)
+	output, err := multiConnector.sendPayload(t.Context(), command)
+
+	// Assert
+	require.NoError(t, err)
+	// The response is unwrapped from the array.
+	require.Equal(t, []byte(`{"result":0}`), output)
+}
+
+// Test that the multi-connector fails to send payload if all connectors fail.
+func TestKeaMultiConnectorSendPayloadFail(t *testing.T) {
+	// Arrange
+	// The UNIX socket connector will fail as there is no server listening.
+	sb := testutil.NewSandbox()
+	defer sb.Close()
+	socketPath := path.Join(sb.BasePath, "kea-socket-test.sock")
+
+	command := []byte(`{"command":"ping"}`)
+
+	// The HTTP connector will fail.
+	defer gock.Off()
+
+	gock.New("http://localhost:45634").
+		MatchHeader("Content-Type", "application/json").
+		Post("/").
+		Reply(500)
+
+	// Act
+	multiConnector := newMultiConnector(
+		[]AccessPoint{
+			{
+				Type:     AccessPointControl,
+				Address:  socketPath,
+				Protocol: protocoltype.Socket,
+			},
+			{
+				Type:     AccessPointControl,
+				Address:  "localhost",
+				Port:     45634,
+				Protocol: protocoltype.HTTP,
+			},
+		},
+		[]HTTPClientConfig{{}, {Interceptor: gock.InterceptClient}},
+	)
+	_, err := multiConnector.sendPayload(t.Context(), command)
+
+	// Assert
+	require.ErrorContains(t, err, "all connectors failed")
+}
+
+// Test that the multi-connector cannot send payload if there is no connectors.
+func TestKeaMultiConnectorEmpty(t *testing.T) {
+	// Arrange
+	command := []byte(`{"command":"ping"}`)
+	multiConnector := newMultiConnector([]AccessPoint{}, []HTTPClientConfig{})
+
+	// Act
+	_, err := multiConnector.sendPayload(t.Context(), command)
+
+	// Assert
+	require.ErrorContains(t, err, "no connectors available")
+}
+
+// Mock a Kea status-get command HTTP request/response sequence.
+//
+// Expect "status-get" for the given `service`, exactly `times` times.
+// Reply with `response`.
+func makeKeaCommandMock(service, response string, times int) error {
+	responseJSON := make([]map[string]any, 1)
+	err := json.Unmarshal([]byte(response), &responseJSON)
+	if err != nil {
+		return err
+	}
+	gock.New("http://localhost:45634").
+		MatchHeader("Content-Type", "application/json").
+		JSON(map[string]any{"command": "status-get", "service": []string{service}}).
+		Times(times).
+		Post("/").
+		Reply(200).
+		JSON(responseJSON)
+	return nil
+}
+
+// Test to ensure that keaDaemon.ensureWatchingLeasefile works correctly in a variety of conditions (documented within).
+func TestEnsureWatchingLeasefile(t *testing.T) {
+	// Call the function once from an empty state to start watching a DHCPv4 lease
+	// file. There should be no errors.
+	t.Run("dhcpv4 start", func(t *testing.T) {
+		sb := testutil.NewSandbox()
+		defer sb.Close()
+
+		config := keaconfig.Config{
+			DHCPv4Config: &keaconfig.DHCPv4Config{
+				CommonDHCPConfig: keaconfig.CommonDHCPConfig{
+					LeaseDatabase: &keaconfig.Database{
+						Type: "memfile",
+					},
+				},
+			},
+		}
+		defer gock.Off()
+
+		leasefile, err := sb.Join("kea-leases4")
+		require.NoError(t, err)
+
+		dhcpV4ResponsesJSON := fmt.Sprintf(`[
+			{
+				"result": 0,
+				"arguments": {
+					"csv-lease-file": "%s"
+				}
+			}
+		]`, leasefile)
+		err = makeKeaCommandMock("dhcp4", dhcpV4ResponsesJSON, 1)
+		require.NoError(t, err)
+
+		accessPoint := AccessPoint{
+			Type:     AccessPointControl,
+			Address:  "localhost",
+			Port:     45634,
+			Protocol: protocoltype.HTTP,
+		}
+		connector := newKeaConnector(
+			accessPoint,
+			HTTPClientConfig{Interceptor: gock.InterceptClient},
+		)
+
+		daemon := &keaDaemon{
+			daemon: daemon{
+				Name:         daemonname.DHCPv4,
+				AccessPoints: []AccessPoint{accessPoint},
+			},
+			connector: connector,
+		}
+
+		err = daemon.ensureWatchingLeasefile(t.Context(), &config, 10)
+
+		require.NoError(t, err)
+		require.False(t, gock.HasUnmatchedRequest())
+	})
+	// Call the function once from an empty state to start watching a DHCPv6
+	// lease file. There should be no errors.
+	t.Run("dhcpv6 start", func(t *testing.T) {
+		sb := testutil.NewSandbox()
+		defer sb.Close()
+		config := keaconfig.Config{
+			DHCPv6Config: &keaconfig.DHCPv6Config{
+				CommonDHCPConfig: keaconfig.CommonDHCPConfig{
+					LeaseDatabase: &keaconfig.Database{
+						Type: "memfile",
+					},
+				},
+			},
+		}
+		defer gock.Off()
+
+		leasefile, err := sb.Join("kea-leases6")
+		require.NoError(t, err)
+
+		dhcpV6ResponsesJSON := fmt.Sprintf(`[
+			{
+				"result": 0,
+				"arguments": {
+					"csv-lease-file": "%s"
+				}
+			}
+		]`, leasefile)
+		err = makeKeaCommandMock("dhcp6", dhcpV6ResponsesJSON, 1)
+		require.NoError(t, err)
+
+		accessPoint := AccessPoint{
+			Type:     AccessPointControl,
+			Address:  "localhost",
+			Port:     45634,
+			Protocol: protocoltype.HTTP,
+		}
+		connector := newKeaConnector(
+			accessPoint,
+			HTTPClientConfig{Interceptor: gock.InterceptClient},
+		)
+
+		daemon := &keaDaemon{
+			daemon: daemon{
+				Name:         daemonname.DHCPv6,
+				AccessPoints: []AccessPoint{accessPoint},
+			},
+			connector: connector,
+		}
+
+		err = daemon.ensureWatchingLeasefile(t.Context(), &config, 10)
+
+		require.NoError(t, err)
+		require.False(t, gock.HasUnmatchedRequest())
+	})
+	// Call the function twice, once to start watching a file, and then again to switch to a different file. There should be no errors.
+	t.Run("dhcp6 change file", func(t *testing.T) {
+		sb := testutil.NewSandbox()
+		defer sb.Close()
+
+		config := keaconfig.Config{
+			DHCPv6Config: &keaconfig.DHCPv6Config{
+				CommonDHCPConfig: keaconfig.CommonDHCPConfig{
+					LeaseDatabase: &keaconfig.Database{
+						Type: "memfile",
+					},
+				},
+			},
+		}
+		defer gock.Off()
+
+		leasefile1, err := sb.Join("kea-leases6")
+		require.NoError(t, err)
+		leasefile2, err := sb.Join("kea-leases6")
+		require.NoError(t, err)
+
+		dhcpV6ResponsesJSONTemplate := `[
+			{
+				"result": 0,
+				"arguments": {
+					"csv-lease-file": "%s"
+				}
+			}
+		]`
+		dhcpV6ResponsesJSON1 := fmt.Sprintf(dhcpV6ResponsesJSONTemplate, leasefile1)
+		dhcpV6ResponsesJSON2 := fmt.Sprintf(dhcpV6ResponsesJSONTemplate, leasefile2)
+		err = makeKeaCommandMock("dhcp6", dhcpV6ResponsesJSON1, 1)
+		require.NoError(t, err)
+		err = makeKeaCommandMock("dhcp6", dhcpV6ResponsesJSON2, 1)
+		require.NoError(t, err)
+
+		accessPoint := AccessPoint{
+			Type:     AccessPointControl,
+			Address:  "localhost",
+			Port:     45634,
+			Protocol: protocoltype.HTTP,
+		}
+		connector := newKeaConnector(
+			accessPoint,
+			HTTPClientConfig{Interceptor: gock.InterceptClient},
+		)
+
+		daemon := &keaDaemon{
+			daemon: daemon{
+				Name:         daemonname.DHCPv6,
+				AccessPoints: []AccessPoint{accessPoint},
+			},
+			connector: connector,
+		}
+
+		err = daemon.ensureWatchingLeasefile(t.Context(), &config, 10)
+		require.NoError(t, err)
+		err = daemon.ensureWatchingLeasefile(t.Context(), &config, 10)
+		require.NoError(t, err)
+
+		require.False(t, gock.HasUnmatchedRequest())
+	})
+	// Call the function twice, once to start watching a lease file and again to
+	// stop watching it (because Kea was switched to a SQL database lease backend).
+	// There should be no errors.
+	t.Run("dhcp6 stop watching", func(t *testing.T) {
+		sb := testutil.NewSandbox()
+		defer sb.Close()
+
+		config1 := keaconfig.Config{
+			DHCPv6Config: &keaconfig.DHCPv6Config{
+				CommonDHCPConfig: keaconfig.CommonDHCPConfig{
+					LeaseDatabase: &keaconfig.Database{
+						Type: "memfile",
+					},
+				},
+			},
+		}
+		config2 := keaconfig.Config{
+			DHCPv6Config: &keaconfig.DHCPv6Config{
+				CommonDHCPConfig: keaconfig.CommonDHCPConfig{
+					LeaseDatabase: &keaconfig.Database{
+						Type: "mysql",
+					},
+				},
+			},
+		}
+		defer gock.Off()
+
+		leasefile, err := sb.Join("kea-leases6")
+		require.NoError(t, err)
+
+		dhcpV6ResponsesJSONTemplate := `[
+			{
+				"result": 0,
+				"arguments": {
+					"csv-lease-file": "%s"
+				}
+			}
+		]`
+		dhcpV6ResponsesJSON1 := fmt.Sprintf(dhcpV6ResponsesJSONTemplate, leasefile)
+		err = makeKeaCommandMock("dhcp6", dhcpV6ResponsesJSON1, 2)
+		require.NoError(t, err)
+
+		accessPoint := AccessPoint{
+			Type:     AccessPointControl,
+			Address:  "localhost",
+			Port:     45634,
+			Protocol: protocoltype.HTTP,
+		}
+		connector := newKeaConnector(
+			accessPoint,
+			HTTPClientConfig{Interceptor: gock.InterceptClient},
+		)
+
+		daemon := &keaDaemon{
+			daemon: daemon{
+				Name:         daemonname.DHCPv6,
+				AccessPoints: []AccessPoint{accessPoint},
+			},
+			connector: connector,
+		}
+
+		err = daemon.ensureWatchingLeasefile(t.Context(), &config1, 10)
+		require.NoError(t, err)
+		err = daemon.ensureWatchingLeasefile(t.Context(), &config2, 10)
+		require.NoError(t, err)
+
+		require.False(t, gock.HasUnmatchedRequest())
+	})
+	// Call the function once with memfile mode on, but persist set to false, to
+	// ensure that nothing breaks when you turn off persistence.
+	t.Run("dhcp6 persist false", func(t *testing.T) {
+		sb := testutil.NewSandbox()
+		defer sb.Close()
+
+		nopersist := false
+		config := keaconfig.Config{
+			DHCPv6Config: &keaconfig.DHCPv6Config{
+				CommonDHCPConfig: keaconfig.CommonDHCPConfig{
+					LeaseDatabase: &keaconfig.Database{
+						Type:    "memfile",
+						Persist: &nopersist,
+					},
+				},
+			},
+		}
+		defer gock.Off()
+
+		leasefile, err := sb.Join("kea-leases6")
+		require.NoError(t, err)
+
+		dhcpV6ResponsesJSONTemplate := `[
+			{
+				"result": 0,
+				"arguments": {
+					"csv-lease-file": "%s"
+				}
+			}
+		]`
+		dhcpV6ResponsesJSON1 := fmt.Sprintf(dhcpV6ResponsesJSONTemplate, leasefile)
+		err = makeKeaCommandMock("dhcp6", dhcpV6ResponsesJSON1, 1)
+		require.NoError(t, err)
+
+		accessPoint := AccessPoint{
+			Type:     AccessPointControl,
+			Address:  "localhost",
+			Port:     45634,
+			Protocol: protocoltype.HTTP,
+		}
+		connector := newKeaConnector(
+			accessPoint,
+			HTTPClientConfig{Interceptor: gock.InterceptClient},
+		)
+
+		daemon := &keaDaemon{
+			daemon: daemon{
+				Name:         daemonname.DHCPv6,
+				AccessPoints: []AccessPoint{accessPoint},
+			},
+			connector: connector,
+		}
+
+		err = daemon.ensureWatchingLeasefile(t.Context(), &config, 10)
+		require.NoError(t, err)
+
+		require.False(t, gock.HasUnmatchedRequest())
+	})
+	// Call the function once with memfile mode on, but persist set to false, to
+	// ensure that nothing breaks when you turn off persistence.
+	t.Run("dhcp4 persist false", func(t *testing.T) {
+		sb := testutil.NewSandbox()
+		defer sb.Close()
+
+		nopersist := false
+		config := keaconfig.Config{
+			DHCPv4Config: &keaconfig.DHCPv4Config{
+				CommonDHCPConfig: keaconfig.CommonDHCPConfig{
+					LeaseDatabase: &keaconfig.Database{
+						Type:    "memfile",
+						Persist: &nopersist,
+					},
+				},
+			},
+		}
+		defer gock.Off()
+
+		leasefile, err := sb.Join("kea-leases4")
+		require.NoError(t, err)
+
+		dhcpV4ResponsesJSONTemplate := `[
+			{
+				"result": 0,
+				"arguments": {
+					"csv-lease-file": "%s"
+				}
+			}
+		]`
+		dhcpV4ResponsesJSON1 := fmt.Sprintf(dhcpV4ResponsesJSONTemplate, leasefile)
+		err = makeKeaCommandMock("dhcp4", dhcpV4ResponsesJSON1, 1)
+		require.NoError(t, err)
+
+		accessPoint := AccessPoint{
+			Type:     AccessPointControl,
+			Address:  "localhost",
+			Port:     45634,
+			Protocol: protocoltype.HTTP,
+		}
+		connector := newKeaConnector(
+			accessPoint,
+			HTTPClientConfig{Interceptor: gock.InterceptClient},
+		)
+
+		daemon := &keaDaemon{
+			daemon: daemon{
+				Name:         daemonname.DHCPv4,
+				AccessPoints: []AccessPoint{accessPoint},
+			},
+			connector: connector,
+		}
+
+		err = daemon.ensureWatchingLeasefile(t.Context(), &config, 10)
+		require.NoError(t, err)
+
+		require.False(t, gock.HasUnmatchedRequest())
+	})
+	// Call the function once and feed it a 500 error from Kea, to ensure that
+	// it handles the error gracefully and does not panic or otherwise take down the
+	// agent.
+	t.Run("fetch error", func(t *testing.T) {
+		config := keaconfig.Config{
+			DHCPv4Config: &keaconfig.DHCPv4Config{
+				CommonDHCPConfig: keaconfig.CommonDHCPConfig{
+					LeaseDatabase: &keaconfig.Database{
+						Type: "memfile",
+					},
+				},
+			},
+		}
+		defer gock.Off()
+
+		gock.New("http://localhost:45634").
+			MatchHeader("Content-Type", "application/json").
+			JSON(map[string]any{"command": "status-get", "service": []string{"dhcp4"}}).
+			Post("/").
+			Reply(500)
+
+		accessPoint := AccessPoint{
+			Type:     AccessPointControl,
+			Address:  "localhost",
+			Port:     45634,
+			Protocol: protocoltype.HTTP,
+		}
+		connector := newKeaConnector(
+			accessPoint,
+			HTTPClientConfig{Interceptor: gock.InterceptClient},
+		)
+
+		daemon := &keaDaemon{
+			daemon: daemon{
+				Name:         daemonname.DHCPv4,
+				AccessPoints: []AccessPoint{accessPoint},
+			},
+			connector: connector,
+		}
+
+		err := daemon.ensureWatchingLeasefile(t.Context(), &config, 10)
+		require.ErrorContains(t, err, "500")
+
+		require.False(t, gock.HasUnmatchedRequest())
+	})
+	// Call the function once and give it a default configuration, but with the
+	// value returned by get-status pointing to a file which doesn't exist. It
+	// should handle this gracefully, log it, and not take down the agent.
+	t.Run("dhcp4 persist true but csv-lease-file missing", func(t *testing.T) {
+		persist := true
+		config := keaconfig.Config{
+			DHCPv4Config: &keaconfig.DHCPv4Config{
+				CommonDHCPConfig: keaconfig.CommonDHCPConfig{
+					LeaseDatabase: &keaconfig.Database{
+						Type:    "memfile",
+						Persist: &persist,
+					},
+				},
+			},
+		}
+		defer gock.Off()
+
+		dhcpV4ResponsesJSON := `[
+			{
+				"result": 0,
+				"arguments": {}
+			}
+		]`
+		err := makeKeaCommandMock("dhcp4", dhcpV4ResponsesJSON, 1)
+		require.NoError(t, err)
+
+		accessPoint := AccessPoint{
+			Type:     AccessPointControl,
+			Address:  "localhost",
+			Port:     45634,
+			Protocol: protocoltype.HTTP,
+		}
+		connector := newKeaConnector(
+			accessPoint,
+			HTTPClientConfig{Interceptor: gock.InterceptClient},
+		)
+
+		daemon := &keaDaemon{
+			daemon: daemon{
+				Name:         daemonname.DHCPv4,
+				AccessPoints: []AccessPoint{accessPoint},
+			},
+			connector: connector,
+		}
+
+		err = daemon.ensureWatchingLeasefile(t.Context(), &config, 10)
+		require.ErrorContains(t, err, "status API did not return the path to the lease memfile")
+
+		require.False(t, gock.HasUnmatchedRequest())
+	})
+}
+
+// Test that resolveKeaSocketPath returns the correct socket path for different
+// Kea installation prefixes.
+func TestResolveKeaSocketPath(t *testing.T) {
+	t.Run("Standard Linux distribution (prefix /)", func(t *testing.T) {
+		// Arrange
+		socketFilename := "kea-dhcp4.socket"
+		keaExecutablePath := "/sbin/kea-dhcp4"
+
+		// Act
+		result := resolveKeaSocketPath(socketFilename, keaExecutablePath)
+
+		// Assert
+		require.Equal(t, "/var/run/kea/kea-dhcp4.socket", result)
+	})
+
+	t.Run("Prefix /usr", func(t *testing.T) {
+		// Arrange
+		socketFilename := "kea-dhcp4.socket"
+		keaExecutablePath := "/usr/sbin/kea-dhcp4"
+
+		// Act
+		result := resolveKeaSocketPath(socketFilename, keaExecutablePath)
+
+		// Assert
+		require.Equal(t, "/var/run/kea/kea-dhcp4.socket", result)
+	})
+
+	t.Run("Prefix /usr/local (BSDs, MacOS)", func(t *testing.T) {
+		// Arrange
+		socketFilename := "kea-dhcp4.socket"
+		keaExecutablePath := "/usr/local/sbin/kea-dhcp4"
+
+		// Act
+		result := resolveKeaSocketPath(socketFilename, keaExecutablePath)
+
+		// Assert
+		require.Equal(t, "/var/local/run/kea/kea-dhcp4.socket", result)
+	})
+
+	t.Run("Custom prefix /opt/kea", func(t *testing.T) {
+		// Arrange
+		socketFilename := "kea-dhcp4.socket"
+		keaExecutablePath := "/opt/kea/sbin/kea-dhcp4"
+
+		// Act
+		result := resolveKeaSocketPath(socketFilename, keaExecutablePath)
+
+		// Assert
+		require.Equal(t, "/opt/kea/var/run/kea/kea-dhcp4.socket", result)
+	})
+
+	t.Run("Custom prefix /home/user/kea", func(t *testing.T) {
+		// Arrange
+		socketFilename := "kea-ctrl-agent.socket"
+		keaExecutablePath := "/home/user/kea/bin/kea-ctrl-agent"
+
+		// Act
+		result := resolveKeaSocketPath(socketFilename, keaExecutablePath)
+
+		// Assert
+		require.Equal(t, "/home/user/kea/var/run/kea/kea-ctrl-agent.socket", result)
+	})
+
+	t.Run("DHCPv6 daemon socket", func(t *testing.T) {
+		// Arrange
+		socketFilename := "kea-dhcp6.socket"
+		keaExecutablePath := "/usr/sbin/kea-dhcp6"
+
+		// Act
+		result := resolveKeaSocketPath(socketFilename, keaExecutablePath)
+
+		// Assert
+		require.Equal(t, "/var/run/kea/kea-dhcp6.socket", result)
+	})
+
+	t.Run("DDNS daemon socket", func(t *testing.T) {
+		// Arrange
+		socketFilename := "kea-ddns.socket"
+		keaExecutablePath := "/usr/local/sbin/kea-dhcp-ddns"
+
+		// Act
+		result := resolveKeaSocketPath(socketFilename, keaExecutablePath)
+
+		// Assert
+		require.Equal(t, "/var/local/run/kea/kea-ddns.socket", result)
+	})
+}
