@@ -6,8 +6,7 @@ import (
 	"github.com/pkg/errors"
 	log "github.com/sirupsen/logrus"
 
-	agentapi "isc.org/stork/api"
-	keactrl "isc.org/stork/appctrl/kea"
+	keactrl "isc.org/stork/daemonctrl/kea"
 )
 
 // Structure containing a pointer to the callback function registered in
@@ -18,7 +17,7 @@ type keaInterceptorHandler struct {
 	callback func(*StorkAgent, *keactrl.Response) error
 }
 
-// Structure holding a collection of handlers/callabacks to be invoked
+// Structure holding a collection of handlers/callbacks to be invoked
 // for a given Kea command.
 type keaInterceptorTarget struct {
 	// List of callbacks to be invoked for a command.
@@ -102,7 +101,7 @@ func (i *keaInterceptor) registerSync(callback func(*StorkAgent, *keactrl.Respon
 // callback is invoked separately for each daemon which responded to the command.
 // The result of the callbacks may to affect the response forwarded to the Stork Server.
 // Synchronous handler is executed before asynchronous one.
-func (i *keaInterceptor) syncHandle(agent *StorkAgent, request *agentapi.KeaRequest, response []byte) ([]byte, error) {
+func (i *keaInterceptor) syncHandle(agent *StorkAgent, request keactrl.SerializableCommand, response keactrl.Response) (keactrl.Response, error) {
 	changedResponse, err := i.handle(i.syncTargets, agent, request, response)
 	err = errors.WithMessage(err, "Failed to execute synchronous handlers")
 	return changedResponse, err
@@ -114,7 +113,7 @@ func (i *keaInterceptor) syncHandle(agent *StorkAgent, request *agentapi.KeaRequ
 // which can be run independently from the agent. The agent may send back the
 // response to the server while these callbacks are invoked. The result of the
 // callbacks do not affect the response forwarded to the Stork Server.
-func (i *keaInterceptor) asyncHandle(agent *StorkAgent, request *agentapi.KeaRequest, response []byte) {
+func (i *keaInterceptor) asyncHandle(agent *StorkAgent, request keactrl.SerializableCommand, response keactrl.Response) {
 	// We don't want to run the handlers concurrently in case they update the same
 	// data structures. Also, we want to avoid registration of handlers while we're
 	// here.
@@ -123,64 +122,44 @@ func (i *keaInterceptor) asyncHandle(agent *StorkAgent, request *agentapi.KeaReq
 
 	_, err := i.handle(i.asyncTargets, agent, request, response)
 	if err != nil {
-		log.Errorf("Failed to execute asynchronous handler: %+v", err)
+		log.WithError(err).Error("Failed to execute asynchronous handler")
 	}
 }
 
 // Common part of asynchronous and synchronous handlers. Returns the serialized
 // response after modifications performed by callbacks or error.
-func (i *keaInterceptor) handle(targets map[keactrl.CommandName]*keaInterceptorTarget, agent *StorkAgent, request *agentapi.KeaRequest, response []byte) ([]byte, error) {
-	// Parse the request to get the command name and service.
-	command, err := keactrl.NewCommandFromJSON(request.Request)
-	if err != nil {
-		err = errors.WithMessage(err, "Failed to parse Kea command")
-		return nil, err
-	}
-
+func (i *keaInterceptor) handle(targets map[keactrl.CommandName]*keaInterceptorTarget, agent *StorkAgent, command keactrl.SerializableCommand, response keactrl.Response) (keactrl.Response, error) {
 	// Check if there is any handler registered for this command.
-	target, ok := targets[command.Command]
+	target, ok := targets[command.GetCommand()]
 	if !ok {
 		return response, nil
 	}
 
-	// Parse the response. It will be passed to the callback so as the callback
-	// can "do something" with it.
-	var parsedResponse keactrl.ResponseList
-	err = keactrl.UnmarshalResponseList(command, response, &parsedResponse)
-	if err != nil {
-		err = errors.WithMessagef(err, "Failed to parse Kea responses for command %s", command.Command)
-		return nil, err
+	// Check what daemons the callbacks need to be invoked for.
+	daemons := command.GetDaemonsList()
+	switch len(daemons) {
+	case 0:
+		// No daemon specified, this field is required by Stork agent.
+		return keactrl.Response{}, errors.Errorf("no daemon specified in the command %s", command.GetCommand())
+	case 1:
+		// Only one daemon specified, so we can proceed.
+	default:
+		// More than one daemon specified. This is not supported.
+		return keactrl.Response{}, errors.Errorf("multiple daemons specified in the command %s", command.GetCommand())
 	}
 
-	// Check what daemons the callbacks need to be invoked for.
-	var daemons []keactrl.DaemonName
-	if len(command.Daemons) == 0 {
-		daemons = append(daemons, "ca")
-	} else {
-		daemons = command.Daemons
-	}
 	// Invoke callbacks for each handler registered for this command.
+	processedResponse := response
 	for i := range target.handlers {
-		// Invoke the handler for each daemon.
-		for j := range daemons {
-			if j < len(parsedResponse) {
-				callback := target.handlers[i].callback
-				if callback != nil {
-					err = callback(agent, &parsedResponse[j])
-					if err != nil {
-						err = errors.WithMessagef(err, "Callback returned an error for command %s", command.Command)
-						return nil, err
-					}
-				}
+		// Invoke the handler.
+		callback := target.handlers[i].callback
+		if callback != nil {
+			err := callback(agent, &processedResponse)
+			if err != nil {
+				err = errors.WithMessagef(err, "Callback returned an error for command %s", command.GetCommand())
+				return keactrl.Response{}, err
 			}
 		}
 	}
-
-	// Serialize response after modifications.
-	response, err = keactrl.MarshalResponseList(parsedResponse)
-	if err != nil {
-		err = errors.WithMessagef(err, "Failed to marshal changed responses for command %s", command.Command)
-		return nil, err
-	}
-	return response, nil
+	return processedResponse, nil
 }
