@@ -19,9 +19,10 @@ import (
 // Operations provided by the Stork agent to set up daemon-related configuration.
 type agentManager interface {
 	allowLog(path string)
+	allowLeaseTracking() (bool, int)
 }
 
-// An access point for an application to retrieve information such
+// An access point for a daemon to retrieve information such
 // as status or metrics.
 type AccessPoint struct {
 	Type     string
@@ -66,10 +67,16 @@ const (
 
 type Daemon interface {
 	GetName() daemonname.Name
+	// Returns a first access point of a given type. If the access point is not
+	// found, it returns nil.
 	GetAccessPoint(apType string) *AccessPoint
+	// Returns all access points of the daemon. There may be multiple access
+	// points of the same type.
 	GetAccessPoints() []AccessPoint
-	// Checks if data of two daemons are equal.
-	IsEqual(other Daemon) bool
+	// Checks if two daemon instances are the same. It is used to determine
+	// whether the newly detected daemon is the same as the previously detected
+	// daemon. In that case, the detected daemon is ignored.
+	IsSame(other Daemon) bool
 	// Called when the monitor newly detects the daemon.
 	// It allows the daemon to perform initialization tasks
 	// such as starting a background goroutine.
@@ -128,9 +135,9 @@ func (d *daemon) String() string {
 	return b.String()
 }
 
-// Checks if two applications are the same. It checks the name and access
+// Checks if two daemons are the same. It checks the name and access
 // points including their configuration.
-func (d *daemon) IsEqual(other Daemon) bool {
+func (d *daemon) IsSame(other Daemon) bool {
 	if d.Name != other.GetName() {
 		return false
 	}
@@ -140,11 +147,10 @@ func (d *daemon) IsEqual(other Daemon) bool {
 		return false
 	}
 
-	for _, otherAccessPoint := range otherAccessPoints {
-		thisAccessPoint := d.GetAccessPoint(otherAccessPoint.Type)
-		if thisAccessPoint == nil {
-			return false
-		}
+	// It is expected that the access points are always detected in the same
+	// order.
+	for i, otherAccessPoint := range otherAccessPoints {
+		thisAccessPoint := d.AccessPoints[i]
 		if !thisAccessPoint.IsEqual(otherAccessPoint) {
 			return false
 		}
@@ -155,13 +161,24 @@ func (d *daemon) IsEqual(other Daemon) bool {
 // An interface representing the DNS daemon.
 type dnsDaemon interface {
 	Daemon
+	isSame(other dnsDaemon) bool
 	getZoneInventory() zoneInventory
+	getDetectedFiles() *detectedDaemonFiles
 }
 
 // An implementation providing common functionality for DNS daemons.
 type dnsDaemonImpl struct {
 	daemon
 	zoneInventory zoneInventory
+	detectedFiles *detectedDaemonFiles
+}
+
+// Checks if the embedded daemon instance has the same name and access points
+// as the other daemon instance, and that the detected files are the same as
+// well. It includes checking the paths, modification times, and sizes of the
+// files.
+func (d *dnsDaemonImpl) isSame(other dnsDaemon) bool {
+	return other != nil && d.IsSame(other) && d.getDetectedFiles().isSame(other.getDetectedFiles())
 }
 
 // Returns the zone inventory.
@@ -169,6 +186,11 @@ func (d *dnsDaemonImpl) getZoneInventory() zoneInventory {
 	return d.zoneInventory
 }
 
+// Returns the files associated with the detected daemon (e.g., configuration files).
+func (d *dnsDaemonImpl) getDetectedFiles() *detectedDaemonFiles {
+	return d.detectedFiles
+}
+
 // Bootstrap the DNS daemon. It starts the zone inventory if available.
 func (d *dnsDaemonImpl) Bootstrap() error {
 	if d.zoneInventory != nil {
@@ -232,11 +254,17 @@ type monitor struct {
 	daemons []Daemon
 }
 
-// Creates an Monitor instance. It used to start it as well, but this is now done
+// Returns an exported interface to the monitor. It used to start it as well, but this is now done
 // by a dedicated method Start(). Make sure you call Start() before using daemon
 // monitor.
 func NewMonitor(explicitBind9ConfigPath string, explicitPowerDNSConfigPath string, keaHTTPClientConfig HTTPClientConfig) Monitor {
-	sm := &monitor{
+	return newMonitor(explicitBind9ConfigPath, explicitPowerDNSConfigPath, keaHTTPClientConfig)
+}
+
+// Creates a new monitor instance. It is used internally by the NewMonitor function and
+// in the tests.
+func newMonitor(explicitBind9ConfigPath string, explicitPowerDNSConfigPath string, keaHTTPClientConfig HTTPClientConfig) *monitor {
+	return &monitor{
 		requests:                   make(chan chan []Daemon),
 		quit:                       make(chan bool),
 		wg:                         &sync.WaitGroup{},
@@ -250,7 +278,6 @@ func NewMonitor(explicitBind9ConfigPath string, explicitPowerDNSConfigPath strin
 		running:                    false,
 		daemons:                    nil,
 	}
-	return sm
 }
 
 // This function starts the actual monitor. This start is delayed in case we want to only
@@ -324,12 +351,21 @@ func splitDaemonsByTransition(previous, next []Daemon) (started, unchanged, unch
 
 	for ip, p := range previous {
 		for in, n := range next {
-			if p.IsEqual(n) {
+			// The daemon detecting functions may reuse existing daemon instances
+			// when configuration files appear to not have changed. In this case,
+			// instead of checking if the daemons are the same (that involves some
+			// IO operations), it is enough to say if the daemons have equal pointers.
+			if p == n || p.IsSame(n) {
 				// Daemon is still running.
 				stoppedMap[ip] = false
 				startedMap[in] = false
 				unchangedMap[ip] = true
-				unchangedDuplicatedMap[in] = true
+				if p != n {
+					// Only stop the duplicated daemon if it is not the same
+					// as the unchanged daemon. Otherwise, we'd stop the unchanged
+					// daemon.
+					unchangedDuplicatedMap[in] = true
+				}
 				break
 			}
 		}
@@ -377,7 +413,7 @@ func (sm *monitor) detectDaemons(ctx context.Context) {
 		switch daemonName {
 		case daemonname.DHCPv4, daemonname.DHCPv6, daemonname.D2, daemonname.CA:
 			// Kea DHCP server.
-			detectedDaemons, err := detectKeaDaemons(ctx, p, sm.keaHTTPClientConfig, sm.commander)
+			detectedDaemons, err := sm.detectKeaDaemons(ctx, p)
 			if err != nil {
 				log.WithField("daemon", daemonName).WithError(err).Warn("Failed to detect Kea daemon(s)")
 				continue
@@ -386,12 +422,7 @@ func (sm *monitor) detectDaemons(ctx context.Context) {
 
 		case daemonname.Bind9:
 			// BIND 9 DNS server.
-			detectedDaemon, err := detectBind9Daemon(
-				p,
-				sm.commander,
-				sm.explicitBind9ConfigPath,
-				sm.bind9FileParser,
-			)
+			detectedDaemon, err := sm.detectBind9Daemon(p)
 			if err != nil {
 				log.WithError(err).Warnf("Failed to detect BIND 9 DNS server daemon")
 				continue
@@ -399,7 +430,7 @@ func (sm *monitor) detectDaemons(ctx context.Context) {
 			daemons = append(daemons, detectedDaemon)
 		case daemonname.PDNS:
 			// PowerDNS server.
-			detectedDaemon, err := detectPowerDNSDaemon(p, sm.commander, sm.pdnsConfigParser, sm.explicitPowerDNSConfigPath)
+			detectedDaemon, err := sm.detectPowerDNSDaemon(p)
 			if err != nil {
 				log.WithError(err).Warn("Failed to detect PowerDNS server daemon")
 				continue
