@@ -61,7 +61,7 @@ func TestGetDaemons(t *testing.T) {
 	monitor := NewMonitor("", "", HTTPClientConfig{})
 	hm := NewHookManager()
 	bind9StatsClient := NewBind9StatsClient()
-	sa := NewStorkAgent("foo", 42, monitor, bind9StatsClient, hm)
+	sa := NewStorkAgent("foo", 42, monitor, bind9StatsClient, hm, false, 0)
 	monitor.Start(t.Context(), sa)
 	daemons := monitor.GetDaemons()
 	require.Len(t, daemons, 0)
@@ -290,10 +290,10 @@ func TestDetectDaemons(t *testing.T) {
 	}
 
 	// Create fake daemon for which the zone inventory should be stopped
-	// when new apps are detected.
+	// when new daemons are detected.
 	fakeDaemon := NewMockDaemon(ctrl)
 	fakeDaemon.EXPECT().Cleanup().Times(1)
-	fakeDaemon.EXPECT().IsEqual(gomock.Any()).AnyTimes().Return(false)
+	fakeDaemon.EXPECT().IsSame(gomock.Any()).AnyTimes().Return(false)
 	fakeDaemon.EXPECT().String().AnyTimes().Return("fake-daemon")
 
 	monitor.daemons = append(monitor.daemons, fakeDaemon)
@@ -311,7 +311,7 @@ func TestDetectDaemons(t *testing.T) {
 	require.Equal(t, daemonname.Bind9, daemons[1].GetName())
 	require.Equal(t, daemonname.PDNS, daemons[2].GetName())
 
-	// Detect tha apps again. The zone inventory should be preserved.
+	// Detect tha daemons again. The zone inventory should be preserved.
 	monitor.detectDaemons(t.Context())
 	daemons2 := monitor.daemons
 	sort.Slice(daemons2, func(i, j int) bool {
@@ -340,7 +340,12 @@ func TestDetectDaemons(t *testing.T) {
 		}
 	}
 
-	// Redetect apps. It should result in recreating the zone inventory.
+	// Also, emulate the size change of the configuration files to ensure
+	// that the new daemon instances are used.
+	commander.addFileInfo("/etc/named.conf", &testFileInfo{size: 200})
+	commander.addFileInfo("/etc/powerdns/pdns.conf", &testFileInfo{size: 200})
+
+	// Redetect daemons. It should result in recreating the zone inventory.
 	monitor.detectDaemons(t.Context())
 	daemons3 := monitor.daemons
 	sort.Slice(daemons3, func(i, j int) bool {
@@ -366,7 +371,8 @@ func TestDetectDaemonsConfigNoStatistics(t *testing.T) {
 	// Prepare the command executor.
 	executor := newTestCommandExecutor().
 		addCheckConfOutput("/etc/named.conf", bind9ConfigWithoutStatistics).
-		setConfigPathInNamedOutput("/etc/named.conf")
+		setConfigPathInNamedOutput("/etc/named.conf").
+		addFileInfo("/etc/named.conf", &testFileInfo{})
 
 	// Prepare process mocks.
 	ctrl := gomock.NewController(t)
@@ -398,7 +404,7 @@ func TestDetectDaemonsConfigNoStatistics(t *testing.T) {
 	fakeDaemon := NewMockDaemon(ctrl)
 	fakeDaemon.EXPECT().RefreshState(gomock.Any(), gomock.Any()).AnyTimes()
 	fakeDaemon.EXPECT().Cleanup().Times(1)
-	fakeDaemon.EXPECT().IsEqual(gomock.Any()).AnyTimes().Return(false)
+	fakeDaemon.EXPECT().IsSame(gomock.Any()).AnyTimes().Return(false)
 	fakeDaemon.EXPECT().String().AnyTimes().Return("fake-daemon")
 
 	monitor.daemons = append(monitor.daemons, fakeDaemon)
@@ -504,10 +510,10 @@ func TestDetectDaemonsSkipOnNotAvailableCwd(t *testing.T) {
 }
 
 // The monitor periodically searches for the Kea/Bind9 instances. Usually, at
-// least one application should be available. If no monitored daemon is found,
+// least one daemon should be available. If no monitored daemon is found,
 // the Stork prints the warning message to indicate that something unexpected
 // happened.
-func TestDetectAppsNoAppDetectedWarning(t *testing.T) {
+func TestDetectDaemonsNoDaemonDetectedWarning(t *testing.T) {
 	// Arrange
 	// Prepare logger.
 	output := logrus.StandardLogger().Out
@@ -554,7 +560,7 @@ func TestDetectAllowedLogsKeaUnreachable(t *testing.T) {
 	})
 
 	hm := NewHookManager()
-	sa := NewStorkAgent("foo", 42, monitor, bind9StatsClient, hm)
+	sa := NewStorkAgent("foo", 42, monitor, bind9StatsClient, hm, false, 0)
 
 	require.NotPanics(t, func() { monitor.refreshDaemons(t.Context(), sa) })
 }
@@ -564,7 +570,9 @@ func TestDetectAllowedLogsKeaUnreachable(t *testing.T) {
 func newTestCommandExecutorDefault() *testCommandExecutor {
 	return newTestCommandExecutor().
 		addCheckConfOutput("/etc/named.conf", defaultBind9Config).
-		setConfigPathInNamedOutput("/etc/named.conf")
+		setConfigPathInNamedOutput("/etc/named.conf").
+		addFileInfo("/etc/named.conf", &testFileInfo{}).
+		addFileInfo("/etc/powerdns/pdns.conf", &testFileInfo{})
 }
 
 // Check BIND 9 daemon detection when its conf file is absolute path.
@@ -573,16 +581,22 @@ func TestDetectBind9DaemonAbsPath(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
+	monitor := newMonitor("", "", HTTPClientConfig{})
+
 	parser := NewMockBind9FileParser(ctrl)
 	parser.EXPECT().ParseFile("/etc/named.conf", "").AnyTimes().DoAndReturn(func(configPath string, _ string) (*bind9config.Config, error) {
 		return bind9config.NewParser().Parse(configPath, "", strings.NewReader(defaultBind9Config))
 	})
+	monitor.bind9FileParser = parser
+
 	process := NewMockSupportedProcess(ctrl)
 	process.EXPECT().getCmdline().Return("/dir/named -c /etc/named.conf", nil)
 	process.EXPECT().getCwd().Return("", nil)
 	process.EXPECT().getPid().Return(int32(1234))
-	executor := newTestCommandExecutorDefault()
-	daemon, err := detectBind9Daemon(process, executor, "", parser)
+
+	monitor.commander = newTestCommandExecutorDefault()
+
+	daemon, err := monitor.detectBind9Daemon(process)
 	require.NoError(t, err)
 	require.NotNil(t, daemon)
 	require.Equal(t, daemonname.Bind9, daemon.GetName())
@@ -604,16 +618,20 @@ func TestDetectBind9DaemonRelativePath(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
+	monitor := newMonitor("", "", HTTPClientConfig{})
+
 	parser := NewMockBind9FileParser(ctrl)
 	parser.EXPECT().ParseFile("/etc/named.conf", "").AnyTimes().DoAndReturn(func(configPath string, _ string) (*bind9config.Config, error) {
 		return bind9config.NewParser().Parse(configPath, "", strings.NewReader(defaultBind9Config))
 	})
-	executor := newTestCommandExecutorDefault()
+	monitor.bind9FileParser = parser
+
 	process := NewMockSupportedProcess(ctrl)
 	process.EXPECT().getCmdline().Return("/dir/named -c named.conf", nil)
 	process.EXPECT().getCwd().Return("/etc", nil)
 	process.EXPECT().getPid().Return(int32(1234))
-	daemon, err := detectBind9Daemon(process, executor, "", parser)
+	monitor.commander = newTestCommandExecutorDefault()
+	daemon, err := monitor.detectBind9Daemon(process)
 	require.NoError(t, err)
 	require.NotNil(t, daemon)
 	require.Equal(t, daemonname.Bind9, daemon.GetName())
@@ -682,6 +700,9 @@ func TestDetectKeaDaemon(t *testing.T) {
 	httpClientConfig := HTTPClientConfig{}
 	commander := newTestCommandExecutorDefault()
 
+	monitor := newMonitor("", "", httpClientConfig)
+	monitor.commander = commander
+
 	t.Run("config file without include statement", func(t *testing.T) {
 		tmpFilePath, clean := makeKeaConfFile()
 		defer clean()
@@ -695,7 +716,7 @@ func TestDetectKeaDaemon(t *testing.T) {
 		process.EXPECT().getDaemonName().Return(daemonname.CA)
 		process.EXPECT().getCmdline().Return(fmt.Sprintf("/usr/bin/kea-ctrl-agent -c %s", tmpFilePath), nil)
 		process.EXPECT().getCwd().Return("", nil)
-		daemon, err := detectKeaDaemons(t.Context(), process, httpClientConfig, commander)
+		daemon, err := monitor.detectKeaDaemons(t.Context(), process)
 		require.NoError(t, err)
 		checkDaemon(daemon)
 
@@ -705,7 +726,7 @@ func TestDetectKeaDaemon(t *testing.T) {
 		process.EXPECT().getDaemonName().Return(daemonname.CA)
 		process.EXPECT().getCmdline().Return(fmt.Sprintf("kea-ctrl-agent -c %s", file), nil)
 		process.EXPECT().getCwd().Return(cwd, nil)
-		daemon, err = detectKeaDaemons(t.Context(), process, httpClientConfig, commander)
+		daemon, err = monitor.detectKeaDaemons(t.Context(), process)
 		require.NoError(t, err)
 		checkDaemon(daemon)
 	})
@@ -724,7 +745,7 @@ func TestDetectKeaDaemon(t *testing.T) {
 		process.EXPECT().getCmdline().Return(fmt.Sprintf("/usr/bin/kea-ctrl-agent -c %s", tmpFilePath), nil)
 		process.EXPECT().getCwd().Return("", nil)
 
-		daemon, err := detectKeaDaemons(t.Context(), process, httpClientConfig, commander)
+		daemon, err := monitor.detectKeaDaemons(t.Context(), process)
 		require.NoError(t, err)
 		checkDaemon(daemon)
 
@@ -734,7 +755,7 @@ func TestDetectKeaDaemon(t *testing.T) {
 		process.EXPECT().getDaemonName().Return(daemonname.CA)
 		process.EXPECT().getCmdline().Return(fmt.Sprintf("kea-ctrl-agent -c %s", file), nil)
 		process.EXPECT().getCwd().Return(cwd, nil)
-		daemon, err = detectKeaDaemons(t.Context(), process, httpClientConfig, commander)
+		daemon, err = monitor.detectKeaDaemons(t.Context(), process)
 		require.NoError(t, err)
 		checkDaemon(daemon)
 	})
@@ -821,7 +842,7 @@ func TestDaemonGetAccessPoint(t *testing.T) {
 }
 
 // Test that the daemon can be compared by their overall content.
-func TestDaemonEqual(t *testing.T) {
+func TestDaemonIsSame(t *testing.T) {
 	// Arrange
 	daemon1 := &keaDaemon{
 		daemon: daemon{
@@ -867,18 +888,42 @@ func TestDaemonEqual(t *testing.T) {
 			},
 		},
 	}
+	daemon6 := &keaDaemon{
+		daemon: daemon{
+			Name: daemonname.CA,
+			AccessPoints: []AccessPoint{
+				{Type: AccessPointStatistics, Address: "localhost", Port: 1235},
+				{Type: AccessPointControl, Address: "localhost", Port: 1234},
+			},
+		},
+	}
+	daemon7 := &keaDaemon{
+		daemon: daemon{
+			Name: daemonname.CA,
+			AccessPoints: []AccessPoint{
+				{Type: AccessPointStatistics, Address: "localhost", Port: 1235},
+				{Type: AccessPointControl, Address: "localhost", Port: 1234},
+				{Type: AccessPointControl, Address: "example.com", Port: 1234},
+			},
+		},
+	}
 
 	// Act & Assert
 	// Same daemon names and access points.
-	require.True(t, daemon1.IsEqual(daemon2))
+	require.True(t, daemon1.IsSame(daemon2))
 	// Different daemon names but the same access points.
-	require.False(t, daemon1.IsEqual(daemon3))
+	require.False(t, daemon1.IsSame(daemon3))
 	// Same daemon names, and the same access point location but different
 	// configuration.
-	require.False(t, daemon1.IsEqual(daemon4))
+	require.False(t, daemon1.IsSame(daemon4))
 	// The second daemon has the same daemon name and includes the access
 	// points from the first daemon but it has an additional access point.
-	require.False(t, daemon1.IsEqual(daemon5))
+	require.False(t, daemon1.IsSame(daemon5))
+	// The same daemon names and access points but in different order.
+	require.False(t, daemon5.IsSame(daemon6))
+	// The same daemon names and access points but with an additional access
+	// point with duplicate type.
+	require.False(t, daemon6.IsSame(daemon7))
 }
 
 // Test that the DNS zone inventories are successfully populated.
