@@ -10,11 +10,145 @@ import (
 	gomock "go.uber.org/mock/gomock"
 	pdnsconfig "isc.org/stork/daemoncfg/pdns"
 	"isc.org/stork/datamodel/daemonname"
+	"isc.org/stork/datamodel/protocoltype"
 )
 
 //go:generate mockgen -package=agent -destination=pdnsconfigparsermock_test.go -mock_names=pdnsConfigParser=MockPDNSConfigParser isc.org/stork/agent pdnsConfigParser
 //go:generate mockgen -package=agent -destination=commandexecutormock_test.go -mock_names=commandExecutor=MockCommandExecutor isc.org/stork/util CommandExecutor
 
+// Test that the function correctly checks if two PowerDNS daemons are the same.
+// Note that it is not checking them for equality. It merely checks if they
+// represent the same daemon in terms of their name, access points, and detected
+// files.
+func TestPowerDNSDaemonIsSame(t *testing.T) {
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+
+	executor := NewMockCommandExecutor(ctrl)
+	executor.EXPECT().GetFileInfo("/etc/pdns.conf").AnyTimes().Return(&testFileInfo{}, nil)
+
+	detectedFiles := newDetectedDaemonFiles("", "")
+	err := detectedFiles.addFile(detectedFileTypeConfig, "/etc/pdns.conf", executor)
+	require.NoError(t, err)
+
+	comparedDaemon := &pdnsDaemon{
+		dnsDaemonImpl: dnsDaemonImpl{
+			daemon: daemon{
+				Name: daemonname.PDNS,
+				AccessPoints: []AccessPoint{
+					{
+						Type:     AccessPointControl,
+						Address:  "127.0.0.1",
+						Port:     8081,
+						Protocol: protocoltype.HTTP,
+					},
+				},
+			},
+			detectedFiles: detectedFiles,
+		},
+	}
+
+	t.Run("same daemon", func(t *testing.T) {
+		otherDaemon := &pdnsDaemon{
+			dnsDaemonImpl: dnsDaemonImpl{
+				daemon: daemon{
+					Name: daemonname.PDNS,
+					AccessPoints: []AccessPoint{
+						{
+							Type:     AccessPointControl,
+							Address:  "127.0.0.1",
+							Port:     8081,
+							Protocol: protocoltype.HTTP,
+						},
+					},
+				},
+				detectedFiles: detectedFiles,
+			},
+		}
+		require.True(t, comparedDaemon.IsSame(otherDaemon))
+	})
+
+	t.Run("different daemon name", func(t *testing.T) {
+		otherDaemon := &pdnsDaemon{
+			dnsDaemonImpl: dnsDaemonImpl{
+				daemon: daemon{
+					Name: daemonname.Bind9,
+					AccessPoints: []AccessPoint{
+						{
+							Type:     AccessPointControl,
+							Address:  "127.0.0.1",
+							Port:     8081,
+							Protocol: protocoltype.HTTP,
+						},
+					},
+				},
+				detectedFiles: detectedFiles,
+			},
+		}
+		require.False(t, comparedDaemon.IsSame(otherDaemon))
+	})
+
+	t.Run("different access points", func(t *testing.T) {
+		otherDaemon := &pdnsDaemon{
+			dnsDaemonImpl: dnsDaemonImpl{
+				daemon: daemon{
+					Name: daemonname.PDNS,
+					AccessPoints: []AccessPoint{
+						{
+							Type:     AccessPointControl,
+							Address:  "127.0.0.1",
+							Port:     8082,
+							Protocol: protocoltype.HTTP,
+						},
+					},
+				},
+				detectedFiles: detectedFiles,
+			},
+		}
+		require.False(t, comparedDaemon.IsSame(otherDaemon))
+	})
+
+	t.Run("different detected files", func(t *testing.T) {
+		otherDaemon := &pdnsDaemon{
+			dnsDaemonImpl: dnsDaemonImpl{
+				daemon: daemon{
+					Name: daemonname.PDNS,
+					AccessPoints: []AccessPoint{
+						{
+							Type:     AccessPointControl,
+							Address:  "127.0.0.1",
+							Port:     8081,
+							Protocol: protocoltype.HTTP,
+						},
+					},
+				},
+				detectedFiles: nil,
+			},
+		}
+		require.False(t, comparedDaemon.IsSame(otherDaemon))
+	})
+
+	t.Run("not a PowerDNS daemon", func(t *testing.T) {
+		otherDaemon := &Bind9Daemon{
+			dnsDaemonImpl: dnsDaemonImpl{
+				daemon: daemon{
+					Name: daemonname.Bind9,
+					AccessPoints: []AccessPoint{
+						{
+							Type:     AccessPointControl,
+							Address:  "127.0.0.1",
+							Port:     8081,
+							Protocol: protocoltype.HTTP,
+						},
+					},
+				},
+				detectedFiles: detectedFiles,
+			},
+		}
+		require.False(t, comparedDaemon.IsSame(otherDaemon))
+	})
+}
+
 // Test that the daemon structure can be accessed.
 func TestPowerDNSDaemonGetBaseDaemon(t *testing.T) {
 	daemon := &pdnsDaemon{
@@ -84,7 +218,11 @@ func TestPowerDNSDaemonCmdLineError(t *testing.T) {
 	process.EXPECT().getCmdline().Return("", errors.New("test error"))
 
 	executor := NewMockCommandExecutor(ctrl)
-	configPath, err := detectPowerDNSConfigPath(process, executor, "")
+
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
+
+	configPath, err := monitor.detectPowerDNSConfigPath(process)
 	require.Error(t, err)
 	require.ErrorContains(t, err, "test error")
 	require.Nil(t, configPath)
@@ -104,8 +242,13 @@ func TestDetectPowerDNSDaemon(t *testing.T) {
 	})
 
 	executor := NewMockCommandExecutor(ctrl)
+	executor.EXPECT().GetFileInfo("/etc/pdns.conf").Return(&testFileInfo{}, nil)
 
-	daemon, err := detectPowerDNSDaemon(process, executor, parser, "")
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.pdnsConfigParser = parser
+	monitor.commander = executor
+
+	daemon, err := monitor.detectPowerDNSDaemon(process)
 	require.NoError(t, err)
 	require.NotNil(t, daemon)
 
@@ -134,11 +277,15 @@ func TestDetectPowerDNSDaemonNoConfigDir(t *testing.T) {
 	executor.EXPECT().IsFileExist(gomock.Any()).DoAndReturn(func(path string) bool {
 		return path == "/etc/powerdns/pdns.conf"
 	})
+	executor.EXPECT().GetFileInfo("/etc/powerdns/pdns.conf").Return(&testFileInfo{}, nil)
 
-	configPath, err := detectPowerDNSConfigPath(process, executor, "")
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.NoError(t, err)
-	require.NotNil(t, configPath)
-	require.Equal(t, "/etc/powerdns/pdns.conf", *configPath)
+	require.NotNil(t, detectedFiles)
+	require.Equal(t, "/etc/powerdns/pdns.conf", detectedFiles.getFirstFilePathByType(detectedFileTypeConfig))
 }
 
 // Test that the PowerDNS config path is correctly detected when the config-dir
@@ -148,13 +295,18 @@ func TestDetectPowerDNSDaemonConfigDir(t *testing.T) {
 	defer ctrl.Finish()
 
 	executor := NewMockCommandExecutor(ctrl)
+	executor.EXPECT().GetFileInfo("/etc/pdns.conf").Return(&testFileInfo{}, nil)
+
 	process := NewMockSupportedProcess(ctrl)
 	process.EXPECT().getCmdline().Return("/dir/pdns_server --config-dir=/etc", nil)
 
-	configPath, err := detectPowerDNSConfigPath(process, executor, "")
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.NoError(t, err)
-	require.NotNil(t, configPath)
-	require.Equal(t, "/etc/pdns.conf", *configPath)
+	require.NotNil(t, detectedFiles)
+	require.Equal(t, "/etc/pdns.conf", detectedFiles.getFirstFilePathByType(detectedFileTypeConfig))
 }
 
 // Test that the config directory is correctly detected when it is relative
@@ -164,14 +316,19 @@ func TestDetectPowerDNSDaemonRelConfigDir(t *testing.T) {
 	defer ctrl.Finish()
 
 	executor := NewMockCommandExecutor(ctrl)
+	executor.EXPECT().GetFileInfo("/opt/etc/pdns.conf").Return(&testFileInfo{}, nil)
+
 	process := NewMockSupportedProcess(ctrl)
 	process.EXPECT().getCmdline().Return("/dir/pdns_server --config-dir=etc", nil)
 	process.EXPECT().getCwd().Return("/opt", nil)
 
-	configPath, err := detectPowerDNSConfigPath(process, executor, "")
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.NoError(t, err)
-	require.NotNil(t, configPath)
-	require.Equal(t, "/opt/etc/pdns.conf", *configPath)
+	require.NotNil(t, detectedFiles)
+	require.Equal(t, "/opt/etc/pdns.conf", detectedFiles.getFirstFilePathByType(detectedFileTypeConfig))
 }
 
 // Test that an error is returned when getting a process current working directory fails
@@ -185,10 +342,13 @@ func TestDetectPowerDNSDaemonRelConfigDirCwdError(t *testing.T) {
 	process.EXPECT().getCmdline().Return("/dir/pdns_server --config-dir=etc", nil)
 	process.EXPECT().getCwd().Return("", errors.New("test error"))
 
-	configPath, err := detectPowerDNSConfigPath(process, executor, "")
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.Error(t, err)
 	require.ErrorContains(t, err, "test error")
-	require.Nil(t, configPath)
+	require.Nil(t, detectedFiles)
 }
 
 // Test that the config-name parameter is correctly interpreted when detected
@@ -201,20 +361,24 @@ func TestDetectPowerDNSDaemonConfigName(t *testing.T) {
 	executor.EXPECT().IsFileExist(gomock.Any()).DoAndReturn(func(path string) bool {
 		return path == "/etc/powerdns/pdns-foo.conf"
 	})
+	executor.EXPECT().GetFileInfo("/etc/powerdns/pdns-foo.conf").Return(&testFileInfo{}, nil)
 
 	process := NewMockSupportedProcess(ctrl)
 	process.EXPECT().getCmdline().Return("/dir/pdns_server --config-name=foo", nil)
 
-	configPath, err := detectPowerDNSConfigPath(process, executor, "")
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.NoError(t, err)
-	require.NotNil(t, configPath)
-	require.Equal(t, "/etc/powerdns/pdns-foo.conf", *configPath)
+	require.NotNil(t, detectedFiles)
+	require.Equal(t, "/etc/powerdns/pdns-foo.conf", detectedFiles.getFirstFilePathByType(detectedFileTypeConfig))
 }
 
 // Test that the PowerDNS config path is correctly detected when both
 // the chroot and config-dir are absolute and the config-dir belongs to
 // the chroot directory.
-func TestDetectPowerDNSAppChrootAbsConfigDir(t *testing.T) {
+func TestDetectPowerDNSDaemonChrootAbsConfigDir(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
@@ -222,15 +386,20 @@ func TestDetectPowerDNSAppChrootAbsConfigDir(t *testing.T) {
 	process.EXPECT().getCmdline().Return("/dir/pdns_server --chroot=/chroot --config-dir=/chroot/etc --config-name=foo", nil)
 
 	executor := NewMockCommandExecutor(ctrl)
-	configPath, err := detectPowerDNSConfigPath(process, executor, "")
+	executor.EXPECT().GetFileInfo("/chroot/etc/pdns-foo.conf").Return(&testFileInfo{}, nil)
+
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.NoError(t, err)
-	require.NotNil(t, configPath)
-	require.Equal(t, "/chroot/etc/pdns-foo.conf", *configPath)
+	require.NotNil(t, detectedFiles)
+	require.Equal(t, "/etc/pdns-foo.conf", detectedFiles.getFirstFilePathByType(detectedFileTypeConfig))
 }
 
 // Test that using chroot and relative config-dir falls back to alternative
 // locations.
-func TestDetectPowerDNSAppChrootRelConfigDir(t *testing.T) {
+func TestDetectPowerDNSDaemonChrootRelConfigDir(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
@@ -241,16 +410,20 @@ func TestDetectPowerDNSAppChrootRelConfigDir(t *testing.T) {
 	executor.EXPECT().IsFileExist(gomock.Any()).DoAndReturn(func(path string) bool {
 		return path == "/var/chroot/etc/powerdns/pdns.conf"
 	})
+	executor.EXPECT().GetFileInfo("/var/chroot/etc/powerdns/pdns.conf").Return(&testFileInfo{}, nil)
 
-	configPath, err := detectPowerDNSConfigPath(process, executor, "")
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.NoError(t, err)
-	require.NotNil(t, configPath)
-	require.Equal(t, "/var/chroot/etc/powerdns/pdns.conf", *configPath)
+	require.NotNil(t, detectedFiles)
+	require.Equal(t, "/etc/powerdns/pdns.conf", detectedFiles.getFirstFilePathByType(detectedFileTypeConfig))
 }
 
 // Test that the PowerDNS config path is correctly detected even for a relative
 // chroot directory if cwd is correctly set.
-func TestDetectPowerDNSAppRelChroot(t *testing.T) {
+func TestDetectPowerDNSDaemonRelChroot(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
@@ -268,11 +441,15 @@ func TestDetectPowerDNSAppRelChroot(t *testing.T) {
 		// one below.
 		return path == "/var/chroot/etc/powerdns/pdns.conf"
 	})
+	executor.EXPECT().GetFileInfo("/var/chroot/etc/powerdns/pdns.conf").Return(&testFileInfo{}, nil)
 
-	configPath, err := detectPowerDNSConfigPath(process, executor, "")
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.NoError(t, err)
-	require.NotNil(t, configPath)
-	require.Equal(t, "/var/chroot/etc/powerdns/pdns.conf", *configPath)
+	require.NotNil(t, detectedFiles)
+	require.Equal(t, "/etc/powerdns/pdns.conf", detectedFiles.getFirstFilePathByType(detectedFileTypeConfig))
 }
 
 // Test that an error is returned when getting a process current working directory fails.
@@ -286,10 +463,14 @@ func TestDetectPowerDNSDaemonRelChrootCwdError(t *testing.T) {
 	process.EXPECT().getCwd().Return("", errors.New("test error"))
 
 	executor := NewMockCommandExecutor(ctrl)
-	configPath, err := detectPowerDNSConfigPath(process, executor, "")
+
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.Error(t, err)
 	require.ErrorContains(t, err, "test error")
-	require.Nil(t, configPath)
+	require.Nil(t, detectedFiles)
 }
 
 // Test that the PowerDNS config path is correctly detected when the explicit
@@ -306,16 +487,21 @@ func TestDetectPowerDNSDaemonExplicitConfigPath(t *testing.T) {
 	executor.EXPECT().IsFileExist(gomock.Any()).DoAndReturn(func(path string) bool {
 		return path == "/etc/custom/powerdns/pdns.conf"
 	})
+	executor.EXPECT().GetFileInfo("/etc/custom/powerdns/pdns.conf").Return(&testFileInfo{}, nil)
 
-	configPath, err := detectPowerDNSConfigPath(process, executor, "/etc/custom/powerdns/pdns.conf")
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
+	monitor.explicitPowerDNSConfigPath = "/etc/custom/powerdns/pdns.conf"
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.NoError(t, err)
-	require.NotNil(t, configPath)
-	require.Equal(t, "/etc/custom/powerdns/pdns.conf", *configPath)
+	require.NotNil(t, detectedFiles)
+	require.Equal(t, "/etc/custom/powerdns/pdns.conf", detectedFiles.getFirstFilePathByType(detectedFileTypeConfig))
 }
 
 // Test that the explicit PowerDNS config path is respected when this path
 // belongs to the chroot directory.
-func TestDetectPowerDNSAppExplicitConfigPathChroot(t *testing.T) {
+func TestDetectPowerDNSDaemonExplicitConfigPathChroot(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
@@ -326,16 +512,21 @@ func TestDetectPowerDNSAppExplicitConfigPathChroot(t *testing.T) {
 	executor.EXPECT().IsFileExist(gomock.Any()).DoAndReturn(func(path string) bool {
 		return path == "/chroot/etc/custom/powerdns/pdns.conf"
 	})
+	executor.EXPECT().GetFileInfo("/chroot/etc/custom/powerdns/pdns.conf").Return(&testFileInfo{}, nil)
 
-	configPath, err := detectPowerDNSConfigPath(process, executor, "/chroot/etc/custom/powerdns/pdns.conf")
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
+	monitor.explicitPowerDNSConfigPath = "/chroot/etc/custom/powerdns/pdns.conf"
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.NoError(t, err)
-	require.NotNil(t, configPath)
-	require.Equal(t, "/chroot/etc/custom/powerdns/pdns.conf", *configPath)
+	require.NotNil(t, detectedFiles)
+	require.Equal(t, "/etc/custom/powerdns/pdns.conf", detectedFiles.getFirstFilePathByType(detectedFileTypeConfig))
 }
 
 // Test that the explicit PowerDNS config path is ignored when it is not
 // inside the chroot directory.
-func TestDetectPowerDNSAppExplicitConfigPathChrootMismatch(t *testing.T) {
+func TestDetectPowerDNSDaemonExplicitConfigPathChrootMismatch(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
@@ -349,17 +540,23 @@ func TestDetectPowerDNSAppExplicitConfigPathChrootMismatch(t *testing.T) {
 		// not belong to the chroot directory.
 		return path == "/var/chroot/etc/powerdns/pdns.conf"
 	})
+	executor.EXPECT().GetFileInfo("/var/chroot/etc/powerdns/pdns.conf").Return(&testFileInfo{}, nil)
+
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
 
 	// Explicit path does not belong to the chroot directory.
-	configPath, err := detectPowerDNSConfigPath(process, executor, "/chroot/etc/custom/powerdns/pdns.conf")
+	monitor.explicitPowerDNSConfigPath = "/chroot/etc/custom/powerdns/pdns.conf"
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.NoError(t, err)
-	require.NotNil(t, configPath)
-	require.Equal(t, "/var/chroot/etc/powerdns/pdns.conf", *configPath)
+	require.NotNil(t, detectedFiles)
+	require.Equal(t, "/etc/powerdns/pdns.conf", detectedFiles.getFirstFilePathByType(detectedFileTypeConfig))
 }
 
 // Test that the explicit PowerDNS config path is ignored when it contains
 // a path to a file which is in a parent of the chroot directory.
-func TestDetectPowerDNSAppExplicitConfigPathInChrootParent(t *testing.T) {
+func TestDetectPowerDNSDaemonExplicitConfigPathInChrootParent(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
@@ -373,20 +570,26 @@ func TestDetectPowerDNSAppExplicitConfigPathInChrootParent(t *testing.T) {
 		// not belong to the chroot directory.
 		return path == "/var/chroot/etc/powerdns/pdns.conf"
 	})
+	executor.EXPECT().GetFileInfo("/var/chroot/etc/powerdns/pdns.conf").Return(&testFileInfo{}, nil)
+
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
 
 	// Explicit path does not belong to the chroot directory. The
 	// explicit path should be ignored and one of the default locations
 	// should be used.
-	configPath, err := detectPowerDNSConfigPath(process, executor, "/var/pdns.conf")
+	monitor.explicitPowerDNSConfigPath = "/var/pdns.conf"
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.NoError(t, err)
-	require.NotNil(t, configPath)
-	require.Equal(t, "/var/chroot/etc/powerdns/pdns.conf", *configPath)
+	require.NotNil(t, detectedFiles)
+	require.Equal(t, "/etc/powerdns/pdns.conf", detectedFiles.getFirstFilePathByType(detectedFileTypeConfig))
 }
 
 // Test that the PowerDNS config path is correctly detected when the config
 // directory is not specified. It should try to find the config file in
 // typical locations.
-func TestDetectPowerDNSAppConfigPathPotentialConfLocations(t *testing.T) {
+func TestDetectPowerDNSDaemonConfigPathPotentialConfLocations(t *testing.T) {
 	for _, location := range getPotentialPDNSConfLocations() {
 		t.Run(location, func(t *testing.T) {
 			ctrl := gomock.NewController(t)
@@ -396,20 +599,24 @@ func TestDetectPowerDNSAppConfigPathPotentialConfLocations(t *testing.T) {
 			executor.EXPECT().IsFileExist(gomock.Any()).AnyTimes().DoAndReturn(func(path string) bool {
 				return path == filepath.Join(location, "pdns-custom.conf")
 			})
+			executor.EXPECT().GetFileInfo(gomock.Any()).AnyTimes().Return(&testFileInfo{}, nil)
 
 			process := NewMockSupportedProcess(ctrl)
 			process.EXPECT().getCmdline().Return("/dir/pdns_server --config-name=custom", nil)
 
-			configPath, err := detectPowerDNSConfigPath(process, executor, "")
+			monitor := newMonitor("", "", HTTPClientConfig{})
+			monitor.commander = executor
+
+			configPath, err := monitor.detectPowerDNSConfigPath(process)
 			require.NoError(t, err)
 			require.NotNil(t, configPath)
-			require.Equal(t, filepath.Join(location, "pdns-custom.conf"), *configPath)
+			require.Equal(t, filepath.Join(location, "pdns-custom.conf"), configPath.getFirstFilePathByType(detectedFileTypeConfig))
 		})
 	}
 }
 
 // Test that an error is returned when getting a process command line fails.
-func TestDetectPowerDNSAppConfigPathCmdLineError(t *testing.T) {
+func TestDetectPowerDNSDaemonConfigPathCmdLineError(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
@@ -417,23 +624,35 @@ func TestDetectPowerDNSAppConfigPathCmdLineError(t *testing.T) {
 	process := NewMockSupportedProcess(ctrl)
 	process.EXPECT().getCmdline().Return("", errors.New("test error"))
 
-	configPath, err := detectPowerDNSConfigPath(process, executor, "")
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = executor
+
+	detectedFiles, err := monitor.detectPowerDNSConfigPath(process)
 	require.Error(t, err)
 	require.ErrorContains(t, err, "test error")
-	require.Nil(t, configPath)
+	require.Nil(t, detectedFiles)
 }
 
-// Test instantiating and configuring the PowerDNS app using specified config path.
-func TestConfigurePowerDNSApp(t *testing.T) {
+// Test instantiating and configuring the PowerDNS daemon using specified config path.
+func TestConfigurePowerDNSDaemon(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addFileInfo("/etc/pdns.conf", &testFileInfo{})
+
 	parser := NewMockPDNSConfigParser(ctrl)
 	parser.EXPECT().ParseFile("/etc/pdns.conf").DoAndReturn(func(path string) (*pdnsconfig.Config, error) {
 		return pdnsconfig.NewParser().Parse(path, strings.NewReader(defaultPDNSConfig))
 	})
+	monitor.pdnsConfigParser = parser
 
-	daemon, err := configurePowerDNSDaemon("/etc/pdns.conf", parser)
+	detectedFiles := newDetectedDaemonFiles("", "")
+	err := detectedFiles.addFile(detectedFileTypeConfig, "/etc/pdns.conf", monitor.commander)
+	require.NoError(t, err)
+
+	daemon, err := monitor.configurePowerDNSDaemon(detectedFiles)
 	require.NoError(t, err)
 	require.NotNil(t, daemon)
 
@@ -448,14 +667,23 @@ func TestConfigurePowerDNSApp(t *testing.T) {
 }
 
 // Test that an error is returned when parsing the configuration file fails.
-func TestConfigurePowerDNSAppParseError(t *testing.T) {
+func TestConfigurePowerDNSDaemonParseError(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addFileInfo("/etc/pdns.conf", &testFileInfo{})
+
 	parser := NewMockPDNSConfigParser(ctrl)
 	parser.EXPECT().ParseFile("/etc/pdns.conf").Return(nil, errors.New("test error"))
+	monitor.pdnsConfigParser = parser
 
-	daemon, err := configurePowerDNSDaemon("/etc/pdns.conf", parser)
+	detectedFiles := newDetectedDaemonFiles("", "")
+	err := detectedFiles.addFile(detectedFileTypeConfig, "/etc/pdns.conf", monitor.commander)
+	require.NoError(t, err)
+
+	daemon, err := monitor.configurePowerDNSDaemon(detectedFiles)
 	require.Error(t, err)
 	require.ErrorContains(t, err, "test error")
 	require.Nil(t, daemon)
@@ -463,10 +691,14 @@ func TestConfigurePowerDNSAppParseError(t *testing.T) {
 
 // Test that default webserver address and port are used when not specified
 // in the configuration file.
-func TestConfigurePowerDNSAppDefaultWebserver(t *testing.T) {
+func TestConfigurePowerDNSDaemonDefaultWebserver(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addFileInfo("/etc/pdns.conf", &testFileInfo{})
+
 	parser := NewMockPDNSConfigParser(ctrl)
 	parser.EXPECT().ParseFile("/etc/pdns.conf").DoAndReturn(func(path string) (*pdnsconfig.Config, error) {
 		return pdnsconfig.NewParser().Parse(path, strings.NewReader(`
@@ -475,8 +707,13 @@ func TestConfigurePowerDNSAppDefaultWebserver(t *testing.T) {
 			api-key=stork
 		`))
 	})
+	monitor.pdnsConfigParser = parser
 
-	daemon, err := configurePowerDNSDaemon("/etc/pdns.conf", parser)
+	detectedFiles := newDetectedDaemonFiles("", "")
+	err := detectedFiles.addFile(detectedFileTypeConfig, "/etc/pdns.conf", monitor.commander)
+	require.NoError(t, err)
+
+	daemon, err := monitor.configurePowerDNSDaemon(detectedFiles)
 	require.NoError(t, err)
 	require.NotNil(t, daemon)
 
@@ -492,10 +729,14 @@ func TestConfigurePowerDNSAppDefaultWebserver(t *testing.T) {
 
 // Test that an error is returned when the API key is not specified in the
 // configuration file.
-func TestConfigurePowerDNSAppNoAPIKey(t *testing.T) {
+func TestConfigurePowerDNSDaemonNoAPIKey(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addFileInfo("/etc/pdns.conf", &testFileInfo{})
+
 	parser := NewMockPDNSConfigParser(ctrl)
 	parser.EXPECT().ParseFile("/etc/pdns.conf").DoAndReturn(func(path string) (*pdnsconfig.Config, error) {
 		return pdnsconfig.NewParser().Parse(path, strings.NewReader(`
@@ -503,19 +744,27 @@ func TestConfigurePowerDNSAppNoAPIKey(t *testing.T) {
 			webserver=yes
 		`))
 	})
+	monitor.pdnsConfigParser = parser
 
-	daemon, err := configurePowerDNSDaemon("/etc/pdns.conf", parser)
-	require.Error(t, err)
+	detectedFiles := newDetectedDaemonFiles("", "")
+	err := detectedFiles.addFile(detectedFileTypeConfig, "/etc/pdns.conf", monitor.commander)
+	require.NoError(t, err)
+
+	daemon, err := monitor.configurePowerDNSDaemon(detectedFiles)
 	require.ErrorContains(t, err, "api-key not found in /etc/pdns.conf")
 	require.Nil(t, daemon)
 }
 
 // Test that an error is returned when the webserver is disabled in the
 // configuration file.
-func TestConfigurePowerDNSAppNoWebserver(t *testing.T) {
+func TestConfigurePowerDNSDaemonNoWebserver(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addFileInfo("/etc/pdns.conf", &testFileInfo{})
+
 	parser := NewMockPDNSConfigParser(ctrl)
 	parser.EXPECT().ParseFile("/etc/pdns.conf").DoAndReturn(func(path string) (*pdnsconfig.Config, error) {
 		return pdnsconfig.NewParser().Parse(path, strings.NewReader(`
@@ -523,28 +772,40 @@ func TestConfigurePowerDNSAppNoWebserver(t *testing.T) {
 			webserver=no
 		`))
 	})
+	monitor.pdnsConfigParser = parser
 
-	daemon, err := configurePowerDNSDaemon("/etc/pdns.conf", parser)
-	require.Error(t, err)
+	detectedFiles := newDetectedDaemonFiles("", "")
+	err := detectedFiles.addFile(detectedFileTypeConfig, "/etc/pdns.conf", monitor.commander)
+	require.NoError(t, err)
+
+	daemon, err := monitor.configurePowerDNSDaemon(detectedFiles)
 	require.ErrorContains(t, err, "webserver disabled in /etc/pdns.conf")
 	require.Nil(t, daemon)
 }
 
 // Test that an error is returned when the API is disabled in the
 // configuration file.
-func TestConfigurePowerDNSAppNoAPI(t *testing.T) {
+func TestConfigurePowerDNSDaemonNoAPI(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 
+	monitor := newMonitor("", "", HTTPClientConfig{})
+	monitor.commander = newTestCommandExecutor().
+		addFileInfo("/etc/pdns.conf", &testFileInfo{})
+
 	parser := NewMockPDNSConfigParser(ctrl)
 	parser.EXPECT().ParseFile("/etc/pdns.conf").DoAndReturn(func(path string) (*pdnsconfig.Config, error) {
 		return pdnsconfig.NewParser().Parse(path, strings.NewReader(`
 			webserver=yes
 		`))
 	})
+	monitor.pdnsConfigParser = parser
 
-	daemon, err := configurePowerDNSDaemon("/etc/pdns.conf", parser)
-	require.Error(t, err)
+	detectedFiles := newDetectedDaemonFiles("", "")
+	err := detectedFiles.addFile(detectedFileTypeConfig, "/etc/pdns.conf", monitor.commander)
+	require.NoError(t, err)
+
+	daemon, err := monitor.configurePowerDNSDaemon(detectedFiles)
 	require.ErrorContains(t, err, "API or webserver disabled in /etc/pdns.conf")
 	require.Nil(t, daemon)
 }
