@@ -18,6 +18,7 @@ var (
 type supportedProcess interface {
 	getCmdline() (string, error)
 	getCwd() (string, error)
+	getExe() (string, error)
 	getName() (string, error)
 	getPid() int32
 	getParentPid() (int32, error)
@@ -44,6 +45,13 @@ func (p *processWrapper) getCwd() (string, error) {
 	return cwd, err
 }
 
+// Returns the process path to the executable.
+func (p *processWrapper) getExe() (string, error) {
+	exe, err := p.process.Exe()
+	err = errors.Wrapf(err, "failed to get process executable path for pid %d", p.getPid())
+	return exe, err
+}
+
 // Returns the process pid.
 func (p *processWrapper) getPid() int32 {
 	return p.process.Pid
