@@ -14,9 +14,9 @@ func TestAddressMatchListExcludesIPAddress(t *testing.T) {
 			{IPAddressOrACLName: "::1", Negation: false},
 		},
 	}
-	require.True(t, aml.ExcludesIPAddress("127.0.0.1"))
-	require.False(t, aml.ExcludesIPAddress("::1"))
-	require.False(t, aml.ExcludesIPAddress("192.168.1.1"))
+	require.True(t, aml.Excludes("127.0.0.1"))
+	require.False(t, aml.Excludes("::1"))
+	require.False(t, aml.Excludes("192.168.1.1"))
 }
 
 // Test checking that the address match list excludes the specified IP address
@@ -27,9 +27,9 @@ func TestAddressMatchListExcludesIPAddressWithNone(t *testing.T) {
 			{IPAddressOrACLName: "none"},
 		},
 	}
-	require.True(t, aml.ExcludesIPAddress("127.0.0.1"))
-	require.True(t, aml.ExcludesIPAddress("::1"))
-	require.True(t, aml.ExcludesIPAddress("192.168.1.1"))
+	require.True(t, aml.Excludes("127.0.0.1"))
+	require.True(t, aml.Excludes("::1"))
+	require.True(t, aml.Excludes("192.168.1.1"))
 }
 
 // Test checking that the address match list does not exclude the specified IP
@@ -40,7 +40,7 @@ func TestAddressMatchListExcludesIPAddressWithAny(t *testing.T) {
 			{IPAddressOrACLName: "any"},
 		},
 	}
-	require.False(t, aml.ExcludesIPAddress("127.0.0.1"))
-	require.False(t, aml.ExcludesIPAddress("::1"))
-	require.False(t, aml.ExcludesIPAddress("192.168.1.1"))
+	require.False(t, aml.Excludes("127.0.0.1"))
+	require.False(t, aml.Excludes("::1"))
+	require.False(t, aml.Excludes("192.168.1.1"))
 }
