@@ -247,7 +247,7 @@ func (c *Config) getAXFRCredentialsForDefaultView(zoneName string) (address stri
 	// The listenOnSet may contain multiple listen-on clauses. We need to find the
 	// clause matching our desired port. Also, preferably it should be a local
 	// loopback address.
-	listenOn := listenOnSet.GetMatchingListenOn(port)
+	listenOn := listenOnSet.GetMatchingListenOnClause(port)
 	if listenOn == nil {
 		return "", "", "", "", errors.Errorf("failed to get AXFR credentials for zone %s: allow-transfer port %d does not match any listen-on setting", zoneName, port)
 	}
@@ -361,7 +361,7 @@ func (c *Config) getAXFRCredentialsForView(viewName string, zoneName string) (ad
 	// The listenOnSet may contain multiple listen-on clauses. We need to find the
 	// clause matching our desired port. Also, preferably it should be a local
 	// loopback address.
-	listenOn := listenOnSet.GetMatchingListenOn(port)
+	listenOn := listenOnSet.GetMatchingListenOnClause(port)
 	if listenOn == nil {
 		return "", "", "", "", errors.Errorf("failed to get AXFR credentials for zone %s: allow-transfer port %d does not match any listen-on setting", zoneName, port)
 	}
@@ -535,11 +535,13 @@ func (c *Config) GetZoneKey(viewName string, zoneName string) (*Key, error) {
 }
 
 // Expands the configuration by including the contents of the included files.
-func (c *Config) Expand() (*Config, error) {
+// Returns the expanded configuration and the list of paths of included files.
+func (c *Config) Expand() (*Config, []string, error) {
 	baseDir := filepath.Dir(c.sourcePath)
 	expanded := &Config{
 		sourcePath: c.sourcePath,
 	}
+	var includedFiles []string
 	// Go over the top-level statements and identify the include statements.
 	for _, statement := range c.Statements {
 		if statement.Include != nil {
@@ -563,16 +565,17 @@ func (c *Config) Expand() (*Config, error) {
 			// Parse the included file.
 			parsedInclude, err := NewParser().ParseFile(path, c.chrootDir)
 			if err != nil {
-				return nil, err
+				return nil, nil, err
 			}
 			// Append the parsed statements to the parent file.
 			expanded.Statements = append(expanded.Statements, parsedInclude.Statements...)
+			includedFiles = append(includedFiles, parsedInclude.GetSourcePath())
 		} else {
 			// This is not an include statement. Append it as is.
 			expanded.Statements = append(expanded.Statements, statement)
 		}
 	}
-	return expanded, nil
+	return expanded, includedFiles, nil
 }
 
 // Accepts paths to two files and checks if they point to the same file.
