@@ -4,6 +4,7 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
+	"slices"
 	"strings"
 	"time"
 
@@ -144,6 +145,38 @@ func (d Daemon) GetMachineTag() MachineTag {
 	return d.Machine
 }
 
+// Return the label of the daemon for identification in the UI and logs.
+func (d Daemon) GetLabel() string {
+	formattedDaemonName := string(d.Name)
+	switch d.Name {
+	case daemonname.CA:
+		formattedDaemonName = "CA"
+	case daemonname.D2:
+		formattedDaemonName = "DDNS"
+	case daemonname.NetConf:
+		formattedDaemonName = "NetConf"
+	case daemonname.DHCPv4:
+		formattedDaemonName = "DHCPv4"
+	case daemonname.DHCPv6:
+		formattedDaemonName = "DHCPv6"
+	case daemonname.Bind9:
+		formattedDaemonName = "named"
+	case daemonname.PDNS:
+		formattedDaemonName = "pdns_server"
+	}
+
+	if d.Machine != nil {
+		machineLabel := d.Machine.GetLabel()
+		return fmt.Sprintf("%s@%s", formattedDaemonName, machineLabel)
+	}
+
+	accessPoint, err := d.GetAccessPoint(AccessPointControl)
+	if err == nil {
+		return fmt.Sprintf("%s@%s", formattedDaemonName, accessPoint.Address)
+	}
+	return formattedDaemonName
+}
+
 // Structure representing HA service information displayed for the daemon
 // in the dashboard.
 type DaemonServiceOverview struct {
@@ -157,7 +190,6 @@ type DaemonTag interface {
 	GetID() int64
 	GetName() daemonname.Name
 	GetMachineID() int64
-	GetVirtualApp() *VirtualApp
 }
 
 // Creates an instance of a daemon with its references initialized to empty
@@ -207,6 +239,7 @@ func GetDaemonByIDWithRelations(dbi pg.DBI, id int64, relations ...DaemonRelatio
 func GetDaemonByID(dbi pg.DBI, id int64) (*Daemon, error) {
 	return GetDaemonByIDWithRelations(
 		dbi, id,
+		DaemonRelationLogTargets,
 		DaemonRelationAccessPoints, DaemonRelationMachine,
 		DaemonRelationKeaDHCPDaemon, DaemonRelationBind9Daemon,
 		DaemonRelationPDNSDaemon,
@@ -218,6 +251,7 @@ func GetDaemonByID(dbi pg.DBI, id int64) (*Daemon, error) {
 func GetKeaDaemonByID(dbi pg.DBI, id int64) (*Daemon, error) {
 	return GetDaemonByIDWithRelations(
 		dbi, id,
+		DaemonRelationLogTargets,
 		DaemonRelationAccessPoints, DaemonRelationMachine,
 		DaemonRelationKeaDHCPDaemon,
 	)
@@ -237,6 +271,7 @@ func GetDNSDaemonByID(dbi pg.DBI, id int64) (*Daemon, error) {
 // It doesn't validate that the daemons are indeed Kea daemons.
 func GetKeaDaemonsByIDs(dbi pg.DBI, ids []int64) (daemons []Daemon, err error) {
 	err = dbi.Model(&daemons).
+		Relation(DaemonRelationLogTargets).
 		Relation(DaemonRelationAccessPoints).
 		Relation(DaemonRelationMachine).
 		Relation(DaemonRelationKeaDHCPDaemon).
@@ -260,6 +295,7 @@ func GetKeaDaemonsByIDs(dbi pg.DBI, ids []int64) (daemons []Daemon, err error) {
 // Get daemons by their machine ID.
 func GetDaemonsByMachine(dbi pg.DBI, machineID int64) (daemons []Daemon, err error) {
 	err = dbi.Model(&daemons).
+		Relation(DaemonRelationLogTargets).
 		Relation(DaemonRelationAccessPoints).
 		Relation(DaemonRelationMachine).
 		Relation(DaemonRelationKeaDaemon).
@@ -292,18 +328,34 @@ func GetAllDaemons(dbi dbops.DBI) ([]Daemon, error) {
 // Retrieves all daemons with provided relationships to other tables.
 func GetAllDaemonsWithRelations(dbi dbops.DBI, relations ...DaemonRelation) ([]Daemon, error) {
 	var daemons []Daemon
+	withMachineRelation := slices.Contains(relations, DaemonRelationMachine)
 
 	q := dbi.Model(&daemons)
 	for _, relation := range relations {
 		q = q.Relation(relation)
 	}
-	err := q.OrderExpr("id ASC").Select()
+	orderExpr := "machine_id"
+	if withMachineRelation {
+		orderExpr = "machine.state->>'Hostname' ASC, machine.address"
+	}
+	err := q.OrderExpr(orderExpr + " ASC, id ASC").Select()
 	if err != nil {
 		return nil, errors.Wrapf(err, "problem getting daemons from the database")
 	}
 	return daemons, nil
 }
 
+// Sort field which may be used in GetDaemonsByPage.
+type DaemonSortField string
+
+// Valid sort fields.
+const (
+	DaemonSortFieldName            DaemonSortField = "name"
+	DaemonSortFieldVersion         DaemonSortField = "version"
+	DaemonSortFieldMachineAddress  DaemonSortField = "machine_address"
+	DaemonSortFieldMachineHostname DaemonSortField = "machine_hostname"
+)
+
 // Fetches a collection of daemons from the database.
 //
 // The offset and limit specify the beginning of the page and the maximum size
@@ -332,26 +384,29 @@ func GetDaemonsByPage(dbi dbops.DBI, offset int64, limit int64, filterText *stri
 		Relation(DaemonRelationMachine).
 		Relation(DaemonRelationLogTargets)
 
-	for _, daemonName := range daemonNames {
-		q = q.WhereOr("name = ?", daemonName)
-		switch daemonName {
-		case daemonname.DHCPv4, daemonname.DHCPv6:
-			q = q.Relation(DaemonRelationHAService)
-			q = q.Relation(DaemonRelationKeaDHCPDaemon)
-		case daemonname.CA, daemonname.D2, daemonname.NetConf:
-			q = q.Relation(DaemonRelationKeaDaemon)
-		case daemonname.Bind9:
-			q = q.Relation(DaemonRelationBind9Daemon)
-		case daemonname.PDNS:
-			q = q.Relation(DaemonRelationPDNSDaemon)
-		}
-	}
-
 	if len(daemonNames) == 0 {
 		q = q.Relation(DaemonRelationHAService).
 			Relation(DaemonRelationKeaDHCPDaemon).
 			Relation(DaemonRelationBind9Daemon).
 			Relation(DaemonRelationPDNSDaemon)
+	} else {
+		q = q.WhereGroup(func(qq *orm.Query) (*orm.Query, error) {
+			for _, daemonName := range daemonNames {
+				qq = qq.WhereOr("name = ?", daemonName)
+				switch daemonName {
+				case daemonname.DHCPv4, daemonname.DHCPv6:
+					qq = qq.Relation(DaemonRelationHAService)
+					qq = qq.Relation(DaemonRelationKeaDHCPDaemon)
+				case daemonname.CA, daemonname.D2, daemonname.NetConf:
+					qq = qq.Relation(DaemonRelationKeaDaemon)
+				case daemonname.Bind9:
+					qq = qq.Relation(DaemonRelationBind9Daemon)
+				case daemonname.PDNS:
+					qq = qq.Relation(DaemonRelationPDNSDaemon)
+				}
+			}
+			return qq, nil
+		})
 	}
 
 	if filterText != nil {
@@ -367,7 +422,26 @@ func GetDaemonsByPage(dbi dbops.DBI, offset int64, limit int64, filterText *stri
 	}
 
 	// prepare sorting expression, offset and limit
-	ordExpr, _ := prepareOrderAndDistinctExpr("daemon", sortField, sortDir, nil)
+	ordExpr, _ := prepareOrderAndDistinctExpr("daemon", sortField, sortDir, func(sortField, escapedTableName, dirExpr string) (orderExpr, distinctOnExpr string, useCustom bool) {
+		switch DaemonSortField(sortField) {
+		case DaemonSortFieldName:
+			// When sorting daemons by name, apply the second sort by id field.
+			orderExpr = fmt.Sprintf("%[1]s.name %[2]s, %[1]s.id %[2]s", escapedTableName, dirExpr)
+			distinctOnExpr = fmt.Sprintf("%s.name", escapedTableName)
+		case DaemonSortFieldMachineAddress:
+			// When sorting daemons by machine address, apply the second sort by name field.
+			orderExpr = fmt.Sprintf("machine.address %[2]s, %[1]s.name %[2]s", escapedTableName, dirExpr)
+			distinctOnExpr = "machine.address"
+		case DaemonSortFieldMachineHostname:
+			// When sorting daemons by machine hostname, apply the second sort by name field.
+			orderExpr = fmt.Sprintf("machine.state->'Hostname' %[2]s, %[1]s.name %[2]s", escapedTableName, dirExpr)
+			distinctOnExpr = "machine.state->'Hostname'"
+		default:
+			return "", "", false
+		}
+		useCustom = true
+		return
+	})
 	q = q.OrderExpr(ordExpr)
 	q = q.Offset(int(offset))
 	q = q.Limit(int(limit))
@@ -435,10 +509,9 @@ func GetDNSDaemons(dbi pg.DBI) (daemons []Daemon, err error) {
 // Get all Kea DHCP daemons.
 func GetKeaDHCPDaemons(dbi pg.DBI) (daemons []Daemon, err error) {
 	err = dbi.Model(&daemons).
+		Relation(DaemonRelationLogTargets).
 		Relation(DaemonRelationMachine).
 		Relation(DaemonRelationKeaDHCPDaemon).
-		// TODO: Code implemented in below line is a temporary solution for virtual applications.
-		Relation(DaemonRelationAccessPoints).
 		Where("daemon.name ILIKE 'dhcp%'").
 		OrderExpr("daemon.id ASC").
 		Select()
@@ -883,6 +956,7 @@ func (d *Daemon) setKeaConfigWithHash(config *keaconfig.Config, configHash strin
 						targets[i].ID = existingTarget.ID
 						targets[i].DaemonID = d.ID
 						targets[i].CreatedAt = existingTarget.CreatedAt
+						break
 					}
 				}
 				d.LogTargets = append(d.LogTargets, targets[i])
