@@ -90,7 +90,11 @@ func TestUpdateKeaDHCPDaemon(t *testing.T) {
 	daemon.Version = "2.0.0"
 	err = daemon.SetKeaConfigFromJSON([]byte(`{
         "Dhcp4": {
-            "valid-lifetime": 1234
+            "valid-lifetime": 1234,
+			"loggers": [{
+				"name": "kea-dhcp4",
+				"output_options": [{ "output": "/var/log/kea/kea-dhcp4-ha1.log"}]
+			}]
         }
     }`))
 	require.NoError(t, err)
@@ -110,6 +114,7 @@ func TestUpdateKeaDHCPDaemon(t *testing.T) {
 	require.Equal(t, daemonname.DHCPv6, updatedDaemon.Name)
 	require.False(t, updatedDaemon.Active)
 	require.Equal(t, "2.0.0", updatedDaemon.Version)
+	require.Len(t, updatedDaemon.LogTargets, 1)
 	require.NotNil(t, updatedDaemon.KeaDaemon)
 	require.NotNil(t, updatedDaemon.KeaDaemon.Config)
 	require.NotNil(t, updatedDaemon.KeaDaemon.KeaDHCPDaemon)
@@ -351,6 +356,7 @@ func TestGetDaemonByID(t *testing.T) {
 	require.NotNil(t, dmn.KeaDaemon.Config)
 	require.NotNil(t, dmn.Machine)
 	require.Len(t, dmn.AccessPoints, 1)
+	require.Len(t, dmn.LogTargets, 1)
 }
 
 // Test getting multiple Kea daemons by IDs.
@@ -386,6 +392,10 @@ func TestGetKeaDaemonsByIDs(t *testing.T) {
 	var daemons []*Daemon
 	for _, daemonName := range []daemonname.Name{daemonname.DHCPv4, daemonname.DHCPv6, daemonname.D2, daemonname.CA} {
 		daemon := NewDaemon(m, daemonName, true, accessPoints)
+		daemon.LogTargets = []*LogTarget{{
+			Name:   "kea-dhcp4",
+			Output: "/var/log/kea/kea-dhcp4-ha1.log",
+		}}
 		err = AddDaemon(db, daemon)
 		require.NoError(t, err)
 		daemons = append(daemons, daemon)
@@ -404,6 +414,7 @@ func TestGetKeaDaemonsByIDs(t *testing.T) {
 		require.EqualValues(t, m.ID, rd.Machine.ID)
 		require.NotNil(t, rd.KeaDaemon)
 		require.NotNil(t, rd.KeaDaemon.KeaDHCPDaemon)
+		require.Len(t, rd.LogTargets, 1)
 	}
 	require.ElementsMatch(t, ids, selectedDaemons)
 }
@@ -440,6 +451,10 @@ func TestGetKeaDHCPDaemons(t *testing.T) {
 	daemonNames := []daemonname.Name{daemonname.DHCPv4, daemonname.DHCPv6, daemonname.CA, daemonname.D2}
 	for _, dn := range daemonNames {
 		daemon := NewDaemon(m, dn, true, accessPoints)
+		daemon.LogTargets = []*LogTarget{{
+			Name:   "kea-dhcp4",
+			Output: "/var/log/kea/kea-dhcp4-ha1.log",
+		}}
 		err = AddDaemon(db, daemon)
 		require.NoError(t, err)
 	}
@@ -462,6 +477,7 @@ func TestGetKeaDHCPDaemons(t *testing.T) {
 		require.NotNil(t, d.KeaDaemon)
 		require.Equal(t, d.ID, d.KeaDaemon.DaemonID)
 		require.NotNil(t, d.KeaDaemon.KeaDHCPDaemon)
+		require.Len(t, d.LogTargets, 1)
 	}
 	require.Contains(t, names, daemonname.DHCPv4)
 	require.Contains(t, names, daemonname.DHCPv6)
@@ -1313,6 +1329,10 @@ func TestGetDaemonsByMachine(t *testing.T) {
 	require.NoError(t, err)
 
 	d1 := NewDaemon(m1, daemonname.DHCPv4, true, []*AccessPoint{})
+	d1.LogTargets = []*LogTarget{{
+		Name:   "kea-dhcp4",
+		Output: "/var/log/kea/kea-dhcp4-ha1.log",
+	}}
 	err = AddDaemon(db, d1)
 	require.NoError(t, err)
 	d2 := NewDaemon(m1, daemonname.Bind9, true, []*AccessPoint{})
@@ -1329,6 +1349,7 @@ func TestGetDaemonsByMachine(t *testing.T) {
 	ids := []int64{daemons[0].ID, daemons[1].ID}
 	require.Contains(t, ids, d1.ID)
 	require.Contains(t, ids, d2.ID)
+	require.Len(t, daemons[0].LogTargets, 1)
 
 	daemons, err = GetDaemonsByMachine(db, m2.ID)
 	require.NoError(t, err)
@@ -1341,10 +1362,14 @@ func TestGetDaemonsByPage(t *testing.T) {
 	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
 	defer teardown()
 
-	m := &Machine{Address: "localhost", AgentPort: 8080}
+	m := &Machine{Address: "localhost", AgentPort: 8080, State: MachineState{Hostname: "abchostname"}}
 	err := AddMachine(db, m)
 	require.NoError(t, err)
 
+	m2 := &Machine{Address: "zyxlocalhost", AgentPort: 8080, State: MachineState{Hostname: "xyzhostname"}}
+	err = AddMachine(db, m2)
+	require.NoError(t, err)
+
 	for i := 0; i < 10; i++ {
 		d := NewDaemon(m, daemonname.DHCPv4, true, []*AccessPoint{})
 		d.Version = "1.0"
@@ -1352,16 +1377,23 @@ func TestGetDaemonsByPage(t *testing.T) {
 		require.NoError(t, err)
 	}
 
+	for i := 0; i < 5; i++ {
+		d := NewDaemon(m2, daemonname.DHCPv6, true, []*AccessPoint{})
+		d.Version = "2.0"
+		err = AddDaemon(db, d)
+		require.NoError(t, err)
+	}
+
 	// Test pagination
 	daemons, total, err := GetDaemonsByPage(db, 0, 5, nil, "id", SortDirAsc)
 	require.NoError(t, err)
 	require.Len(t, daemons, 5)
-	require.EqualValues(t, 10, total)
+	require.EqualValues(t, 15, total)
 
 	daemons, total, err = GetDaemonsByPage(db, 5, 5, nil, "id", SortDirAsc)
 	require.NoError(t, err)
 	require.Len(t, daemons, 5)
-	require.EqualValues(t, 10, total)
+	require.EqualValues(t, 15, total)
 
 	// Test filtering
 	filter := "1.0"
@@ -1386,6 +1418,62 @@ func TestGetDaemonsByPage(t *testing.T) {
 	require.NoError(t, err)
 	require.Len(t, daemons, 0)
 	require.EqualValues(t, 0, total)
+
+	filter = "non-existent"
+	daemons, total, err = GetDaemonsByPage(db, 0, 10, &filter, "id", SortDirAsc, daemonname.DHCPv4, daemonname.DHCPv6, daemonname.CA)
+	require.NoError(t, err)
+	require.Len(t, daemons, 0)
+	require.EqualValues(t, 0, total)
+
+	filter = "2.0"
+	daemons, total, err = GetDaemonsByPage(db, 0, 10, &filter, "id", SortDirAsc, daemonname.DHCPv4, daemonname.DHCPv6, daemonname.CA)
+	require.NoError(t, err)
+	require.Len(t, daemons, 5)
+	require.EqualValues(t, 5, total)
+
+	// Test sorting
+	// by name
+	daemons, total, err = GetDaemonsByPage(db, 0, 11, nil, string(DaemonSortFieldName), SortDirAsc)
+	require.NoError(t, err)
+	require.Len(t, daemons, 11)
+	require.EqualValues(t, 15, total)
+	require.EqualValues(t, daemons[0].Name, daemonname.DHCPv4)
+	require.EqualValues(t, daemons[10].Name, daemonname.DHCPv6)
+	require.Greater(t, daemons[1].ID, daemons[0].ID)
+
+	daemons, total, err = GetDaemonsByPage(db, 0, 6, nil, string(DaemonSortFieldName), SortDirDesc)
+	require.NoError(t, err)
+	require.Len(t, daemons, 6)
+	require.EqualValues(t, 15, total)
+	require.EqualValues(t, daemons[0].Name, daemonname.DHCPv6)
+	require.EqualValues(t, daemons[5].Name, daemonname.DHCPv4)
+	require.Greater(t, daemons[0].ID, daemons[1].ID)
+
+	// by machine address
+	daemons, total, err = GetDaemonsByPage(db, 0, 11, nil, string(DaemonSortFieldMachineAddress), SortDirAsc)
+	require.NoError(t, err)
+	require.Len(t, daemons, 11)
+	require.EqualValues(t, 15, total)
+	require.Greater(t, daemons[10].Machine.Address, daemons[0].Machine.Address)
+
+	daemons, total, err = GetDaemonsByPage(db, 0, 11, nil, string(DaemonSortFieldMachineAddress), SortDirDesc)
+	require.NoError(t, err)
+	require.Len(t, daemons, 11)
+	require.EqualValues(t, 15, total)
+	require.Greater(t, daemons[0].Machine.Address, daemons[10].Machine.Address)
+
+	// by machine hostname
+	daemons, total, err = GetDaemonsByPage(db, 0, 11, nil, string(DaemonSortFieldMachineHostname), SortDirAsc)
+	require.NoError(t, err)
+	require.Len(t, daemons, 11)
+	require.EqualValues(t, 15, total)
+	require.Greater(t, daemons[10].Machine.State.Hostname, daemons[0].Machine.State.Hostname)
+
+	daemons, total, err = GetDaemonsByPage(db, 0, 11, nil, string(DaemonSortFieldMachineHostname), SortDirDesc)
+	require.NoError(t, err)
+	require.Len(t, daemons, 11)
+	require.EqualValues(t, 15, total)
+	require.Greater(t, daemons[0].Machine.State.Hostname, daemons[10].Machine.State.Hostname)
 }
 
 // Test getting DHCP daemons.
@@ -1447,6 +1535,10 @@ func TestGetKeaDaemonByID(t *testing.T) {
 
 	// Add Kea DHCPv4 daemon
 	kea4 := NewDaemon(m, daemonname.DHCPv4, true, []*AccessPoint{})
+	kea4.LogTargets = []*LogTarget{{
+		Name:   "kea-dhcp4",
+		Output: "/var/log/kea/kea-dhcp4-ha1.log",
+	}}
 	err = AddDaemon(db, kea4)
 	require.NoError(t, err)
 
@@ -1462,6 +1554,7 @@ func TestGetKeaDaemonByID(t *testing.T) {
 	require.Equal(t, daemonname.DHCPv4, d.Name)
 	require.NotNil(t, d.KeaDaemon)
 	require.NotNil(t, d.KeaDaemon.KeaDHCPDaemon)
+	require.Len(t, d.LogTargets, 1)
 
 	// Get BIND9 (should return daemon but without this daemon specific fields
 	// populated).
@@ -1471,9 +1564,129 @@ func TestGetKeaDaemonByID(t *testing.T) {
 	require.Equal(t, daemonname.Bind9, d.Name)
 	require.Nil(t, d.KeaDaemon)
 	require.Nil(t, d.Bind9Daemon)
+	require.Len(t, d.LogTargets, 0)
 
 	// Get non-existing daemon
 	d, err = GetKeaDaemonByID(db, 12345)
 	require.NoError(t, err)
 	require.Nil(t, d)
 }
+
+// Test that the access point is retrieved from the daemon.
+func TestGetAccessPoint(t *testing.T) {
+	t.Run("no access points", func(t *testing.T) {
+		// Arrange
+		daemon := &Daemon{}
+
+		// Act
+		accessPoint, err := daemon.GetAccessPoint(AccessPointControl)
+
+		// Assert
+		require.ErrorContains(t, err, "no access point")
+		require.Nil(t, accessPoint)
+	})
+
+	t.Run("single access point", func(t *testing.T) {
+		// Arrange
+		daemon := &Daemon{AccessPoints: []*AccessPoint{{
+			Type: AccessPointControl,
+			Port: 42,
+		}}}
+
+		// Act
+		accessPoint, err := daemon.GetAccessPoint(AccessPointControl)
+
+		// Assert
+		require.NoError(t, err)
+		require.NotNil(t, accessPoint)
+		require.EqualValues(t, 42, accessPoint.Port)
+	})
+
+	t.Run("multiple access points", func(t *testing.T) {
+		// Arrange
+		daemon := &Daemon{AccessPoints: []*AccessPoint{
+			{
+				Type: AccessPointControl,
+				Port: 43,
+			},
+			{
+				Type: AccessPointStatistics,
+				Port: 44,
+			},
+		}}
+
+		// Act
+		accessPoint, err := daemon.GetAccessPoint(AccessPointStatistics)
+
+		// Assert
+		require.NoError(t, err)
+		require.NotNil(t, accessPoint)
+		require.EqualValues(t, 44, accessPoint.Port)
+	})
+
+	t.Run("not exists access point", func(t *testing.T) {
+		// Arrange
+		daemon := &Daemon{AccessPoints: []*AccessPoint{
+			{
+				Type: AccessPointStatistics,
+				Port: 46,
+			},
+		}}
+
+		// Act
+		accessPoint, err := daemon.GetAccessPoint(AccessPointControl)
+
+		// Assert
+		require.ErrorContains(t, err, "no access point")
+		require.Nil(t, accessPoint)
+	})
+
+	t.Run("unknown access point", func(t *testing.T) {
+		// Arrange
+		daemon := &Daemon{}
+
+		// Act
+		accessPoint, err := daemon.GetAccessPoint(AccessPointType("unknown"))
+
+		// Assert
+		require.ErrorContains(t, err, "no access point")
+		require.Nil(t, accessPoint)
+	})
+}
+
+// Test that the daemon label is well-formatted.
+func TestGetLabel(t *testing.T) {
+	t.Parallel()
+	cases := []struct {
+		name     daemonname.Name
+		expected string
+	}{
+		{daemonname.DHCPv4, "DHCPv4@foobar"},
+		{daemonname.DHCPv6, "DHCPv6@foobar"},
+		{daemonname.Bind9, "named@foobar"},
+		{daemonname.PDNS, "pdns_server@foobar"},
+		{daemonname.CA, "CA@foobar"},
+		{daemonname.NetConf, "NetConf@foobar"},
+		{daemonname.D2, "DDNS@foobar"},
+	}
+
+	for _, testcase := range cases {
+		t.Run(testcase.expected, func(t *testing.T) {
+			t.Parallel()
+			// Arrange
+			daemon := &Daemon{
+				Name: testcase.name,
+				ID:   42,
+				Machine: &Machine{
+					ID: 24,
+					State: MachineState{
+						Hostname: "foobar",
+					},
+				},
+			}
+
+			// Act & Assert
+			require.Equal(t, testcase.expected, daemon.GetLabel())
+		})
+	}
+}
