@@ -75,13 +75,14 @@ func AddEvent(db *pg.DB, event *Event) error {
 // limit specify the beginning of the page and the maximum size of the
 // page. Limit has to be greater then 0, otherwise error is returned.
 // The level indicates the lowest level of events that should be
-// returned (0 - info, 1 - warning, 2 - error). daemon
-// allows for selecting events for a given daemon (e.g. 'named' or 'dhcp4').
-// machineID and userID allows for selecting events pertaining to the specific
-// machine or user. sortField allows for selecting a sort column in database, and
-// sortDir selects the sorting order. If the sortField is empty then id is used
-// for sorting. If SortDirAny is used then ASC order is used.
-func GetEventsByPage(db *pg.DB, offset int64, limit int64, level EventLevel, daemonName *string, machineID *int64, userID *int64, sortField string, sortDir SortDirEnum) ([]Event, int64, error) {
+// returned (0 - info, 1 - warning, 2 - error). daemonName
+// allows for selecting events for a given daemon name (e.g. 'named' or 'dhcp4').
+// machineID, daemonID and userID allows for selecting events pertaining to the
+// specific machine, daemon or user. sortField allows for selecting a sort
+// column in database, and sortDir selects the sorting order. If the sortField
+// is empty then id is used for sorting. If SortDirAny is used then ASC order
+// is used.
+func GetEventsByPage(db *pg.DB, offset int64, limit int64, level EventLevel, daemonName *string, machineID *int64, daemonID *int64, userID *int64, sortField string, sortDir SortDirEnum) ([]Event, int64, error) {
 	if limit == 0 {
 		return nil, 0, pkgerrors.New("limit should be greater than 0")
 	}
@@ -102,6 +103,9 @@ func GetEventsByPage(db *pg.DB, offset int64, limit int64, level EventLevel, dae
 	if userID != nil {
 		q = q.Where("CAST (relations->>'UserID' AS INTEGER) = ?", *userID)
 	}
+	if daemonID != nil {
+		q = q.Where("CAST (relations->>'DaemonID' AS INTEGER) = ?", *daemonID)
+	}
 
 	// prepare sorting expression, offset and limit
 	ordExpr, _ := prepareOrderAndDistinctExpr("event", sortField, sortDir, func(sortField, escapedTableName, dirExpr string) (orderExpr, distinctOnExpr string, useCustom bool) {
