@@ -380,7 +380,6 @@ func TestGetSubnetsByPageBasic(t *testing.T) {
 	require.ElementsMatch(t, localSubnetIDs, []int64{1, 2, 3, 4, 11, 12, 21})
 
 	// Get subnets from daemon d4
-	// Note: AppID filter no longer exists, so we verify daemon associations directly
 	subnets, total, err = GetSubnetsByPage(db, 0, 10, nil, "", SortDirAny)
 	require.NoError(t, err)
 	require.EqualValues(t, 7, total)
@@ -661,7 +660,7 @@ func TestGetSharedNetworksByPageBasic(t *testing.T) {
 		},
 	}
 
-	appSubnets := []Subnet{
+	subnets := []Subnet{
 		{
 			Prefix: "192.168.0.0/24",
 			LocalSubnets: []*LocalSubnet{
@@ -672,7 +671,7 @@ func TestGetSharedNetworksByPageBasic(t *testing.T) {
 			},
 		},
 	}
-	_, err = CommitNetworksIntoDB(db, appNetworks, appSubnets)
+	_, err = CommitNetworksIntoDB(db, appNetworks, subnets)
 	require.NoError(t, err)
 
 	// add daemon with dhcp6 to machine
@@ -737,7 +736,7 @@ func TestGetSharedNetworksByPageBasic(t *testing.T) {
 		},
 	}
 
-	appSubnets = []Subnet{
+	subnets = []Subnet{
 		{
 			Prefix: "2001:db8:1::/64",
 			LocalSubnets: []*LocalSubnet{
@@ -748,7 +747,7 @@ func TestGetSharedNetworksByPageBasic(t *testing.T) {
 			},
 		},
 	}
-	_, err = CommitNetworksIntoDB(db, appNetworks, appSubnets)
+	_, err = CommitNetworksIntoDB(db, appNetworks, subnets)
 	require.NoError(t, err)
 
 	// Get all shared networks.
