@@ -8,8 +8,6 @@ import (
 	"github.com/go-pg/pg/v10"
 	"github.com/go-pg/pg/v10/orm"
 	pkgerrors "github.com/pkg/errors"
-	"isc.org/stork/datamodel/daemonname"
-	dbops "isc.org/stork/server/database"
 )
 
 // Part of machine table in database that describes state of machine. In DB it is stored as JSONB.
@@ -106,7 +104,6 @@ func GetMachineByAddressAndAgentPort(db *pg.DB, address string, agentPort int64)
 		return nil, pkgerrors.Wrapf(err, "problem getting machine %s:%d", address, agentPort)
 	}
 
-	// TODO: Code implemented in below block is a temporary solution for virtual applications.
 	for _, daemon := range machine.Daemons {
 		daemon.Machine = &machine
 	}
@@ -136,7 +133,6 @@ func GetMachineByAddressAndAccessPointPort(db *pg.DB, machineAddress string, acc
 		return nil, pkgerrors.Wrapf(err, "problem getting machine by the '%s' machine address and the '%d' access point port", machineAddress, accessPointPort)
 	}
 
-	// TODO: Code implemented in below block is a temporary solution for virtual applications.
 	for _, daemon := range machine.Daemons {
 		daemon.Machine = &machine
 	}
@@ -147,6 +143,7 @@ func GetMachineByAddressAndAccessPointPort(db *pg.DB, machineAddress string, acc
 // Get a machine by its ID with default relations.
 func GetMachineByID(db *pg.DB, id int64) (*Machine, error) {
 	return GetMachineByIDWithRelations(db, id,
+		MachineRelationDaemonLogTargets,
 		MachineRelationDaemonAccessPoints,
 		MachineRelationBind9Daemons,
 		MachineRelationKeaDHCPConfigs,
@@ -176,7 +173,6 @@ func getMachineByID(db *pg.DB, id int64, relations []string) (*Machine, error) {
 		return nil, pkgerrors.Wrapf(err, "problem getting machine %v", id)
 	}
 
-	// TODO: Code implemented in below block is a temporary solution for virtual applications.
 	for _, daemon := range machine.Daemons {
 		daemon.Machine = &machine
 	}
@@ -194,7 +190,6 @@ func RefreshMachineFromDB(db *pg.DB, machine *Machine) error {
 		return pkgerrors.Wrapf(err, "problem getting machine %v", machine.ID)
 	}
 
-	// TODO: Code implemented in below block is a temporary solution for virtual applications.
 	for _, daemon := range machine.Daemons {
 		daemon.Machine = machine
 	}
@@ -230,6 +225,7 @@ func GetMachinesByPage(db *pg.DB, offset int64, limit int64, filterText *string,
 	// prepare query
 	q := db.Model(&machines)
 	q = q.Relation(string(MachineRelationDaemonAccessPoints))
+	q = q.Relation(string(MachineRelationDaemonLogTargets))
 	q = q.Relation(string(MachineRelationKeaDHCPConfigs))
 	q = q.Relation(string(MachineRelationBind9Daemons))
 	q = q.Relation(string(MachineRelationPDNSDaemons))
@@ -292,7 +288,6 @@ func GetMachinesByPage(db *pg.DB, offset int64, limit int64, filterText *string,
 		return nil, 0, pkgerrors.Wrapf(err, "problem getting machines")
 	}
 
-	// TODO: Code implemented in below block is a temporary solution for virtual applications.
 	for _, machine := range machines {
 		for _, daemon := range machine.Daemons {
 			daemon.Machine = &machine
@@ -305,6 +300,7 @@ func GetMachinesByPage(db *pg.DB, offset int64, limit int64, filterText *string,
 // Get all machines from database. It can be filtered by authorized field.
 func GetAllMachines(db *pg.DB, authorized *bool) ([]Machine, error) {
 	return GetAllMachinesWithRelations(db, authorized,
+		MachineRelationDaemonLogTargets,
 		MachineRelationDaemonAccessPoints,
 		MachineRelationKeaDHCPConfigs,
 		MachineRelationBind9Daemons,
@@ -331,7 +327,6 @@ func GetAllMachinesWithRelations(db *pg.DB, authorized *bool, relations ...Machi
 		return nil, pkgerrors.Wrapf(err, "problem getting machines")
 	}
 
-	// TODO: Code implemented in below block is a temporary solution for virtual applications.
 	for _, machine := range machines {
 		for _, daemon := range machine.Daemons {
 			daemon.Machine = &machine
@@ -352,15 +347,10 @@ func GetUnauthorizedMachinesCount(db *pg.DB) (int, error) {
 	return count, pkgerrors.Wrapf(err, "problem counting unauthorized machines")
 }
 
-// Delete a machine from database. The machine must include non-nil Daemons
-// field (though it may be an empty slice). The Daemons field is used to
-// delete orphaned objects (e.g., subnets, zones) after the machine is deleted.
-// The whole operation is transactional, so it is rolled back if it fails at
-// any stage.
+// Delete a machine from database. It also deletes all orphaned objects related
+// to the machine. The whole operation is transactional, so it is rolled back
+// if it fails at any stage.
 func DeleteMachine(db *pg.DB, machine *Machine) error {
-	if machine.Daemons == nil {
-		return pkgerrors.Errorf("deleted machine with ID %d has no daemons relation", machine.ID)
-	}
 	return db.RunInTransaction(context.Background(), func(tx *pg.Tx) error {
 		result, err := db.Model(machine).WherePK().Delete()
 		if err != nil {
@@ -368,27 +358,22 @@ func DeleteMachine(db *pg.DB, machine *Machine) error {
 		} else if result.RowsAffected() <= 0 {
 			return pkgerrors.Wrapf(ErrNotExists, "machine with ID %d does not exist", machine.ID)
 		}
-		// Deleting the machine may leave some orphaned objects behind.
-		// Let's make sure they are deleted.
-		daemonNames := make(map[daemonname.Name]bool)
-		fns := []func(tx dbops.DBI) (int64, error){}
-		for _, daemon := range machine.Daemons {
-			daemonNames[daemon.Name] = true
+
+		_, err = DeleteOrphanedZones(db)
+		if err != nil {
+			return err
 		}
-		for daemonName := range daemonNames {
-			switch daemonName {
-			case daemonname.Bind9, daemonname.PDNS:
-				fns = append(fns, DeleteOrphanedZones)
-			case daemonname.DHCPv4, daemonname.DHCPv6:
-				fns = append(fns, DeleteOrphanedSubnets, DeleteOrphanedHosts, DeleteOrphanedSharedNetworks)
-			case daemonname.CA, daemonname.D2, daemonname.NetConf:
-				// No orphaned objects to delete.
-			}
+		_, err = DeleteOrphanedSubnets(db)
+		if err != nil {
+			return err
 		}
-		for _, fn := range fns {
-			if _, err := fn(tx); err != nil {
-				return err
-			}
+		_, err = DeleteOrphanedHosts(db)
+		if err != nil {
+			return err
+		}
+		_, err = DeleteOrphanedSharedNetworks(db)
+		if err != nil {
+			return err
 		}
 		return nil
 	})
@@ -415,3 +400,11 @@ func (machine *Machine) GetAgentPort() int64 {
 func (machine *Machine) GetHostname() string {
 	return machine.State.Hostname
 }
+
+// Return the label of the daemon for identification in the UI and logs.
+func (machine *Machine) GetLabel() string {
+	if machine.State.Hostname != "" {
+		return machine.State.Hostname
+	}
+	return machine.Address
+}
