@@ -123,6 +123,7 @@ func TestGetMachineByAddress(t *testing.T) {
 	require.Equal(t, "localhost", m.Daemons[0].AccessPoints[0].Address)
 	require.EqualValues(t, 1234, m.Daemons[0].AccessPoints[0].Port)
 	require.Empty(t, m.Daemons[0].AccessPoints[0].Key)
+	require.Equal(t, m, m.Daemons[0].Machine)
 
 	// delete machine
 	err = DeleteMachine(db, m)
@@ -178,6 +179,7 @@ func TestGetMachineByID(t *testing.T) {
 	require.Equal(t, "abcd", m.Daemons[0].AccessPoints[0].Key)
 	require.Equal(t, daemonname.DHCPv4, m.Daemons[0].Name)
 	require.True(t, m.LastVisitedAt.IsZero())
+	require.Equal(t, m, m.Daemons[0].Machine)
 
 	// delete machine
 	err = DeleteMachine(db, m)
@@ -292,30 +294,39 @@ func TestGetMachineByIDWithRelations(t *testing.T) {
 	sortMachineDaemonsByName(machineDaemons)
 	require.Nil(t, machineDaemons.Daemons[0].LogTargets)
 	require.Nil(t, machineDaemons.Daemons[0].KeaDaemon)
+	require.Equal(t, machineDaemons, machineDaemons.Daemons[0].Machine)
 	require.Nil(t, machineDaemons.Daemons[1].Bind9Daemon)
+	require.Equal(t, machineDaemons, machineDaemons.Daemons[1].Machine)
 	// Machine with kea daemons
 	require.Len(t, machineKeaDaemons.Daemons, 2)
 	sortMachineDaemonsByName(machineKeaDaemons)
 	require.Nil(t, machineKeaDaemons.Daemons[0].KeaDaemon.KeaDHCPDaemon)
 	require.Nil(t, machineKeaDaemons.Daemons[0].LogTargets)
+	require.Equal(t, machineKeaDaemons, machineKeaDaemons.Daemons[0].Machine)
 	require.Nil(t, machineKeaDaemons.Daemons[1].Bind9Daemon)
+	require.Equal(t, machineKeaDaemons, machineKeaDaemons.Daemons[1].Machine)
 	// Machine with Bind9 daemons
 	require.Len(t, machineBind9Daemons.Daemons, 2)
 	sortMachineDaemonsByName(machineBind9Daemons)
 	require.Nil(t, machineBind9Daemons.Daemons[0].KeaDaemon)
 	require.Nil(t, machineBind9Daemons.Daemons[0].LogTargets)
+	require.Equal(t, machineBind9Daemons, machineBind9Daemons.Daemons[0].Machine)
 	require.NotNil(t, machineBind9Daemons.Daemons[1].Bind9Daemon)
+	require.Equal(t, machineBind9Daemons, machineBind9Daemons.Daemons[1].Machine)
 	// Machine with daemon log targets
 	require.Len(t, machineDaemonLogTargets.Daemons, 2)
 	sortMachineDaemonsByName(machineDaemonLogTargets)
 	require.Nil(t, machineDaemonLogTargets.Daemons[0].KeaDaemon)
 	require.Len(t, machineDaemonLogTargets.Daemons[0].LogTargets, 2)
 	require.Nil(t, machineDaemonLogTargets.Daemons[0].Bind9Daemon)
+	require.Equal(t, machineDaemonLogTargets, machineDaemonLogTargets.Daemons[0].Machine)
 	// Machine with the access points
 	require.Len(t, machineDaemonAccessPoints.Daemons, 2)
 	sortMachineDaemonsByName(machineDaemonAccessPoints)
 	require.Len(t, machineDaemonAccessPoints.Daemons[0].AccessPoints, 1)
+	require.Equal(t, machineDaemonAccessPoints, machineDaemonAccessPoints.Daemons[0].Machine)
 	require.Empty(t, machineDaemonAccessPoints.Daemons[1].AccessPoints)
+	require.Equal(t, machineDaemonAccessPoints, machineDaemonAccessPoints.Daemons[1].Machine)
 	// Machine with Kea DHCP configurations
 	require.Len(t, machineKeaDHCPConfigs.Daemons, 2)
 	sortMachineDaemonsByName(machineKeaDHCPConfigs)
@@ -325,12 +336,15 @@ func TestGetMachineByIDWithRelations(t *testing.T) {
 	sortMachineDaemonsByName(machineDaemonAccessPointsKeaDHCPConfigs)
 	require.NotNil(t, machineDaemonAccessPointsKeaDHCPConfigs.Daemons[0].KeaDaemon.KeaDHCPDaemon)
 	require.Len(t, machineDaemonAccessPointsKeaDHCPConfigs.Daemons[0].AccessPoints, 1)
+	require.Equal(t, machineDaemonAccessPointsKeaDHCPConfigs, machineDaemonAccessPointsKeaDHCPConfigs.Daemons[0].Machine)
 	// Machine with the HA services
 	require.Len(t, machineDaemonHAServices.Daemons, 2)
 	sortMachineDaemonsByName(machineDaemonHAServices)
 	require.Len(t, machineDaemonHAServices.Daemons[0].Services, 1)
 	require.NotNil(t, machineDaemonHAServices.Daemons[0].Services[0].HAService)
 	require.Empty(t, machineDaemonHAServices.Daemons[1].Services)
+	require.Equal(t, machineDaemonHAServices, machineDaemonHAServices.Daemons[0].Machine)
+	require.Equal(t, machineDaemonHAServices, machineDaemonHAServices.Daemons[1].Machine)
 }
 
 // Test that the machine is selected by the address and port of an access point.
@@ -379,6 +393,9 @@ func TestGetMachineByAddressAndAccessPointPort(t *testing.T) {
 	require.NoError(t, err)
 	require.NotNil(t, machine)
 	require.EqualValues(t, m1.ID, machine.ID)
+	require.Len(t, machine.Daemons, 2)
+	require.Equal(t, machine, machine.Daemons[0].Machine)
+	require.Equal(t, machine, machine.Daemons[1].Machine)
 }
 
 // Test that the machine is selected by the address, port, and type of an
@@ -491,6 +508,8 @@ func TestGetMachinesByPageBasic(t *testing.T) {
 	require.Nil(t, err)
 	require.EqualValues(t, 10, total)
 	require.Len(t, ms, 10)
+	require.Len(t, ms[5].Daemons, 1)
+	require.Equal(t, ms[5].Daemons[0].Machine, &ms[5])
 
 	// get 2 machines out of 10, from 0
 	ms, total, err = GetMachinesByPage(db, 0, 2, nil, nil, "", SortDirAny)
@@ -659,12 +678,12 @@ func TestGetUnauthorizedMachinesCount(t *testing.T) {
 }
 
 // Check if an attempt to delete a machine without specifying the daemons
-// relation fails.
+// relation doesn't fail.
 func TestDeleteMachineOnly(t *testing.T) {
 	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
 	defer teardown()
 
-	// add machine
+	// Add machine.
 	m := &Machine{
 		Address:   "localhost",
 		AgentPort: 8080,
@@ -672,10 +691,20 @@ func TestDeleteMachineOnly(t *testing.T) {
 	err := AddMachine(db, m)
 	require.NoError(t, err)
 
-	// delete machine
+	// Add an orphaned subnet.
+	subnet := &Subnet{
+		Prefix: "fe80::/64",
+	}
+	err = AddSubnet(db, subnet)
+	require.NoError(t, err)
+
+	// Delete machine.
 	err = DeleteMachine(db, m)
-	require.Error(t, err)
-	require.Contains(t, err.Error(), "deleted machine with ID 1 has no daemons relation")
+	require.NoError(t, err)
+	// Check if there are no orphans.
+	subnets, err := GetAllSubnets(db, 0)
+	require.NoError(t, err)
+	require.Empty(t, subnets)
 }
 
 // Check if deleting machine and its daemons works.
@@ -703,6 +732,8 @@ func TestDeleteMachineWithDaemons(t *testing.T) {
 	// reload machine from db to get daemons relation loaded
 	err = RefreshMachineFromDB(db, m)
 	require.Nil(t, err)
+	require.Len(t, m.Daemons, 1)
+	require.Equal(t, m, m.Daemons[0].Machine)
 
 	// delete machine
 	err = DeleteMachine(db, m)
@@ -1006,6 +1037,8 @@ func TestGetAllMachines(t *testing.T) {
 	require.EqualValues(t, 4, machines[0].State.Cpus)
 	require.EqualValues(t, 4, machines[19].State.Cpus)
 	require.NotEqual(t, machines[0].AgentPort, machines[19].AgentPort)
+	require.Len(t, machines[10].Daemons, 1)
+	require.Equal(t, &machines[10], machines[10].Daemons[0].Machine)
 
 	// Ensure that we fetched daemons and config reviews too.
 	require.Len(t, machines[0].Daemons, 1)
@@ -1099,6 +1132,14 @@ func TestGetAllMachinesWithRelations(t *testing.T) {
 		},
 	})
 
+	sortDaemons := func(machines []Machine) {
+		for m := range machines {
+			sort.Slice(machines[m].Daemons, func(i, j int) bool {
+				return machines[m].Daemons[i].ID < machines[m].Daemons[j].ID
+			})
+		}
+	}
+
 	t.Run("No relations - all", func(t *testing.T) {
 		// Act
 		machines, err := GetAllMachinesWithRelations(db, nil)
@@ -1139,12 +1180,14 @@ func TestGetAllMachinesWithRelations(t *testing.T) {
 		require.NoError(t, err)
 		require.Len(t, machines, 1)
 		require.Len(t, machines[0].Daemons, 3)
+		sortDaemons(machines)
 		require.Equal(t, daemonname.DHCPv4, machines[0].Daemons[0].Name)
 		require.Empty(t, machines[0].Daemons[0].LogTargets)
 		require.Empty(t, machines[0].Daemons[0].AccessPoints)
 		require.Nil(t, machines[0].Daemons[0].KeaDaemon)
 		require.Nil(t, machines[0].Daemons[0].ConfigReview)
 		require.Empty(t, machines[0].Daemons[0].Services)
+		require.Equal(t, &machines[0], machines[0].Daemons[0].Machine)
 		require.Equal(t, daemonname.Bind9, machines[0].Daemons[1].Name)
 		require.Nil(t, machines[0].Daemons[1].Bind9Daemon)
 		require.Nil(t, machines[0].Daemons[1].ConfigReview)
@@ -1163,6 +1206,7 @@ func TestGetAllMachinesWithRelations(t *testing.T) {
 		require.NoError(t, err)
 		require.Len(t, machines, 1)
 		require.Len(t, machines[0].Daemons, 3)
+		sortDaemons(machines)
 		require.Equal(t, daemonname.DHCPv4, machines[0].Daemons[0].Name)
 		require.Len(t, machines[0].Daemons[0].LogTargets, 1)
 		require.Equal(t, "syslog", machines[0].Daemons[0].LogTargets[0].Name)
@@ -1190,6 +1234,7 @@ func TestGetAllMachinesWithRelations(t *testing.T) {
 		require.NoError(t, err)
 		require.Len(t, machines, 1)
 		require.Len(t, machines[0].Daemons, 3)
+		sortDaemons(machines)
 		require.Equal(t, daemonname.DHCPv4, machines[0].Daemons[0].Name)
 		require.Empty(t, machines[0].Daemons[0].LogTargets)
 		require.Len(t, machines[0].Daemons[0].AccessPoints, 1)
@@ -1221,6 +1266,7 @@ func TestGetAllMachinesWithRelations(t *testing.T) {
 		require.NoError(t, err)
 		require.Len(t, machines, 1)
 		require.Len(t, machines[0].Daemons, 3)
+		sortDaemons(machines)
 		require.Equal(t, daemonname.DHCPv4, machines[0].Daemons[0].Name)
 		require.Empty(t, machines[0].Daemons[0].LogTargets)
 		require.Empty(t, machines[0].Daemons[0].AccessPoints)
@@ -1248,6 +1294,7 @@ func TestGetAllMachinesWithRelations(t *testing.T) {
 		require.NoError(t, err)
 		require.Len(t, machines, 1)
 		require.Len(t, machines[0].Daemons, 3)
+		sortDaemons(machines)
 		require.Equal(t, daemonname.DHCPv4, machines[0].Daemons[0].Name)
 		require.Empty(t, machines[0].Daemons[0].LogTargets)
 		require.Empty(t, machines[0].Daemons[0].AccessPoints)
@@ -1274,6 +1321,7 @@ func TestGetAllMachinesWithRelations(t *testing.T) {
 		require.NoError(t, err)
 		require.Len(t, machines, 1)
 		require.Len(t, machines[0].Daemons, 3)
+		sortDaemons(machines)
 		require.Equal(t, daemonname.DHCPv4, machines[0].Daemons[0].Name)
 		require.Empty(t, machines[0].Daemons[0].LogTargets)
 		require.Empty(t, machines[0].Daemons[0].AccessPoints)
@@ -1300,6 +1348,7 @@ func TestGetAllMachinesWithRelations(t *testing.T) {
 		require.NoError(t, err)
 		require.Len(t, machines, 1)
 		require.Len(t, machines[0].Daemons, 3)
+		sortDaemons(machines)
 		require.Equal(t, daemonname.DHCPv4, machines[0].Daemons[0].Name)
 		require.Empty(t, machines[0].Daemons[0].LogTargets)
 		require.Empty(t, machines[0].Daemons[0].AccessPoints)
@@ -1327,6 +1376,7 @@ func TestGetAllMachinesWithRelations(t *testing.T) {
 		require.NoError(t, err)
 		require.Len(t, machines, 1)
 		require.Len(t, machines[0].Daemons, 3)
+		sortDaemons(machines)
 		require.Equal(t, daemonname.DHCPv4, machines[0].Daemons[0].Name)
 		require.Empty(t, machines[0].Daemons[0].LogTargets)
 		require.Empty(t, machines[0].Daemons[0].AccessPoints)
@@ -1355,6 +1405,7 @@ func TestGetAllMachinesWithRelations(t *testing.T) {
 		require.NoError(t, err)
 		require.Len(t, machines, 1)
 		require.Len(t, machines[0].Daemons, 3)
+		sortDaemons(machines)
 		require.Equal(t, daemonname.DHCPv4, machines[0].Daemons[0].Name)
 		require.Empty(t, machines[0].Daemons[0].LogTargets)
 		require.Empty(t, machines[0].Daemons[0].AccessPoints)
@@ -1390,6 +1441,7 @@ func TestGetAllMachinesWithRelations(t *testing.T) {
 		require.NoError(t, err)
 		require.Len(t, machines, 1)
 		require.Len(t, machines[0].Daemons, 3)
+		sortDaemons(machines)
 		require.Equal(t, daemonname.DHCPv4, machines[0].Daemons[0].Name)
 		require.Len(t, machines[0].Daemons[0].LogTargets, 1)
 		require.Len(t, machines[0].Daemons[0].AccessPoints, 1)
@@ -1501,3 +1553,23 @@ func TestGetAllMachinesNoRelations(t *testing.T) {
 		require.True(t, machine.Authorized)
 	}
 }
+
+// Test GetLabel method returns hostname when available.
+func TestGetLabelWithHostname(t *testing.T) {
+	machine := Machine{
+		Address: "2001:db8::1",
+		State: MachineState{
+			Hostname: "myhost.example.org",
+		},
+	}
+	require.Equal(t, "myhost.example.org", machine.GetLabel())
+}
+
+// Test GetLabel method returns address when hostname is empty.
+func TestGetLabelWithoutHostname(t *testing.T) {
+	machine := Machine{
+		Address: "2001:db8::1",
+		State:   MachineState{},
+	}
+	require.Equal(t, "2001:db8::1", machine.GetLabel())
+}
