@@ -56,7 +56,7 @@ const (
 	SharedNetworkRelationSubnetsMachine                  SharedNetworkRelation = "Subnets.LocalSubnets.Daemon.Machine"
 )
 
-// This structure holds shared network information retrieved from an app.
+// This structure holds shared network information retrieved from a daemon.
 // Multiple DHCP servers may be configured to serve leases in the same
 // shared network. For the same shared network configured in the different
 // DHCP servers there will be separate instances of the LocalSharedNetwork
@@ -274,9 +274,7 @@ func DeleteDaemonsFromSharedNetwork(dbi dbops.DBI, sharedNetworkID int64) error
 func GetAllSharedNetworks(dbi dbops.DBI, family int) ([]SharedNetwork, error) {
 	networks := []SharedNetwork{}
 	q := dbi.Model(&networks).
-		Relation(string(SharedNetworkRelationLocalSharedNetworksAccessPoints)).
-		// TODO: Code implemented in below line is a temporary solution for virtual applications.
-		Relation(string(SharedNetworkRelationLocalSharedNetworksMachine))
+		Relation(string(SharedNetworkRelationLocalSharedNetworksAccessPoints))
 
 	if family == 4 || family == 6 {
 		q = q.Where("inet_family = ?", family)
@@ -361,8 +359,7 @@ func GetSharedNetworksByPage(dbi dbops.DBI, offset, limit, daemonID, family int6
 	orderExpr, distinctOnFields := prepareOrderAndDistinctExpr("shared_network", sortField, sortDir, subnetAndSharedNetworkCustomOrderAndDistinct)
 	q = q.DistinctOn(distinctOnFields)
 
-	q = q.Relation(string(SharedNetworkRelationLocalSharedNetworksAccessPoints)).
-		// TODO: Code implemented in below line is a temporary solution for virtual applications.
+	q = q.Relation(string(SharedNetworkRelationLocalSharedNetworksDaemon)).
 		Relation(string(SharedNetworkRelationLocalSharedNetworksMachine))
 
 	// If any of the filtering parameters are specified we need to explicitly join
@@ -378,7 +375,7 @@ func GetSharedNetworksByPage(dbi dbops.DBI, offset, limit, daemonID, family int6
 	q = q.Relation(string(SharedNetworkRelationSubnets), func(q *orm.Query) (*orm.Query, error) {
 		return q.Order("prefix ASC"), nil
 	}).
-		Relation(string(SharedNetworkRelationSubnetsAccessPoints)).
+		Relation(string(SharedNetworkRelationSubnetsDaemon)).
 		Relation(string(SharedNetworkRelationSubnetsMachine))
 
 	// Let's be liberal and allow other values than 0 too. The only special
