@@ -198,13 +198,13 @@ type utilizationStats interface {
 	GetStatistics() Stats
 }
 
-// This structure holds subnet information retrieved from an app. Multiple
-// DHCP server apps may be configured to serve leases in the same subnet.
+// This structure holds subnet information retrieved from a daemon. Multiple
+// DHCP server daemons may be configured to serve leases in the same subnet.
 // For the same subnet configured on different DHCP server there will be
 // a separate instance of the LocalSubnet structure. Apart from possibly
-// different local subnet id between different apps there will also be
+// different local subnet id between different daemons there will also be
 // other information stored here, e.g. statistics for the particular
-// subnet retrieved from the given app. Multiple local subnets can be
+// subnet retrieved from the given daemon. Multiple local subnets can be
 // associated with a single global subnet depending on how many daemons
 // serve the same subnet.
 type LocalSubnet struct {
@@ -669,8 +669,6 @@ func GetGlobalSubnets(dbi dbops.DBI, family int) ([]Subnet, error) {
 
 // Container for values filtering subnets fetched by page.
 type SubnetsByPageFilters struct {
-	// TODO: Code implemented in below line is a temporary solution for virtual applications.
-	MachineID     *int64
 	DaemonID      *int64
 	LocalSubnetID *int64
 	Family        *int64
@@ -766,15 +764,8 @@ func GetSubnetsByPage(dbi dbops.DBI, offset, limit int64, filters *SubnetsByPage
 	orderExpr, distinctOnFields := prepareOrderAndDistinctExpr("subnet", dbSortField, sortDir, subnetAndSharedNetworkCustomOrderAndDistinct)
 	q = q.DistinctOn(distinctOnFields)
 
-	if filters.DaemonID != nil || filters.LocalSubnetID != nil || filters.Text != nil ||
-		// TODO: Code implemented in below line is a temporary solution for virtual applications.
-		filters.MachineID != nil {
+	if filters.DaemonID != nil || filters.LocalSubnetID != nil || filters.Text != nil {
 		q = q.Join("INNER JOIN local_subnet AS ls ON subnet.id = ls.subnet_id")
-		// TODO: Code implemented in below block is a temporary solution for virtual applications.
-		if filters.MachineID != nil {
-			q = q.Join("INNER JOIN daemon AS d ON ls.daemon_id = d.id")
-			q = q.Where("d.machine_id = ?", *filters.MachineID)
-		}
 	}
 	// Pools are also required when trying to filter by text.
 	if filters.Text != nil {
@@ -804,7 +795,6 @@ func GetSubnetsByPage(dbi dbops.DBI, offset, limit int64, filters *SubnetsByPage
 			return q.Order("prefix_pool.id ASC"), nil
 		}).
 		Relation(string(SubnetRelationAccessPoints)).
-		// TODO: Code implemented in below line is a temporary solution for virtual applications.
 		Relation(string(SubnetRelationMachines))
 
 	// Applicable family values are 4 and 6.
@@ -894,7 +884,7 @@ func GetSubnetPrefixes(dbi dbops.DBI) ([]string, error) {
 func addDaemonToSubnet(dbi dbops.DBI, subnet *Subnet, daemon *Daemon) error {
 	localSubnetID := int64(0)
 	// If the prefix is available we should try to match the subnet prefix
-	// with the app's configuration and retrieve the local subnet id from
+	// with the daemon's configuration and retrieve the local subnet id from
 	// there.
 	if len(subnet.Prefix) > 0 {
 		localSubnetID = daemon.GetLocalSubnetID(subnet.Prefix)
@@ -969,7 +959,7 @@ func DeleteDaemonFromSubnets(dbi dbops.DBI, daemonID int64) (int64, error) {
 
 // Iterates over the provided slice of subnets and stores them in the database
 // if they are not there yet. In addition, it associates the subnets with the
-// specified Kea application. Returns a list of added subnets.
+// specified Kea daemon. Returns a list of added subnets.
 func commitSubnetsIntoDB(tx *pg.Tx, networkID int64, subnets []Subnet) (addedSubnets []*Subnet, err error) {
 	for i := range subnets {
 		subnet := &subnets[i]
@@ -1007,7 +997,7 @@ func commitSubnetsIntoDB(tx *pg.Tx, networkID int64, subnets []Subnet) (addedSub
 }
 
 // Iterates over the shared networks, subnets and hosts and commits them to the database.
-// In addition it associates them with the specified app. Returns a list of added subnets.
+// In addition it associates them with the specified daemon. Returns a list of added subnets.
 // This function runs all database operations in a transaction.
 func commitNetworksIntoDB(tx *pg.Tx, networks []SharedNetwork, subnets []Subnet) ([]*Subnet, error) {
 	var (
