@@ -15,7 +15,7 @@ import (
 	log "github.com/sirupsen/logrus"
 	agentapi "isc.org/stork/api"
 	bind9config "isc.org/stork/daemoncfg/bind9"
-	"isc.org/stork/daemoncfg/dnsconfig"
+	dnsmodel "isc.org/stork/datamodel/dns"
 	agentcomm "isc.org/stork/server/agentcomm"
 	dbmodel "isc.org/stork/server/database/model"
 	storkutil "isc.org/stork/util"
@@ -90,22 +90,21 @@ type Manager interface {
 	// makes the fetch sequential (next agent is contacted after fetching all zones
 	// from the previous agent). The batchSize controls the maximum number of zones
 	// that are collected and inserted into the database in a single SQL INSERT.
-	// Finally, block boolean flag indicates if the caller is going to wait for the
-	// completion of the function (if true) or not (if false). In the latter case
-	// the returned ManagerDoneNotify channel is buffered, in which case there is
-	// no requirement to read from this channel before the fetch is complete. Setting
-	// this flag to true is helpful in the unit tests to ensure that specific sequence
-	// of calls is executed.
-	FetchZones(poolSize, batchSize int, block bool) (chan ManagerDoneNotify, error)
+	FetchZones(poolSize, batchSize int, options ...FetchZonesOption) (chan ManagerDoneNotify, error)
 	// Checks if the DNS Manager is currently fetching the zones and returns progress.
 	// The first boolean flag indicates whether or not fetch is in progress. The int
 	// parameters indicate the number of daemons from which the zones are fetched and
 	// the number of daemons from which the zones have been fetched already.
 	GetFetchZonesProgress() (bool, int, int)
-	// Returns the RRs for the specified zone, daemon and view name.
-	// Using the options, the caller can request to force zone transfer even when RRs
-	// are cached in the database.
-	GetZoneRRs(zoneID int64, daemonID int64, viewName string, options ...GetZoneRRsOption) iter.Seq[*RRResponse]
+	// Returns the RRs for the specified zone, daemon and view name. The optional
+	// filter allows for filtering the RRs by type and/or text matching the name or
+	// rdata. It also allows for paging the long results. If the filter is nil,
+	// all RRs are returned for the zoneID, daemonID, viewName. If the filter is
+	// specified but the RRs have not been cached yet, all RRs are fetched (and cached)
+	// from the agent using the zone transfer, and only a subset is returned to the
+	// caller. Using the options, the caller can request to force zone transfer even
+	// when RRs are cached in the database.
+	GetZoneRRs(zoneID int64, daemonID int64, viewName string, filter *dbmodel.GetZoneRRsFilter, options ...GetZoneRRsOption) iter.Seq[*RRResponse]
 	// Returns the BIND 9 configuration for the specified daemon with filtering
 	// and file type selection. If the filter is nil, all configuration elements are
 	// returned. Otherwise,only the configuration elements explicitly enabled in the
@@ -116,12 +115,29 @@ type Manager interface {
 	Shutdown()
 }
 
+// Type of options for FetchZones function.
+type FetchZonesOption int
+
+const (
+	// Indicates that the caller is going to wait for the completion of the function.
+	// In the latter case the returned ManagerDoneNotify channel is buffered, in which
+	// case there is no requirement to read from this channel before the fetch is complete.
+	// Setting this flag is helpful in the unit tests to ensure that specific sequence
+	// of calls is executed.
+	FetchZonesOptionBlock FetchZonesOption = iota
+	// Force zone inventory to be populated from the DNS server before fetching the zones.
+	// Setting this flag may significantly increase the time to fetch the zones.
+	FetchZonesOptionForcePopulate
+)
+
 // Type of options for GetZoneRRs function.
 type GetZoneRRsOption int
 
 const (
 	// Force zone transfer even when RRs are cached.
 	GetZoneRRsOptionForceZoneTransfer GetZoneRRsOption = iota
+	// Exclude the trailing SOA RR from the response.
+	GetZoneRRsOptionExcludeTrailingSOA
 )
 
 // A zones fetching state including the flag whether or not the fetch
@@ -215,10 +231,67 @@ func newRRsRequest(ctx context.Context, key uint64, daemon *dbmodel.Daemon, zone
 type RRResponse struct {
 	Cached         bool
 	ZoneTransferAt time.Time
-	RRs            []*dnsconfig.RR
+	Total          int
+	RRs            []*dnsmodel.RR
 	Err            error
 }
 
+// Returns a new RRResponse with the RRs filtered according to the specified filter.
+// The pos parameter tracks the position in the RRs stream, starting from 0. It is
+// increased by the number of processed RRs and returned as the second return value.
+// If the filter is nil, the response is returned unchanged.
+func (response *RRResponse) applyFilter(filter *dbmodel.GetZoneRRsFilter, pos int) (*RRResponse, int) {
+	if filter == nil {
+		// If the filter is nil, there is nothing to do. Return the response unchanged.
+		response.Total = pos + len(response.RRs)
+		return response, response.Total
+	}
+	// Filter the RRs according to the filter.
+	filteredRRs := []*dnsmodel.RR{}
+	for _, rr := range response.RRs {
+		if filter.IsTypeEnabled(rr.Type) && filter.IsTextMatches(rr) {
+			filteredRRs = append(filteredRRs, rr)
+		}
+	}
+
+	// Calculate the new position in the RRs stream. It is moved forward by the
+	// number of filtered RRs. It must be calculate before paging is applied because
+	// it will be returned as the total number of RRs.
+	newPos := pos + len(filteredRRs)
+
+	if len(filteredRRs) > 0 {
+		// Apply paging if requested.
+		start := filter.GetOffset() - pos
+		if start < 0 {
+			// Negative start means that we're passed the beginning of the
+			// desired range. Set the start to 0 to consume all RRs.
+			start = 0
+		}
+		if start >= len(filteredRRs) {
+			// If the start is passed the end of the RRs, we haven't reached the
+			// desired offset. Set the start to the end of the current RRs set to
+			// not consume any RRs.
+			start = len(filteredRRs)
+		}
+		limit := filter.GetLimit()
+		end := start + limit
+		// A limit of 0 means no limit.
+		if limit == 0 || end > len(filteredRRs) {
+			end = len(filteredRRs)
+		}
+		// It is possible that start is equal to end if we haven't reached the
+		// desired offset yet. This will result in returning an empty slice.
+		filteredRRs = filteredRRs[start:end]
+	}
+	return &RRResponse{
+		Cached:         response.Cached,
+		ZoneTransferAt: response.ZoneTransferAt,
+		Total:          newPos,
+		RRs:            filteredRRs,
+		Err:            response.Err,
+	}, newPos
+}
+
 // Creates a new RRResponse with an error.
 func NewErrorRRResponse(err error) *RRResponse {
 	return &RRResponse{
@@ -228,7 +301,7 @@ func NewErrorRRResponse(err error) *RRResponse {
 
 // Creates a new non-cached RRResponse with RRs. The zone transfer time is
 // set to current time.
-func NewZoneTransferRRResponse(rrs []*dnsconfig.RR) *RRResponse {
+func NewZoneTransferRRResponse(rrs []*dnsmodel.RR) *RRResponse {
 	return &RRResponse{
 		Cached:         false,
 		ZoneTransferAt: time.Now().UTC(),
@@ -237,11 +310,12 @@ func NewZoneTransferRRResponse(rrs []*dnsconfig.RR) *RRResponse {
 }
 
 // Creates a new cached RRResponse with RRs.
-func NewCacheRRResponse(rrs []*dnsconfig.RR, transferAt time.Time) *RRResponse {
+func NewCacheRRResponse(rrs []*dnsmodel.RR, total int, transferAt time.Time) *RRResponse {
 	return &RRResponse{
 		Cached:         true,
 		ZoneTransferAt: transferAt,
 		RRs:            rrs,
+		Total:          total,
 	}
 }
 
@@ -365,7 +439,7 @@ func NewManager(owner ManagerAccessors) (Manager, error) {
 
 // Contacts all agents with DNS servers and fetches zones from these servers.
 // It implements the Manager interface.
-func (manager *managerImpl) FetchZones(poolSize, batchSize int, block bool) (chan ManagerDoneNotify, error) {
+func (manager *managerImpl) FetchZones(poolSize, batchSize int, options ...FetchZonesOption) (chan ManagerDoneNotify, error) {
 	// Only start fetching if there is no other fetch in progress.
 	if !manager.fetchingState.startFetching() {
 		return nil, &ManagerAlreadyFetchingError{}
@@ -385,7 +459,7 @@ func (manager *managerImpl) FetchZones(poolSize, batchSize int, block bool) (cha
 	// that writing to the channel doesn't block. Otherwise, set the
 	// length of 0 to make the channel blocking.
 	bufLen := 1
-	if block {
+	if slices.Contains(options, FetchZonesOptionBlock) {
 		bufLen = 0
 	}
 	notifyChannel := make(chan ManagerDoneNotify, bufLen)
@@ -415,7 +489,7 @@ func (manager *managerImpl) FetchZones(poolSize, batchSize int, block bool) (cha
 			go func(daemonsChan <-chan dbmodel.Daemon) {
 				// Read next daemon from the channel.
 				for daemon := range daemonsChan {
-					manager.fetchZonesFromDNSServer(&daemon, batchSize, &wg, &mutex, results)
+					manager.fetchZonesFromDNSServer(&daemon, batchSize, slices.Contains(options, FetchZonesOptionForcePopulate), &wg, &mutex, results)
 				}
 			}(daemonsChan)
 		}
@@ -451,11 +525,13 @@ func (manager *managerImpl) FetchZones(poolSize, batchSize int, block bool) (cha
 // Contacts a specified DNS server and fetches zones from it. The daemon
 // indicates the DNS server to contact. The batchSize parameter controls
 // the size of the batch of zones to be inserted into the database in a single
-// SQL INSERT. The wg and mutex parameters are used to synchronize the work
+// SQL INSERT. The forcePopulate flag controls whether or not the zone inventory
+// should refresh the zones from the DNS server before returning to the Stork
+// server. The wg and mutex parameters are used to synchronize the work
 // between multiple goroutines. The results parameter is a map of errors for
 // respective daemons. This function can merely be called from the
 // FetchZones function.
-func (manager *managerImpl) fetchZonesFromDNSServer(daemon *dbmodel.Daemon, batchSize int, wg *sync.WaitGroup, mutex *sync.Mutex, results map[int64]*dbmodel.ZoneInventoryStateDetails) {
+func (manager *managerImpl) fetchZonesFromDNSServer(daemon *dbmodel.Daemon, batchSize int, forcePopulate bool, wg *sync.WaitGroup, mutex *sync.Mutex, results map[int64]*dbmodel.ZoneInventoryStateDetails) {
 	defer wg.Done()
 	var (
 		// Track views. We need to flush the batch when the view changes.
@@ -471,7 +547,7 @@ func (manager *managerImpl) fetchZonesFromDNSServer(daemon *dbmodel.Daemon, batc
 	// performance for large number of zones.
 	batch := dbmodel.NewBatch(manager.db, batchSize, dbmodel.AddZones)
 	state := dbmodel.NewZoneInventoryStateDetails()
-	for zone, err := range manager.agents.ReceiveZones(context.Background(), daemon, nil) {
+	for zone, err := range manager.agents.ReceiveZones(context.Background(), daemon, nil, forcePopulate) {
 		if err != nil {
 			// Returned status depends on the returned error type. Some
 			// errors require special handling.
@@ -737,8 +813,12 @@ func (manager *managerImpl) Shutdown() {
 // Returns zone contents (RRs) for a specified view, zone and daemon.
 // Depending on the options, the function may cache transferred RRs in
 // the database. A caller may also request forcing zone transfer to
-// override the cached RRs.
-func (manager *managerImpl) GetZoneRRs(zoneID int64, daemonID int64, viewName string, options ...GetZoneRRsOption) iter.Seq[*RRResponse] {
+// override the cached RRs. The GetZoneRRsOptionExcludeTrailingSOA option
+// can be specified to exclude the trailing SOA RR from the response.
+// The trailing SOA marks the end of the zone transfer. However, the
+// REST API handler typically excludes this last record as it is not
+// interesting to a user viewing the zone contents.
+func (manager *managerImpl) GetZoneRRs(zoneID int64, daemonID int64, viewName string, filter *dbmodel.GetZoneRRsFilter, options ...GetZoneRRsOption) iter.Seq[*RRResponse] {
 	return func(yield func(*RRResponse) bool) {
 		// We need a daemon associated with the zone.
 		daemon, err := dbmodel.GetDNSDaemonByID(manager.db, daemonID)
@@ -777,13 +857,13 @@ func (manager *managerImpl) GetZoneRRs(zoneID int64, daemonID int64, viewName st
 		// from the database.
 		if !slices.Contains(options, GetZoneRRsOptionForceZoneTransfer) && localZone.ZoneTransferAt != nil {
 			// Get cached RRs from the database and return to the caller.
-			rrs, err := dbmodel.GetDNSConfigRRs(manager.db, localZone.ID)
+			rrs, total, err := dbmodel.GetDNSConfigRRs(manager.db, localZone.ID, filter)
 			if err != nil {
 				_ = yield(NewErrorRRResponse(err))
 				return
 			}
 			// This response indicates that the RRs were fetched from the database.
-			_ = yield(NewCacheRRResponse(rrs, *localZone.ZoneTransferAt))
+			_ = yield(NewCacheRRResponse(rrs, total, *localZone.ZoneTransferAt))
 			return
 		}
 		// To avoid sending multiple requests for the same zone, we should check
@@ -808,7 +888,7 @@ func (manager *managerImpl) GetZoneRRs(zoneID int64, daemonID int64, viewName st
 		}
 		defer func() {
 			err := tx.Rollback()
-			if err != nil {
+			if err != nil && !errors.Is(err, pg.ErrTxDone) {
 				log.WithError(err).Error("Failed to rollback the transaction for caching RRs")
 			}
 		}()
@@ -824,6 +904,12 @@ func (manager *managerImpl) GetZoneRRs(zoneID int64, daemonID int64, viewName st
 		}
 		// Batch insert RRs into the database.
 		batch := dbmodel.NewBatch(tx, 100, dbmodel.AddLocalZoneRRs)
+		// Tracks position in the RRs stream. It points to the index of the next
+		// RR to be received from the channel, starting from 0. It is required to
+		// extract a subset of RRs to be returned according to the paging filter.
+		pos := 0
+		// Check if this is the first chunk of RRs.
+		isFirst := true
 		for r := range ch {
 			if r.Err != nil {
 				// There was an error reading from the channel. The channel will be closed and
@@ -831,6 +917,24 @@ func (manager *managerImpl) GetZoneRRs(zoneID int64, daemonID int64, viewName st
 				_ = yield(r)
 				return
 			}
+			if slices.Contains(options, GetZoneRRsOptionExcludeTrailingSOA) {
+				// Check if this is not a trailing SOA RR. If this is the first
+				// chunk of RRs, the first record should be SOA and we must not
+				// remove it. Therefore, we only remove the last record from the
+				// first chunk, assuming this last record is a SOA and is not the
+				// first record (single record case). For subsequent chunks we remove
+				// the last record if it is a SOA record. Note that we have not means
+				// to check if this is truly the last record in the stream because
+				// we don't know if we have reached the end of the stream. If there
+				// are any mid-stream SOA records they may not be removed. Also,
+				// some mid-stream SOA records may be removed if they appear at the
+				// end of the chunk of data.
+				if isFirst && len(r.RRs) > 1 && r.RRs[len(r.RRs)-1].Type == "SOA" ||
+					!isFirst && len(r.RRs) > 0 && r.RRs[len(r.RRs)-1].Type == "SOA" {
+					r.RRs = r.RRs[:len(r.RRs)-1]
+				}
+				isFirst = false
+			}
 			for _, rr := range r.RRs {
 				// Insert next RR into the database.
 				if err := batch.Add(&dbmodel.LocalZoneRR{
@@ -842,7 +946,10 @@ func (manager *managerImpl) GetZoneRRs(zoneID int64, daemonID int64, viewName st
 					return
 				}
 			}
-			if !yield(r) {
+			// Select only the records matching the filter.
+			var filteredResponse *RRResponse
+			filteredResponse, pos = r.applyFilter(filter, pos)
+			if !yield(filteredResponse) {
 				// Stop reading and caching the RRs if the caller is done reading.
 				return
 			}
@@ -889,11 +996,18 @@ func (manager *managerImpl) GetBind9FormattedConfig(ctx context.Context, daemonI
 			_ = yield(NewBind9FormattedConfigResponseError(err))
 			return
 		}
-		for r := range ch {
-			if !yield(r) || r.Err != nil {
-				// Stop reading the BIND 9 configuration if the caller is done reading
-				// or there was an error reading from the channel.
+
+		for {
+			select {
+			case <-ctx.Done():
+				// The caller stopped reading the BIND 9 configuration.
 				return
+			case r, ok := <-ch:
+				if !ok || !yield(r) || r.Err != nil {
+					// Stop reading the BIND 9 configuration if the caller is done reading
+					// or there was an error reading from the channel.
+					return
+				}
 			}
 		}
 	}
