@@ -2,7 +2,7 @@ package eventcenter
 
 import (
 	"testing"
-	"time"
+	"testing/synctest"
 
 	pkgerrors "github.com/pkg/errors"
 	"github.com/stretchr/testify/require"
@@ -77,7 +77,7 @@ func TestCreateEventDaemon(t *testing.T) {
 	ev := CreateEvent(dbmodel.EvError, "foo {daemon} bar", daemon)
 
 	// Assert
-	require.EqualValues(t, "foo <daemon id=\"234\" name=\"dhcp4\" machineId=\"456\" appId=\"918947245\" appType=\"kea\"> bar", ev.Text)
+	require.EqualValues(t, "foo <daemon id=\"234\" name=\"dhcp4\" machineId=\"456\"> bar", ev.Text)
 	require.EqualValues(t, dbmodel.EvError, ev.Level)
 	require.NotNil(t, ev.Relations)
 	require.EqualValues(t, 456, ev.Relations.MachineID)
@@ -88,6 +88,33 @@ func TestCreateEventDaemon(t *testing.T) {
 	require.Zero(t, ev.CreatedAt)
 }
 
+// Test that the event with a daemon entry but without assigned ID is created properly.
+func TestCreateEventDaemonWithoutID(t *testing.T) {
+	// Arrange
+	daemon := &dbmodel.Daemon{
+		Name:      "dhcp4",
+		MachineID: 456,
+		Machine: &dbmodel.Machine{
+			ID: 456,
+		},
+		AccessPoints: []*dbmodel.AccessPoint{{
+			Type:    dbmodel.AccessPointControl,
+			Address: "localhost",
+			Port:    8080,
+		}},
+	}
+
+	// Act
+	ev := CreateEvent(dbmodel.EvError, "foo {daemon} bar", daemon)
+
+	// Assert
+	require.EqualValues(t, "foo <daemon id=\"0\" name=\"dhcp4\" machineId=\"456\"> bar", ev.Text)
+	require.EqualValues(t, dbmodel.EvError, ev.Level)
+	require.NotNil(t, ev.Relations)
+	require.EqualValues(t, 456, ev.Relations.MachineID)
+	require.Zero(t, ev.Relations.DaemonID)
+}
+
 // Test that the event with a daemon entry is created properly even if the
 // daemon misses the machine reference.
 func TestCreateEventDaemonWithoutMachine(t *testing.T) {
@@ -108,7 +135,7 @@ func TestCreateEventDaemonWithoutMachine(t *testing.T) {
 	ev := CreateEvent(dbmodel.EvError, "foo {daemon} bar", daemon)
 
 	// Assert
-	require.EqualValues(t, "foo <daemon id=\"234\" name=\"dhcp4\" machineId=\"456\" appId=\"918947245\" appType=\"kea\"> bar", ev.Text)
+	require.EqualValues(t, "foo <daemon id=\"234\" name=\"dhcp4\" machineId=\"456\"> bar", ev.Text)
 	require.EqualValues(t, dbmodel.EvError, ev.Level)
 	require.NotNil(t, ev.Relations)
 	require.EqualValues(t, 456, ev.Relations.MachineID)
@@ -188,7 +215,7 @@ func TestCreateEventMachineAndDaemon(t *testing.T) {
 	ev := CreateEvent(dbmodel.EvInfo, "foo {daemon} bar {machine} baz", daemon, machine)
 
 	// Assert
-	require.EqualValues(t, "foo <daemon id=\"234\" name=\"dhcp4\" machineId=\"123\" appId=\"0\" appType=\"kea\"> bar <machine id=\"123\" address=\"foo\" hostname=\"bar\"> baz", ev.Text)
+	require.EqualValues(t, "foo <daemon id=\"234\" name=\"dhcp4\" machineId=\"123\"> bar <machine id=\"123\" address=\"foo\" hostname=\"bar\"> baz", ev.Text)
 	require.EqualValues(t, dbmodel.EvInfo, ev.Level)
 	require.NotNil(t, ev.Relations)
 
@@ -381,37 +408,38 @@ func TestAddEvent(t *testing.T) {
 	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
 	defer teardown()
 
-	ec := NewEventCenter(db)
+	synctest.Test(t, func(t *testing.T) {
+		ec := NewEventCenter(db)
+		defer ec.Shutdown()
 
-	subnet := &dbmodel.Subnet{
-		ID: 345,
-	}
-	machine := &dbmodel.Machine{
-		ID: 456,
-	}
-	daemon := &dbmodel.Daemon{
-		Name:      "dhcp4",
-		MachineID: machine.ID,
-		Machine:   machine,
-	}
+		subnet := &dbmodel.Subnet{
+			ID: 345,
+		}
+		machine := &dbmodel.Machine{
+			ID: 456,
+		}
+		daemon := &dbmodel.Daemon{
+			Name:      "dhcp4",
+			MachineID: machine.ID,
+			Machine:   machine,
+		}
 
-	ec.AddInfoEvent("some text", daemon, machine)
-	ec.AddWarningEvent("some text", subnet, machine)
-	ec.AddErrorEvent("some text", daemon, machine)
+		ec.AddInfoEvent("some text", daemon, machine)
+		ec.AddWarningEvent("some text", subnet, machine)
+		ec.AddErrorEvent("some text", daemon, machine)
 
-	// events are stored in db in separate goroutine so it may be delay
-	// so wait for it a little bit
-	var events []dbmodel.Event
-	var total int64
-	var err error
+		// events are stored in db in separate goroutine so it may be delay
+		// so wait for it a little bit
+		var events []dbmodel.Event
+		var total int64
+		var err error
 
-	require.Eventually(t, func() bool {
-		events, total, err = dbmodel.GetEventsByPage(db, 0, 10, 0, nil, nil, nil, "", dbmodel.SortDirAny)
-		return total >= 3
-	}, time.Second, 10*time.Millisecond)
+		synctest.Wait()
+		events, total, err = dbmodel.GetEventsByPage(db, 0, 10, 0, nil, nil, nil, nil, "", dbmodel.SortDirAny)
 
-	require.NoError(t, err)
-	require.EqualValues(t, 3, total)
-	require.Len(t, events, 3)
-	require.EqualValues(t, "some text", events[0].Text)
+		require.NoError(t, err)
+		require.EqualValues(t, 3, total)
+		require.Len(t, events, 3)
+		require.EqualValues(t, "some text", events[0].Text)
+	})
 }
