@@ -45,8 +45,8 @@ func TestSetFilterValues(t *testing.T) {
 
 	// Use an URL with all parameters set.
 	url, err := url.Parse(fmt.Sprintf(
-		"http://example.org/sse?stream=connectivity&stream=message&machine=1&app=%d&subnet=3&daemon=%d&user=5&level=1",
-		daemon.GetVirtualApp().ID, daemon.ID,
+		"http://example.org/sse?stream=connectivity&stream=message&machineId=1&&subnetId=3&daemonId=%d&userId=5&level=1",
+		daemon.ID,
 	))
 	require.NoError(t, err)
 
@@ -74,20 +74,11 @@ func TestAcceptEventsSingleFilter(t *testing.T) {
 	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
 	defer teardown()
 
-	server, err := dbmodeltest.NewKeaDHCPv4Server(db)
-	require.NoError(t, err)
-	daemon, err := server.GetDaemon()
-	require.NoError(t, err)
-
-	testCases := []string{"machine", "app", "subnet", "daemon", "user"}
+	testCases := []string{"machineId", "subnetId", "daemonId", "userId"}
 	for i := range testCases {
 		tc := testCases[i]
 		t.Run(tc, func(t *testing.T) {
 			id := int64(123)
-			if tc == "app" {
-				id = daemon.GetVirtualApp().ID
-			}
-
 			// Create an URL with a test case specific parameter.
 			rawURL := fmt.Sprintf("http://example.org/sse?stream=message&%s=%d", tc, id)
 			url, err := url.Parse(rawURL)
@@ -106,16 +97,13 @@ func TestAcceptEventsSingleFilter(t *testing.T) {
 				Relations: &dbmodel.Relations{},
 			}
 			switch tc {
-			case "machine":
+			case "machineId":
 				ev.Relations.MachineID = 123
-			case "app":
-				ev.Relations.MachineID = daemon.MachineID
-				ev.Relations.DaemonID = daemon.ID
-			case "subnet":
+			case "subnetId":
 				ev.Relations.SubnetID = 123
-			case "daemon":
+			case "daemonId":
 				ev.Relations.DaemonID = 123
-			case "user":
+			case "userId":
 				ev.Relations.UserID = 123
 			}
 			// Event should be accepted.
@@ -139,10 +127,10 @@ func TestAcceptEventsMultipleFilters(t *testing.T) {
 	daemon, err := server.GetDaemon()
 	require.NoError(t, err)
 
-	// Create a filtering rule by machine ID, app ID and warning event level.
+	// Create a filtering rule by machine ID, daemon ID and warning event level.
 	url, err := url.Parse(fmt.Sprintf(
-		"http://example.org/sse?stream=message&machine=%d&app=%d&daemon=%d&level=%d",
-		daemon.MachineID, daemon.GetVirtualApp().ID, daemon.ID, dbmodel.EvWarning,
+		"http://example.org/sse?stream=message&machineId=%d&daemonId=%d&level=%d",
+		daemon.MachineID, daemon.ID, dbmodel.EvWarning,
 	))
 	require.NoError(t, err)
 
@@ -154,7 +142,7 @@ func TestAcceptEventsMultipleFilters(t *testing.T) {
 
 	require.True(t, subscriber.useFilter)
 
-	// This event lacks app id so it should not be accepted.
+	// This event lacks daemon id so it should not be accepted.
 	ev := &dbmodel.Event{
 		Level: dbmodel.EvError,
 		Relations: &dbmodel.Relations{
@@ -204,9 +192,9 @@ func TestAcceptEventsMultipleFilters(t *testing.T) {
 	require.Contains(t, subscriber.findMatchingEventStreams(ev), dbmodel.SSERegularMessage)
 }
 
-// Test that appType and daemonName can be specified instead of app and daemon
-// parameters when machine id is also provided.
-func TestIndirectRelationsAppTypeDaemonName(t *testing.T) {
+// Test that daemonName can be specified instead of daemon ID when machine ID
+// is also provided.
+func TestIndirectRelationsDaemonName(t *testing.T) {
 	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
 	defer teardown()
 
@@ -217,7 +205,7 @@ func TestIndirectRelationsAppTypeDaemonName(t *testing.T) {
 	daemon, err := server.GetDaemon()
 	require.NoError(t, err)
 
-	url, err := url.Parse("http://example.org/sse?stream=message&machine=1&appType=kea&daemonName=dhcp4&level=1")
+	url, err := url.Parse("http://example.org/sse?stream=message&machineId=1&daemonName=dhcp4&level=1")
 	require.NoError(t, err)
 
 	subscriber := newSubscriber(url, "localhost:8080")
@@ -234,7 +222,7 @@ func TestIndirectRelationsAppTypeDaemonName(t *testing.T) {
 	require.Equal(t, "localhost:8080", subscriber.subscriberAddress)
 }
 
-// Test that invalid combination of appType and daemonName parameters with other
+// Test that invalid combination of daemonName parameters with other
 // parameters yields an error.
 func TestIndirectRelationsWrongParams(t *testing.T) {
 	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
@@ -246,8 +234,8 @@ func TestIndirectRelationsWrongParams(t *testing.T) {
 	require.NoError(t, err)
 
 	t.Run("NoMachineID", func(t *testing.T) {
-		// App type and daemon name require machine id.
-		url, err := url.Parse("http://example.org/sse?stream=message&appType=kea&daemonName=dhcp4")
+		// Daemon name requires machine ID.
+		url, err := url.Parse("http://example.org/sse?stream=message&daemonName=dhcp4")
 		require.NoError(t, err)
 
 		subscriber := newSubscriber(url, "localhost:8080")
@@ -269,22 +257,9 @@ func TestIndirectRelationsWrongParams(t *testing.T) {
 		require.Error(t, err)
 	})
 
-	t.Run("app ID and app type", func(t *testing.T) {
-		// App type is ignored.
-		rawURL := fmt.Sprintf("http://example.org/sse?stream=message&machine=1&app=%d&appType=kea", daemon.GetVirtualApp().ID)
-		url, err := url.Parse(rawURL)
-		require.NoError(t, err)
-
-		subscriber := newSubscriber(url, "localhost:8080")
-		require.NotNil(t, subscriber)
-
-		err = subscriber.applyFiltersFromQuery(db)
-		require.NoError(t, err)
-	})
-
 	t.Run("daemon ID and daemon name", func(t *testing.T) {
 		// Daemon ID with daemon name are mutually exclusive.
-		rawURL := fmt.Sprintf("http://example.org/sse?stream=message&machine=1&appType=kea&daemon=%d&daemonName=dhcp4",
+		rawURL := fmt.Sprintf("http://example.org/sse?stream=message&machineId=1&daemonId=%d&daemonName=dhcp4",
 			daemon.ID)
 		url, err := url.Parse(rawURL)
 		require.NoError(t, err)
