@@ -15,9 +15,9 @@ import (
 	storkutil "isc.org/stork/util"
 )
 
-func (r *RestAPI) getEvents(offset, limit int64, level dbmodel.EventLevel, daemonName *string, machineID *int64, userID *int64, sortField string, sortDir dbmodel.SortDirEnum) (*models.Events, error) {
+func (r *RestAPI) getEvents(offset, limit int64, level dbmodel.EventLevel, daemonName *string, machineID *int64, daemonID *int64, userID *int64, sortField string, sortDir dbmodel.SortDirEnum) (*models.Events, error) {
 	// Get the events from the database.
-	dbEvents, total, err := dbmodel.GetEventsByPage(r.DB, offset, limit, level, daemonName, machineID, userID, sortField, sortDir)
+	dbEvents, total, err := dbmodel.GetEventsByPage(r.DB, offset, limit, level, daemonName, machineID, daemonID, userID, sortField, sortDir)
 	if err != nil {
 		return nil, err
 	}
@@ -69,7 +69,7 @@ func (r *RestAPI) GetEvents(ctx context.Context, params events.GetEventsParams)
 	}
 
 	// get events from db
-	eventRecs, err := r.getEvents(start, limit, level, params.DaemonType, params.Machine, params.User, sortField, sortDir)
+	eventRecs, err := r.getEvents(start, limit, level, params.DaemonName, params.MachineID, params.DaemonID, params.UserID, sortField, sortDir)
 	if err != nil {
 		msg := "Problem fetching events from the database"
 		log.WithError(err).Error(msg)
