@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"net/http"
+	"regexp"
 	"strings"
 
 	"github.com/go-openapi/runtime/middleware"
@@ -343,6 +344,17 @@ func (r *RestAPI) CreateUser(ctx context.Context, params users.CreateUserParams)
 		return users.NewCreateUserDefault(http.StatusBadRequest).WithPayload(&rspErr)
 	}
 
+	// Validate the new password against the password policy.
+	validationProblems := validatePassword(string(*p))
+	if len(validationProblems) > 0 {
+		msg := fmt.Sprintf("The password does not meet the password policy: %s", strings.Join(validationProblems, ", "))
+		rspErr := models.APIError{
+			Message: &msg,
+		}
+		rsp := users.NewCreateUserDefault(http.StatusBadRequest).WithPayload(&rspErr)
+		return rsp
+	}
+
 	su := &dbmodel.SystemUser{
 		Login:          u.Login,
 		Email:          u.Email,
@@ -413,6 +425,23 @@ func (r *RestAPI) UpdateUser(ctx context.Context, params users.UpdateUserParams)
 		return users.NewCreateUserDefault(http.StatusBadRequest).WithPayload(&rspErr)
 	}
 
+	password := ""
+	if p != nil {
+		password = string(*p)
+	}
+	if password != "" {
+		// Validate the new password against the password policy.
+		validationProblems := validatePassword(password)
+		if len(validationProblems) > 0 {
+			msg := fmt.Sprintf("The password does not meet the password policy: %s", strings.Join(validationProblems, ", "))
+			rspErr := models.APIError{
+				Message: &msg,
+			}
+			rsp := users.NewUpdateUserDefault(http.StatusBadRequest).WithPayload(&rspErr)
+			return rsp
+		}
+	}
+
 	isInternal := u.AuthenticationMethodID == nil || *u.AuthenticationMethodID == dbmodel.AuthenticationMethodIDInternal
 	if isInternal && (u.Name == "" || u.Lastname == "") {
 		msg := "Failed to update user account: missing first or last name"
@@ -461,10 +490,6 @@ func (r *RestAPI) UpdateUser(ctx context.Context, params users.UpdateUserParams)
 		return rsp
 	}
 
-	password := ""
-	if p != nil {
-		password = string(*p)
-	}
 	if password != "" {
 		err = dbmodel.SetPassword(r.DB, int(*u.ID), password)
 		if err != nil {
@@ -567,7 +592,75 @@ func (r *RestAPI) DeleteUser(ctx context.Context, params users.DeleteUserParams)
 	return users.NewDeleteUserOK().WithPayload(u)
 }
 
+// Regular expression defining valid characters in the password. It is the same
+// pattern as used in the UI.
+var validPasswordPattern *regexp.Regexp = regexp.MustCompile(`^[a-zA-Z0-9~` + "`" + `!@#$%^&*()_+\-=\[\]\\{}|;':",.\/<>?\s]+$`)
+
+// Validates the password policy requirements for the new password.
+// It must match the requirements defined in the UI.
+// See webui/src/app/password-change-page/password-change-page.component.ts.
+// Returns a list of validation error messages. If the list is empty,
+// the password meets the policy requirements.
+func validatePassword(password string) []string {
+	var validationErrors []string
+
+	// Check the minimum length.
+	if len(password) < 12 {
+		validationErrors = append(validationErrors, "password must be at least 12 characters long")
+	}
+
+	// Check the maximum length.
+	if len(password) > 120 {
+		validationErrors = append(validationErrors, "password must be at most 120 characters long")
+	}
+
+	// Check for allowed characters.
+	if !validPasswordPattern.MatchString(password) {
+		validationErrors = append(validationErrors, "password contains invalid characters")
+	}
+
+	// The password must include at least:
+	// - one uppercase letter
+	// - one lowercase letter
+	// - one digit
+	// - one special character
+	var hasUpper, hasLower, hasDigit, hasSpecial bool
+	for _, ch := range password {
+		isLowerLetter := ch >= 'a' && ch <= 'z'
+		isUpperLetter := ch >= 'A' && ch <= 'Z'
+		isDigit := ch >= '0' && ch <= '9'
+		isSpecial := !isLowerLetter && !isUpperLetter && !isDigit
+
+		switch {
+		case isLowerLetter:
+			hasLower = true
+		case isUpperLetter:
+			hasUpper = true
+		case isDigit:
+			hasDigit = true
+		case isSpecial:
+			hasSpecial = true
+		}
+	}
+
+	if !hasUpper {
+		validationErrors = append(validationErrors, "password must include at least one uppercase letter")
+	}
+	if !hasLower {
+		validationErrors = append(validationErrors, "password must include at least one lowercase letter")
+	}
+	if !hasDigit {
+		validationErrors = append(validationErrors, "password must include at least one digit")
+	}
+	if !hasSpecial {
+		validationErrors = append(validationErrors, "password must include at least one special character or whitespace")
+	}
+
+	return validationErrors
+}
+
 // Updates password of the given user in the database.
+// It validates if the new password meets the password policy requirements.
 func (r *RestAPI) UpdateUserPassword(ctx context.Context, params users.UpdateUserPasswordParams) middleware.Responder {
 	id := int(params.ID)
 	passwords := params.Passwords
@@ -582,6 +675,18 @@ func (r *RestAPI) UpdateUserPassword(ctx context.Context, params users.UpdateUse
 		return rsp
 	}
 
+	// Validate the new password against the password policy.
+	validationProblems := validatePassword(string(*passwords.Newpassword))
+	if len(validationProblems) > 0 {
+		log.WithField("userID", id).Infof("New password does not meet the password policy")
+		msg := fmt.Sprintf("New password does not meet the password policy: %s", strings.Join(validationProblems, ", "))
+		rspErr := models.APIError{
+			Message: &msg,
+		}
+		rsp := users.NewUpdateUserPasswordDefault(http.StatusBadRequest).WithPayload(&rspErr)
+		return rsp
+	}
+
 	// Try to change the password for the given user id. Including old password
 	// for verification and the new password which will only be set if this
 	// verification is successful.
