@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"net/http"
+	"strings"
 	"testing"
 
 	"github.com/stretchr/testify/require"
@@ -71,7 +72,7 @@ func TestCreateUserConflictLogin(t *testing.T) {
 	params := users.CreateUserParams{
 		Account: &models.UserAccount{
 			User:     newRestUser(su),
-			Password: storkutil.Ptr(models.Password("pass")),
+			Password: storkutil.Ptr(models.Password("StrongPassword1!")),
 		},
 	}
 
@@ -111,7 +112,7 @@ func TestCreateUserConflictEmail(t *testing.T) {
 	params := users.CreateUserParams{
 		Account: &models.UserAccount{
 			User:     newRestUser(su),
-			Password: storkutil.Ptr(models.Password("pass")),
+			Password: storkutil.Ptr(models.Password("StrongPassword1!")),
 		},
 	}
 
@@ -150,7 +151,7 @@ func TestCreateUserConflictEmailEmpty(t *testing.T) {
 	params := users.CreateUserParams{
 		Account: &models.UserAccount{
 			User:     newRestUser(su),
-			Password: storkutil.Ptr(models.Password("pass")),
+			Password: storkutil.Ptr(models.Password("StrongPassword1!")),
 		},
 	}
 
@@ -185,7 +186,7 @@ func TestCreateUserConflictEmailEmptyLogin(t *testing.T) {
 	params := users.CreateUserParams{
 		Account: &models.UserAccount{
 			User:     newRestUser(su),
-			Password: storkutil.Ptr(models.Password("pass")),
+			Password: storkutil.Ptr(models.Password("StrongPassword1!")),
 		},
 	}
 
@@ -305,7 +306,21 @@ func TestCreateUser(t *testing.T) {
 		},
 	}
 
+	// Attempt to create the user should be rejected due to weak password.
 	rsp := rapi.CreateUser(ctx, params)
+	require.IsType(t, &users.CreateUserDefault{}, rsp)
+	defaultRsp := rsp.(*users.CreateUserDefault)
+	require.Equal(t, http.StatusBadRequest, getStatusCode(*defaultRsp))
+	require.Contains(t, *defaultRsp.Payload.Message, "The password does not meet the password policy")
+
+	// Use a strong password and attempt to create the user again - it should succeed.
+	params = users.CreateUserParams{
+		Account: &models.UserAccount{
+			User:     newRestUser(su),
+			Password: storkutil.Ptr(models.Password("StrongPassword1!")),
+		},
+	}
+	rsp = rapi.CreateUser(ctx, params)
 	require.IsType(t, &users.CreateUserOK{}, rsp)
 	okRsp := rsp.(*users.CreateUserOK)
 	require.Greater(t, *okRsp.Payload.ID, int64(0))
@@ -322,7 +337,7 @@ func TestCreateUser(t *testing.T) {
 	// An attempt to create the same user should fail with HTTP error 409.
 	rsp = rapi.CreateUser(ctx, params)
 	require.IsType(t, &users.CreateUserDefault{}, rsp)
-	defaultRsp := rsp.(*users.CreateUserDefault)
+	defaultRsp = rsp.(*users.CreateUserDefault)
 	require.Equal(t, 409, getStatusCode(*defaultRsp))
 }
 
@@ -785,7 +800,7 @@ func TestUpdateUserInvalidUserID(t *testing.T) {
 	params := users.UpdateUserParams{
 		Account: &models.UserAccount{
 			User:     newRestUser(su),
-			Password: storkutil.Ptr(models.Password("pass")),
+			Password: storkutil.Ptr(models.Password("StrongPassword1!")),
 		},
 	}
 	rsp := rapi.UpdateUser(ctx, params)
@@ -815,8 +830,7 @@ func TestUpdateUserWithPassword(t *testing.T) {
 	require.False(t, con)
 	require.NoError(t, err)
 
-	// Modify some values and update the user.
-	su.Lastname = "Born"
+	// Modify password to be weak and verify that it is rejected.
 	params := users.UpdateUserParams{
 		Account: &models.UserAccount{
 			User:     newRestUser(su),
@@ -824,6 +838,20 @@ func TestUpdateUserWithPassword(t *testing.T) {
 		},
 	}
 	rsp := rapi.UpdateUser(ctx, params)
+	require.IsType(t, &users.UpdateUserDefault{}, rsp)
+	defaultRsp := rsp.(*users.UpdateUserDefault)
+	require.Equal(t, http.StatusBadRequest, getStatusCode(*defaultRsp))
+	require.Contains(t, *defaultRsp.Payload.Message, "The password does not meet the password policy")
+
+	// Modify some values and update the user.
+	su.Lastname = "Born"
+	params = users.UpdateUserParams{
+		Account: &models.UserAccount{
+			User:     newRestUser(su),
+			Password: storkutil.Ptr(models.Password("StrongPassword1!")),
+		},
+	}
+	rsp = rapi.UpdateUser(ctx, params)
 	require.IsType(t, &users.UpdateUserOK{}, rsp)
 
 	// Also check that the user has been updated in the database.
@@ -836,13 +864,12 @@ func TestUpdateUserWithPassword(t *testing.T) {
 	su.ID = 123
 	params = users.UpdateUserParams{
 		Account: &models.UserAccount{
-			User:     newRestUser(su),
-			Password: storkutil.Ptr(models.Password("pass")),
+			User: newRestUser(su),
 		},
 	}
 	rsp = rapi.UpdateUser(ctx, params)
 	require.IsType(t, &users.UpdateUserDefault{}, rsp)
-	defaultRsp := rsp.(*users.UpdateUserDefault)
+	defaultRsp = rsp.(*users.UpdateUserDefault)
 	require.Equal(t, 409, getStatusCode(*defaultRsp))
 }
 
@@ -896,6 +923,44 @@ func TestUpdateUserWithoutPassword(t *testing.T) {
 	require.Equal(t, 409, getStatusCode(*defaultRsp))
 }
 
+// Tests that user account with an empty password can be updated via REST API.
+func TestUpdateUserWithEmptyPassword(t *testing.T) {
+	db, dbSettings, teardown := dbtest.SetupDatabaseTestCase(t)
+	defer teardown()
+
+	ctx := context.Background()
+
+	rapi, err := NewRestAPI(dbSettings, db)
+	require.NoError(t, err)
+
+	// Create new user in the database.
+	su := dbmodel.SystemUser{
+		Email:          "jan@example.org",
+		Lastname:       "Kowalski",
+		Name:           "Jan",
+		ChangePassword: false,
+	}
+	con, err := dbmodel.CreateUser(db, &su)
+	require.False(t, con)
+	require.NoError(t, err)
+
+	// Modify some values and update the user.
+	su.Lastname = "Born"
+	params := users.UpdateUserParams{
+		Account: &models.UserAccount{
+			User:     newRestUser(su),
+			Password: storkutil.Ptr(models.Password("")),
+		},
+	}
+	rsp := rapi.UpdateUser(ctx, params)
+	require.IsType(t, &users.UpdateUserOK{}, rsp)
+
+	// Also check that the user has been updated in the database.
+	returned, err := dbmodel.GetUserByID(db, su.ID)
+	require.NoError(t, err)
+	require.Equal(t, su.Lastname, returned.Lastname)
+}
+
 // Tests that update user password with missing data is rejected via REST API.
 func TestUpdateUserPasswordMissingData(t *testing.T) {
 	db, dbSettings, teardown := dbtest.SetupDatabaseTestCase(t)
@@ -992,7 +1057,7 @@ func TestUpdateUserPassword(t *testing.T) {
 	params := users.UpdateUserPasswordParams{
 		ID: int64(user.ID),
 		Passwords: &models.PasswordChange{
-			Newpassword: storkutil.Ptr(models.Password("updated")),
+			Newpassword: storkutil.Ptr(models.Password("updatedPass2026!")),
 			Oldpassword: storkutil.Ptr(models.Password("pass")),
 		},
 	}
@@ -1005,7 +1070,7 @@ func TestUpdateUserPassword(t *testing.T) {
 	params = users.UpdateUserPasswordParams{
 		ID: int64(user.ID),
 		Passwords: &models.PasswordChange{
-			Newpassword: storkutil.Ptr(models.Password("updated")),
+			Newpassword: storkutil.Ptr(models.Password("updatedPass2026!")),
 			Oldpassword: storkutil.Ptr(models.Password("pass")),
 		},
 	}
@@ -1013,6 +1078,25 @@ func TestUpdateUserPassword(t *testing.T) {
 	require.IsType(t, &users.UpdateUserPasswordDefault{}, rsp)
 	defaultRsp := rsp.(*users.UpdateUserPasswordDefault)
 	require.Equal(t, http.StatusBadRequest, getStatusCode(*defaultRsp))
+
+	// An attempt to update the password with a new password that doesn't
+	// meet the password policy should also result in HTTP error 400 (Bad Request).
+	params = users.UpdateUserPasswordParams{
+		ID: int64(user.ID),
+		Passwords: &models.PasswordChange{
+			Newpassword: storkutil.Ptr(models.Password("short©")),
+			Oldpassword: storkutil.Ptr(models.Password("updatedPass2026!")),
+		},
+	}
+	rsp = rapi.UpdateUserPassword(ctx, params)
+	require.IsType(t, &users.UpdateUserPasswordDefault{}, rsp)
+	defaultRsp = rsp.(*users.UpdateUserPasswordDefault)
+	require.Equal(t, http.StatusBadRequest, getStatusCode(*defaultRsp))
+	require.Contains(t, *defaultRsp.Payload.Message, "New password does not meet the password policy")
+	require.Contains(t, *defaultRsp.Payload.Message, "at least 12 characters")
+	require.Contains(t, *defaultRsp.Payload.Message, "contains invalid characters")
+	require.Contains(t, *defaultRsp.Payload.Message, "at least one uppercase letter")
+	require.Contains(t, *defaultRsp.Payload.Message, "at least one digit")
 }
 
 // Tests that updating the user password via REST API causes the change
@@ -1044,7 +1128,7 @@ func TestUpdateUserPasswordResetChangePasswordFlag(t *testing.T) {
 	params := users.UpdateUserPasswordParams{
 		ID: int64(user.ID),
 		Passwords: &models.PasswordChange{
-			Newpassword: storkutil.Ptr(models.Password("updated")),
+			Newpassword: storkutil.Ptr(models.Password("updatedPass2026!")),
 			Oldpassword: storkutil.Ptr(models.Password("pass")),
 		},
 	}
@@ -1084,7 +1168,7 @@ func TestUpdateUserPasswordForPasswordlessUser(t *testing.T) {
 	params := users.UpdateUserPasswordParams{
 		ID: int64(user.ID),
 		Passwords: &models.PasswordChange{
-			Newpassword: storkutil.Ptr(models.Password("updated")),
+			Newpassword: storkutil.Ptr(models.Password("updatedPass2026!")),
 		},
 	}
 	rsp := rapi.UpdateUserPassword(ctx, params)
@@ -1094,6 +1178,52 @@ func TestUpdateUserPasswordForPasswordlessUser(t *testing.T) {
 	require.Equal(t, http.StatusBadRequest, getStatusCode(*defaultRsp))
 }
 
+// Test that the password validation function works as expected.
+func TestValidatePassword(t *testing.T) {
+	passwordEmptyProblems := validatePassword("")
+	require.NotEmpty(t, passwordEmptyProblems)
+	require.Contains(t, passwordEmptyProblems[0], "at least 12 characters")
+
+	passwordTooShortProblems := validatePassword("short")
+	require.NotEmpty(t, passwordTooShortProblems)
+	require.Contains(t, passwordTooShortProblems[0], "at least 12 characters")
+
+	passwordTooLong := validatePassword(strings.Repeat("a", 121))
+	require.NotEmpty(t, passwordTooLong)
+	require.Contains(t, passwordTooLong[0], "at most 120 characters")
+
+	passwordWithInvalidChars := validatePassword("®√©∆÷…ĺ„•¶")
+	require.NotEmpty(t, passwordWithInvalidChars)
+	require.Contains(t, passwordWithInvalidChars[0], "contains invalid characters")
+
+	passwordHasNoLowerLetters := validatePassword("PASSWORD1234!")
+	require.NotEmpty(t, passwordHasNoLowerLetters)
+	require.Contains(t, passwordHasNoLowerLetters[0], "at least one lowercase letter")
+
+	passwordHasNoUpperLetters := validatePassword("password1234!")
+	require.NotEmpty(t, passwordHasNoUpperLetters)
+	require.Contains(t, passwordHasNoUpperLetters[0], "at least one uppercase letter")
+
+	passwordHasNoDigits := validatePassword("Password!!!!")
+	require.NotEmpty(t, passwordHasNoDigits)
+	require.Contains(t, passwordHasNoDigits[0], "at least one digit")
+
+	passwordHasNoSpecialChars := validatePassword("Password1234")
+	require.NotEmpty(t, passwordHasNoSpecialChars)
+	require.Contains(t, passwordHasNoSpecialChars[0], "at least one special character or whitespace")
+
+	passwordWithManyProblems := validatePassword("®")
+	require.Len(t, passwordWithManyProblems, 5)
+	require.Contains(t, passwordWithManyProblems[0], "at least 12 characters")
+	require.Contains(t, passwordWithManyProblems[1], "contains invalid characters")
+	require.Contains(t, passwordWithManyProblems[2], "at least one uppercase letter")
+	require.Contains(t, passwordWithManyProblems[3], "at least one lowercase letter")
+	require.Contains(t, passwordWithManyProblems[4], "at least one digit")
+
+	validPassword := validatePassword("Password2026!") // sic!
+	require.Empty(t, validPassword)
+}
+
 // Tests that multiple groups can be fetched from the database.
 func TestGetGroups(t *testing.T) {
 	db, dbSettings, teardown := dbtest.SetupDatabaseTestCase(t)
