@@ -43,17 +43,15 @@ func (r *RestAPI) GetZone(ctx context.Context, params dns.GetZoneParams) middlew
 	// Zone found. Convert it to the format used in REST API.
 	var restLocalZones []*models.LocalZone
 	for _, localZone := range dbZone.LocalZones {
-		virtualApp := localZone.Daemon.GetVirtualApp()
 		restLocalZones = append(restLocalZones, &models.LocalZone{
-			AppID:    virtualApp.ID,
-			AppName:  virtualApp.Name,
-			Class:    localZone.Class,
-			DaemonID: localZone.DaemonID,
-			LoadedAt: strfmt.DateTime(localZone.LoadedAt),
-			Serial:   localZone.Serial,
-			Rpz:      localZone.RPZ,
-			View:     localZone.View,
-			ZoneType: localZone.Type,
+			ZoneClass:   localZone.Class,
+			DaemonID:    localZone.DaemonID,
+			DaemonLabel: localZone.Daemon.GetLabel(),
+			LoadedAt:    strfmt.DateTime(localZone.LoadedAt),
+			Serial:      localZone.Serial,
+			Rpz:         localZone.RPZ,
+			View:        localZone.View,
+			ZoneType:    localZone.Type,
 		})
 	}
 	restZone := models.Zone{
@@ -85,52 +83,24 @@ func (r *RestAPI) GetZones(ctx context.Context, params dns.GetZonesParams) middl
 	if params.SortDir != nil {
 		sortDir = dbmodel.SortDirEnum(*params.SortDir)
 	}
-
-	var daemonName *daemonname.Name
-	if params.AppType != nil {
-		switch *params.AppType {
-		case "bind9":
-			daemonName = storkutil.Ptr(daemonname.Bind9)
-		case "pdns":
-			daemonName = storkutil.Ptr(daemonname.PDNS)
-		default:
-			// Unknown app type, return empty result.
-			payload := models.Zones{
-				Items: []*models.Zone{},
-				Total: 0,
-			}
-			rsp := dns.NewGetZonesOK().WithPayload(&payload)
-			return rsp
-		}
-	}
-
-	var machineIDPtr *int64
-	if params.AppID != nil {
-		machineID, err := dbmodel.GetMachineIDByVirtualAppID(r.DB, *params.AppID)
-		if err != nil {
-			msg := "Failed to get machine ID by virtual app ID"
-			log.WithError(err).Error(msg)
-			rsp := dns.NewGetZonesDefault(http.StatusInternalServerError).WithPayload(&models.APIError{
+	var daemonNamePtr *daemonname.Name
+	if params.DaemonName != nil {
+		daemonName, ok := daemonname.Parse(*params.DaemonName)
+		if !ok {
+			msg := fmt.Sprintf("Invalid daemon name: %s", *params.DaemonName)
+			log.Error(msg)
+			rsp := dns.NewGetZonesDefault(http.StatusBadRequest).WithPayload(&models.APIError{
 				Message: &msg,
 			})
 			return rsp
 		}
-		if machineID == 0 {
-			// No machine with the specified virtual app ID exist, return empty result.
-			payload := models.Zones{
-				Items: []*models.Zone{},
-				Total: 0,
-			}
-			rsp := dns.NewGetZonesOK().WithPayload(&payload)
-			return rsp
-		}
-		machineIDPtr = &machineID
+		daemonNamePtr = &daemonName
 	}
 
 	// Apply paging parameters and zone-specific filters.
 	filter := &dbmodel.GetZonesFilter{
-		MachineID:  machineIDPtr,
-		DaemonName: daemonName,
+		DaemonID:   params.DaemonID,
+		DaemonName: daemonNamePtr,
 		Class:      params.Class,
 		RPZ:        params.Rpz,
 		Serial:     params.Serial,
@@ -142,7 +112,12 @@ func (r *RestAPI) GetZones(ctx context.Context, params dns.GetZonesParams) middl
 		filter.EnableZoneType(dbmodel.ZoneType(zoneType))
 	}
 	// Get the zones from the database.
-	zones, total, err := dbmodel.GetZones(r.DB, filter, sortField, sortDir, dbmodel.ZoneRelationLocalZonesDaemon, dbmodel.ZoneRelationLocalZonesAccessPoints, dbmodel.ZoneRelationLocalZonesMachine)
+	zones, total, err := dbmodel.GetZones(
+		r.DB, filter, sortField, sortDir,
+		dbmodel.ZoneRelationLocalZonesDaemon,
+		dbmodel.ZoneRelationLocalZonesAccessPoints,
+		dbmodel.ZoneRelationLocalZonesMachine,
+	)
 	if err != nil {
 		msg := "Failed to get zones from the database"
 		log.WithError(err).Error(msg)
@@ -157,17 +132,15 @@ func (r *RestAPI) GetZones(ctx context.Context, params dns.GetZonesParams) middl
 	for _, zone := range zones {
 		var restLocalZones []*models.LocalZone
 		for _, localZone := range zone.LocalZones {
-			app := localZone.Daemon.GetVirtualApp()
 			restLocalZones = append(restLocalZones, &models.LocalZone{
-				AppID:    app.ID,
-				AppName:  app.Name,
-				Class:    localZone.Class,
-				DaemonID: localZone.DaemonID,
-				LoadedAt: strfmt.DateTime(localZone.LoadedAt),
-				Serial:   localZone.Serial,
-				Rpz:      localZone.RPZ,
-				View:     localZone.View,
-				ZoneType: localZone.Type,
+				ZoneClass:   localZone.Class,
+				DaemonID:    localZone.DaemonID,
+				DaemonLabel: localZone.Daemon.GetLabel(),
+				LoadedAt:    strfmt.DateTime(localZone.LoadedAt),
+				Serial:      localZone.Serial,
+				Rpz:         localZone.RPZ,
+				View:        localZone.View,
+				ZoneType:    localZone.Type,
 			})
 		}
 		restZones = append(restZones, &models.Zone{
@@ -188,16 +161,21 @@ func (r *RestAPI) GetZones(ctx context.Context, params dns.GetZonesParams) middl
 
 // Get the states of fetching the DNS zone information from the remote zone inventories.
 func (r *RestAPI) GetZonesFetch(ctx context.Context, params dns.GetZonesFetchParams) middleware.Responder {
-	isFetching, appsCount, completedAppsCount := r.DNSManager.GetFetchZonesProgress()
+	isFetching, daemonsCount, completedDaemonsCount := r.DNSManager.GetFetchZonesProgress()
 	if isFetching {
 		payload := models.ZonesFetchStatus{
-			CompletedAppsCount: int64(completedAppsCount),
-			AppsCount:          int64(appsCount),
+			CompletedDaemonsCount: int64(completedDaemonsCount),
+			DaemonsCount:          int64(daemonsCount),
 		}
 		rsp := dns.NewGetZonesFetchAccepted().WithPayload(&payload)
 		return rsp
 	}
-	states, count, err := dbmodel.GetZoneInventoryStates(r.DB, dbmodel.ZoneInventoryStateRelationDaemon, dbmodel.ZoneInventoryStateRelationAccessPoints, dbmodel.ZoneInventoryStateRelationMachine)
+	states, count, err := dbmodel.GetZoneInventoryStates(
+		r.DB,
+		dbmodel.ZoneInventoryStateRelationDaemon,
+		dbmodel.ZoneInventoryStateRelationAccessPoints,
+		dbmodel.ZoneInventoryStateRelationMachine,
+	)
 	if err != nil {
 		msg := "Failed to get zones fetch states from the database"
 		log.WithError(err).Error(msg)
@@ -212,12 +190,10 @@ func (r *RestAPI) GetZonesFetch(ctx context.Context, params dns.GetZonesFetchPar
 	}
 	var restStates []*models.ZoneInventoryState
 	for _, state := range states {
-		app := state.Daemon.GetVirtualApp()
 		restStates = append(restStates, &models.ZoneInventoryState{
-			AppID:              app.ID,
-			AppName:            app.Name,
 			CreatedAt:          strfmt.DateTime(state.CreatedAt),
 			DaemonID:           state.DaemonID,
+			DaemonLabel:        state.Daemon.GetLabel(),
 			Error:              state.State.Error,
 			Status:             string(state.State.Status),
 			ZoneConfigsCount:   state.State.ZoneCount,
@@ -235,8 +211,15 @@ func (r *RestAPI) GetZonesFetch(ctx context.Context, params dns.GetZonesFetchPar
 
 // Begins fetching the zones from the zone inventories into the Stork server.
 func (r *RestAPI) PutZonesFetch(ctx context.Context, params dns.PutZonesFetchParams) middleware.Responder {
-	var alreadyFetchingError *dnsop.ManagerAlreadyFetchingError
-	_, err := r.DNSManager.FetchZones(10, 1000, false)
+	var (
+		alreadyFetchingError *dnsop.ManagerAlreadyFetchingError
+		err                  error
+		options              []dnsop.FetchZonesOption
+	)
+	if params.ForcePopulate != nil && *params.ForcePopulate {
+		options = append(options, dnsop.FetchZonesOptionForcePopulate)
+	}
+	_, err = r.DNSManager.FetchZones(10, 1000, options...)
 	switch {
 	case err == nil, errors.As(err, &alreadyFetchingError):
 		return dns.NewPutZonesFetchAccepted()
@@ -253,20 +236,25 @@ func (r *RestAPI) PutZonesFetch(ctx context.Context, params dns.PutZonesFetchPar
 // Returns the zone contents (RRs) for a specified view, zone and daemon.
 // If the zone RRs are not present in the database, the zone transfer is
 // initiated. The transferred data is cached in the database and returned.
-// Future calls to this endpoint will return the cached data.
-
+// The returned data is filtered according to the parameters. However, all
+// RRs are cached regardless of the filtering. Future calls to this endpoint
+// will return the cached data.
 func (r *RestAPI) GetZoneRRs(ctx context.Context, params dns.GetZoneRRsParams) middleware.Responder {
 	var (
 		restRrs               []*models.ZoneRR
 		alreadyRequestedError *dnsop.ManagerRRsAlreadyRequestedError
 		busyError             *agentcomm.ZoneInventoryBusyError
 		notInitedError        *agentcomm.ZoneInventoryNotInitedError
+		cached                bool
+		zoneTransferAt        time.Time
+		total                 int
+		filter                *dbmodel.GetZoneRRsFilter
 	)
-	var (
-		cached         bool
-		zoneTransferAt time.Time
-	)
-	for rrResponse := range r.DNSManager.GetZoneRRs(params.ZoneID, params.DaemonID, params.ViewName) {
+	// Apply filtering if requested.
+	if params.Start != nil || params.Limit != nil || len(params.RrType) > 0 || params.Text != nil {
+		filter = dbmodel.NewGetZoneRRsFilterWithParams(params.Start, params.Limit, params.RrType, params.Text)
+	}
+	for rrResponse := range r.DNSManager.GetZoneRRs(params.ZoneID, params.DaemonID, params.ViewName, filter, dnsop.GetZoneRRsOptionExcludeTrailingSOA) {
 		if rrResponse.Err != nil {
 			msg := "Failed to get zone contents"
 			log.WithError(rrResponse.Err).Error(msg)
@@ -309,11 +297,17 @@ func (r *RestAPI) GetZoneRRs(ctx context.Context, params dns.GetZoneRRsParams) m
 		}
 		cached = rrResponse.Cached
 		zoneTransferAt = rrResponse.ZoneTransferAt
+		// If the records are not cached, the returned total number is increasing as the
+		// new records are returned by the agent. We don't know until the last record how many
+		// records are to be returned. Therefore, we track the total number and take the
+		// highest value.
+		total = max(total, rrResponse.Total)
 	}
 	// Return the zone contents.
 	payload := models.ZoneRRs{
 		Cached:         cached,
 		Items:          restRrs,
+		Total:          int64(total),
 		ZoneTransferAt: strfmt.DateTime(zoneTransferAt),
 	}
 	rsp := dns.NewGetZoneRRsOK().WithPayload(&payload)
@@ -321,8 +315,8 @@ func (r *RestAPI) GetZoneRRs(ctx context.Context, params dns.GetZoneRRsParams) m
 }
 
 // Refreshes the resource for a zone using zone transfer, and return the newly
-// cached RRs. The zone transfer is initiated regardless of whether the zone
-// RRs are present in the database or not.
+// cached RRs with filtering. The zone transfer is initiated regardless of whether
+// the zone RRs are present in the database or not.
 func (r *RestAPI) PutZoneRRsCache(ctx context.Context, params dns.PutZoneRRsCacheParams) middleware.Responder {
 	var (
 		restRrs               []*models.ZoneRR
@@ -331,8 +325,14 @@ func (r *RestAPI) PutZoneRRsCache(ctx context.Context, params dns.PutZoneRRsCach
 		notInitedError        *agentcomm.ZoneInventoryNotInitedError
 		cached                bool
 		zoneTransferAt        time.Time
+		total                 int
+		filter                *dbmodel.GetZoneRRsFilter
 	)
-	for rrResponse := range r.DNSManager.GetZoneRRs(params.ZoneID, params.DaemonID, params.ViewName, dnsop.GetZoneRRsOptionForceZoneTransfer) {
+	// Apply filtering if requested.
+	if params.Start != nil || params.Limit != nil || len(params.RrType) > 0 || params.Text != nil {
+		filter = dbmodel.NewGetZoneRRsFilterWithParams(params.Start, params.Limit, params.RrType, params.Text)
+	}
+	for rrResponse := range r.DNSManager.GetZoneRRs(params.ZoneID, params.DaemonID, params.ViewName, filter, dnsop.GetZoneRRsOptionForceZoneTransfer, dnsop.GetZoneRRsOptionExcludeTrailingSOA) {
 		if rrResponse.Err != nil {
 			msg := "Failed to refresh zone contents using zone transfer"
 			log.WithError(rrResponse.Err).Error(msg)
@@ -375,11 +375,17 @@ func (r *RestAPI) PutZoneRRsCache(ctx context.Context, params dns.PutZoneRRsCach
 		}
 		cached = rrResponse.Cached
 		zoneTransferAt = rrResponse.ZoneTransferAt
+		// The records are not cached because we're forcing the zone transfer. The returned
+		// total number is increasing as the new records are returned by the agent. We don't
+		// know until the last record how many records are to be returned. Therefore, we
+		// track the total number and take the highest value.
+		total = max(total, rrResponse.Total)
 	}
 	// Return the zone contents.
 	payload := models.ZoneRRs{
 		Cached:         cached,
 		Items:          restRrs,
+		Total:          int64(total),
 		ZoneTransferAt: strfmt.DateTime(zoneTransferAt),
 	}
 	rsp := dns.NewPutZoneRRsCacheOK().WithPayload(&payload)
