@@ -15,8 +15,8 @@ import (
 	dnslib "github.com/miekg/dns"
 	"github.com/stretchr/testify/require"
 	gomock "go.uber.org/mock/gomock"
-	dnsconfig "isc.org/stork/daemoncfg/dnsconfig"
 	"isc.org/stork/datamodel/daemonname"
+	dnsmodel "isc.org/stork/datamodel/dns"
 	"isc.org/stork/datamodel/protocoltype"
 	"isc.org/stork/server/agentcomm"
 	dbmodel "isc.org/stork/server/database/model"
@@ -50,7 +50,7 @@ func TestGetZones(t *testing.T) {
 	rapi, err := NewRestAPI(&settings, dbSettings, db)
 	require.NoError(t, err)
 
-	// Store zones in the database and associate them with our app.
+	// Store zones in the database and associate them with our daemon.
 	randomZones := testutil.GenerateRandomZones(25)
 	randomZones = testutil.GenerateMoreZonesWithClass(randomZones, 25, "CH")
 	randomZones = testutil.GenerateMoreZonesWithType(randomZones, 25, "secondary")
@@ -168,7 +168,7 @@ func TestGetZones(t *testing.T) {
 		require.Len(t, rspOK.Payload.Items, 25)
 		require.EqualValues(t, 25, rspOK.Payload.Total)
 		for _, zone := range rspOK.Payload.Items {
-			require.Equal(t, "CH", zone.LocalZones[0].Class)
+			require.Equal(t, "CH", zone.LocalZones[0].ZoneClass)
 		}
 	})
 
@@ -235,27 +235,25 @@ func TestGetZones(t *testing.T) {
 		require.Zero(t, rspOK.Payload.Total)
 	})
 
-	t.Run("filter by app ID", func(t *testing.T) {
+	t.Run("filter by daemon ID", func(t *testing.T) {
 		ctx := context.Background()
-		virtualApp := daemons[0].GetVirtualApp()
-		appID := virtualApp.ID
 		params := dns.GetZonesParams{
-			AppID: &appID,
+			DaemonID: &daemons[0].ID,
 		}
 		rsp := rapi.GetZones(ctx, params)
 		require.IsType(t, &dns.GetZonesOK{}, rsp)
 		rspOK := (rsp).(*dns.GetZonesOK)
 		require.NotEmpty(t, rspOK.Payload.Items)
 		require.Equal(t, 1, len(rspOK.Payload.Items))
-		require.EqualValues(t, virtualApp.ID, rspOK.Payload.Items[0].LocalZones[0].AppID)
+		require.EqualValues(t, daemons[0].ID, rspOK.Payload.Items[0].LocalZones[0].DaemonID)
 		require.EqualValues(t, 1, rspOK.Payload.Total)
 	})
 
-	t.Run("filter by non-existent app ID", func(t *testing.T) {
+	t.Run("filter by non-existent daemon ID", func(t *testing.T) {
 		ctx := context.Background()
-		appID := daemons[99].GetVirtualApp().ID + 100
+		daemonID := daemons[99].ID + 100
 		params := dns.GetZonesParams{
-			AppID: &appID,
+			DaemonID: &daemonID,
 		}
 		rsp := rapi.GetZones(ctx, params)
 		require.IsType(t, &dns.GetZonesOK{}, rsp)
@@ -264,12 +262,12 @@ func TestGetZones(t *testing.T) {
 		require.Zero(t, rspOK.Payload.Total)
 	})
 
-	t.Run("filter by DNS app type", func(t *testing.T) {
+	t.Run("filter by DNS daemon name", func(t *testing.T) {
 		ctx := context.Background()
-		appType := "bind9"
+		daemonName := daemonname.Bind9
 		params := dns.GetZonesParams{
-			AppType: &appType,
-			Limit:   storkutil.Ptr(int64(1000)),
+			DaemonName: (*string)(&daemonName),
+			Limit:      storkutil.Ptr(int64(1000)),
 		}
 		rsp := rapi.GetZones(ctx, params)
 		require.IsType(t, &dns.GetZonesOK{}, rsp)
@@ -278,11 +276,11 @@ func TestGetZones(t *testing.T) {
 		require.EqualValues(t, 125, rspOK.Payload.Total)
 	})
 
-	t.Run("filter by non-DNS app type", func(t *testing.T) {
+	t.Run("filter by non-DNS daemon name", func(t *testing.T) {
 		ctx := context.Background()
-		appType := "kea"
+		daemonName := daemonname.DHCPv4
 		params := dns.GetZonesParams{
-			AppType: &appType,
+			DaemonName: (*string)(&daemonName),
 		}
 		rsp := rapi.GetZones(ctx, params)
 		require.IsType(t, &dns.GetZonesOK{}, rsp)
@@ -401,7 +399,7 @@ func TestGetZone(t *testing.T) {
 	rapi, err := NewRestAPI(&settings, dbSettings, db)
 	require.NoError(t, err)
 
-	// Store zones in the database and associate them with our app.
+	// Store zones in the database and associate them with our daemon.
 	randomZones := testutil.GenerateRandomZones(5)
 	randomZones = testutil.GenerateMoreZonesWithClass(randomZones, 5, "CH")
 	randomZones = testutil.GenerateMoreZonesWithType(randomZones, 5, "secondary")
@@ -570,7 +568,7 @@ func TestGetZonesFetch(t *testing.T) {
 		require.Equal(t, d.DistinctZoneCount, rspOK.Payload.Items[index].DistinctZonesCount)
 		require.Equal(t, d.BuiltinZoneCount, rspOK.Payload.Items[index].BuiltinZonesCount)
 		require.Positive(t, rspOK.Payload.Items[index].DaemonID)
-		require.Positive(t, rspOK.Payload.Items[index].AppID)
+		require.NotEmpty(t, rspOK.Payload.Items[index].DaemonLabel)
 		require.NotZero(t, rspOK.Payload.Items[index].CreatedAt)
 	}
 }
@@ -597,8 +595,8 @@ func TestGetZonesFetchAlreadyFetching(t *testing.T) {
 	require.NotNil(t, rsp)
 	require.IsType(t, &dns.GetZonesFetchAccepted{}, rsp)
 	rspAccepted := (rsp).(*dns.GetZonesFetchAccepted)
-	require.EqualValues(t, 10, rspAccepted.Payload.AppsCount)
-	require.EqualValues(t, 5, rspAccepted.Payload.CompletedAppsCount)
+	require.EqualValues(t, 10, rspAccepted.Payload.DaemonsCount)
+	require.EqualValues(t, 5, rspAccepted.Payload.CompletedDaemonsCount)
 }
 
 // Test getting the zone inventory states when no state is available.
@@ -629,7 +627,7 @@ func TestPutZonesFetch(t *testing.T) {
 
 	ctrl := gomock.NewController(t)
 	mockManager := NewMockManager(ctrl)
-	mockManager.EXPECT().FetchZones(gomock.Any(), gomock.Any(), false).Return(nil, nil)
+	mockManager.EXPECT().FetchZones(gomock.Any(), gomock.Any()).Return(nil, nil)
 
 	settings := RestAPISettings{}
 	rapi, err := NewRestAPI(&settings, dbSettings, db, mockManager)
@@ -641,6 +639,28 @@ func TestPutZonesFetch(t *testing.T) {
 	require.IsType(t, &dns.PutZonesFetchAccepted{}, rsp)
 }
 
+// Test that the flag indicating that the zone inventory should be populated
+// is propagated from the REST API to the manager.
+func TestPutZonesFetchForcePopulate(t *testing.T) {
+	db, dbSettings, teardown := dbtest.SetupDatabaseTestCase(t)
+	defer teardown()
+
+	ctrl := gomock.NewController(t)
+	mockManager := NewMockManager(ctrl)
+	mockManager.EXPECT().FetchZones(gomock.Any(), gomock.Any(), dnsop.FetchZonesOptionForcePopulate).Return(nil, nil)
+
+	settings := RestAPISettings{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, mockManager)
+	require.NoError(t, err)
+	ctx := context.Background()
+
+	params := dns.PutZonesFetchParams{
+		ForcePopulate: storkutil.Ptr(true),
+	}
+	rsp := rapi.PutZonesFetch(ctx, params)
+	require.IsType(t, &dns.PutZonesFetchAccepted{}, rsp)
+}
+
 // Test that the HTTP Accepted status is returned upon an attempt to
 // fetch the zones while the fetch is already in progress.
 func TestPutZonesFetchAlreadyFetching(t *testing.T) {
@@ -649,7 +669,7 @@ func TestPutZonesFetchAlreadyFetching(t *testing.T) {
 
 	ctrl := gomock.NewController(t)
 	mockManager := NewMockManager(ctrl)
-	mockManager.EXPECT().FetchZones(gomock.Any(), gomock.Any(), false).Return(nil, &dnsop.ManagerAlreadyFetchingError{})
+	mockManager.EXPECT().FetchZones(gomock.Any(), gomock.Any()).Return(nil, &dnsop.ManagerAlreadyFetchingError{})
 
 	settings := RestAPISettings{}
 	rapi, err := NewRestAPI(&settings, dbSettings, db, mockManager)
@@ -669,7 +689,7 @@ func TestPutZonesFetchError(t *testing.T) {
 
 	ctrl := gomock.NewController(t)
 	mockManager := NewMockManager(ctrl)
-	mockManager.EXPECT().FetchZones(gomock.Any(), gomock.Any(), false).Return(nil, &testError{})
+	mockManager.EXPECT().FetchZones(gomock.Any(), gomock.Any()).Return(nil, &testError{})
 
 	settings := RestAPISettings{}
 	rapi, err := NewRestAPI(&settings, dbSettings, db, mockManager)
@@ -695,12 +715,18 @@ func TestGetZoneRRs(t *testing.T) {
 
 	ctrl := gomock.NewController(t)
 	mockManager := NewMockManager(ctrl)
-	mockManager.EXPECT().GetZoneRRs(gomock.Any(), gomock.Any(), gomock.Any()).DoAndReturn(func(zoneID int64, daemonID int64, viewName string, options ...dnsop.GetZoneRRsOption) iter.Seq[*dnsop.RRResponse] {
+	mockManager.EXPECT().GetZoneRRs(int64(1), int64(2), "trusted", gomock.Any(), dnsop.GetZoneRRsOptionExcludeTrailingSOA).DoAndReturn(func(zoneID int64, daemonID int64, viewName string, filter *dbmodel.GetZoneRRsFilter, options ...dnsop.GetZoneRRsOption) iter.Seq[*dnsop.RRResponse] {
+		// Ensure that the filter is applied.
+		require.NotNil(t, filter)
+		require.Equal(t, 1, filter.GetOffset())
+		require.Equal(t, 10, filter.GetLimit())
+		require.ElementsMatch(t, []string{"A", "AAAA", "SOA"}, filter.GetTypes())
+		require.Equal(t, "example.com", filter.GetText())
 		return func(yield func(*dnsop.RRResponse) bool) {
 			for _, rr := range rrs {
-				rr, err := dnsconfig.NewRR(rr)
+				rr, err := dnsmodel.NewRR(rr)
 				require.NoError(t, err)
-				if !yield(dnsop.NewZoneTransferRRResponse([]*dnsconfig.RR{rr})) {
+				if !yield(dnsop.NewZoneTransferRRResponse([]*dnsmodel.RR{rr})) {
 					return
 				}
 			}
@@ -716,6 +742,10 @@ func TestGetZoneRRs(t *testing.T) {
 		ZoneID:   1,
 		DaemonID: 2,
 		ViewName: "trusted",
+		Start:    storkutil.Ptr(int64(1)),
+		Limit:    storkutil.Ptr(int64(10)),
+		RrType:   []string{"A", "AAAA", "SOA"},
+		Text:     storkutil.Ptr("example.com"),
 	}
 	rsp := rapi.GetZoneRRs(ctx, params)
 	require.IsType(t, &dns.GetZoneRRsOK{}, rsp)
@@ -749,12 +779,18 @@ func TestPutZoneRRsCache(t *testing.T) {
 
 	ctrl := gomock.NewController(t)
 	mockManager := NewMockManager(ctrl)
-	mockManager.EXPECT().GetZoneRRs(gomock.Any(), gomock.Any(), gomock.Any(), dnsop.GetZoneRRsOptionForceZoneTransfer).AnyTimes().DoAndReturn(func(zoneID int64, daemonID int64, viewName string, options ...dnsop.GetZoneRRsOption) iter.Seq[*dnsop.RRResponse] {
+	mockManager.EXPECT().GetZoneRRs(int64(1), int64(2), "trusted", gomock.Any(), dnsop.GetZoneRRsOptionForceZoneTransfer, dnsop.GetZoneRRsOptionExcludeTrailingSOA).AnyTimes().DoAndReturn(func(zoneID int64, daemonID int64, viewName string, filter *dbmodel.GetZoneRRsFilter, options ...dnsop.GetZoneRRsOption) iter.Seq[*dnsop.RRResponse] {
+		// Ensure that the filter is applied.
+		require.NotNil(t, filter)
+		require.Equal(t, 1, filter.GetOffset())
+		require.Equal(t, 10, filter.GetLimit())
+		require.ElementsMatch(t, []string{"A", "AAAA", "SOA"}, filter.GetTypes())
+		require.Equal(t, "example.com", filter.GetText())
 		return func(yield func(*dnsop.RRResponse) bool) {
 			for _, rr := range rrs {
-				rr, err := dnsconfig.NewRR(rr)
+				rr, err := dnsmodel.NewRR(rr)
 				require.NoError(t, err)
-				if !yield(dnsop.NewZoneTransferRRResponse([]*dnsconfig.RR{rr})) {
+				if !yield(dnsop.NewZoneTransferRRResponse([]*dnsmodel.RR{rr})) {
 					return
 				}
 			}
@@ -770,6 +806,10 @@ func TestPutZoneRRsCache(t *testing.T) {
 		ZoneID:   1,
 		DaemonID: 2,
 		ViewName: "trusted",
+		Start:    storkutil.Ptr(int64(1)),
+		Limit:    storkutil.Ptr(int64(10)),
+		RrType:   []string{"A", "AAAA", "SOA"},
+		Text:     storkutil.Ptr("example.com"),
 	}
 	rsp := rapi.PutZoneRRsCache(ctx, params)
 	require.IsType(t, &dns.PutZoneRRsCacheOK{}, rsp)
@@ -823,7 +863,7 @@ func TestGetZoneRRsAnotherRequestInProgress(t *testing.T) {
 
 	ctrl := gomock.NewController(t)
 	mockManager := NewMockManager(ctrl)
-	mockManager.EXPECT().GetZoneRRs(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).AnyTimes().DoAndReturn(func(zoneID int64, daemonID int64, viewName string, options ...dnsop.GetZoneRRsOption) iter.Seq[*dnsop.RRResponse] {
+	mockManager.EXPECT().GetZoneRRs(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).AnyTimes().DoAndReturn(func(zoneID int64, daemonID int64, viewName string, filter *dbmodel.GetZoneRRsFilter, options ...dnsop.GetZoneRRsOption) iter.Seq[*dnsop.RRResponse] {
 		return func(yield func(*dnsop.RRResponse) bool) {
 			yield(dnsop.NewErrorRRResponse(dnsop.NewManagerRRsAlreadyRequestedError("trusted", "example.com")))
 		}
@@ -864,7 +904,7 @@ func TestGetZoneRRsBusy(t *testing.T) {
 
 	ctrl := gomock.NewController(t)
 	mockManager := NewMockManager(ctrl)
-	mockManager.EXPECT().GetZoneRRs(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).AnyTimes().DoAndReturn(func(zoneID int64, daemonID int64, viewName string, options ...dnsop.GetZoneRRsOption) iter.Seq[*dnsop.RRResponse] {
+	mockManager.EXPECT().GetZoneRRs(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).AnyTimes().DoAndReturn(func(zoneID int64, daemonID int64, viewName string, filter *dbmodel.GetZoneRRsFilter, options ...dnsop.GetZoneRRsOption) iter.Seq[*dnsop.RRResponse] {
 		return func(yield func(*dnsop.RRResponse) bool) {
 			yield(dnsop.NewErrorRRResponse(agentcomm.NewZoneInventoryBusyError("localhost:8080")))
 		}
@@ -910,7 +950,7 @@ func TestGetZoneRRsNotInited(t *testing.T) {
 
 	ctrl := gomock.NewController(t)
 	mockManager := NewMockManager(ctrl)
-	mockManager.EXPECT().GetZoneRRs(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).AnyTimes().DoAndReturn(func(zoneID int64, daemonID int64, viewName string, options ...dnsop.GetZoneRRsOption) iter.Seq[*dnsop.RRResponse] {
+	mockManager.EXPECT().GetZoneRRs(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).AnyTimes().DoAndReturn(func(zoneID int64, daemonID int64, viewName string, filter *dbmodel.GetZoneRRsFilter, options ...dnsop.GetZoneRRsOption) iter.Seq[*dnsop.RRResponse] {
 		return func(yield func(*dnsop.RRResponse) bool) {
 			yield(dnsop.NewErrorRRResponse(agentcomm.NewZoneInventoryNotInitedError("localhost:8080")))
 		}
@@ -956,7 +996,7 @@ func TestGetZoneRRsUnknownError(t *testing.T) {
 
 	ctrl := gomock.NewController(t)
 	mockManager := NewMockManager(ctrl)
-	mockManager.EXPECT().GetZoneRRs(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).AnyTimes().DoAndReturn(func(zoneID int64, daemonID int64, viewName string, options ...dnsop.GetZoneRRsOption) iter.Seq[*dnsop.RRResponse] {
+	mockManager.EXPECT().GetZoneRRs(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).AnyTimes().DoAndReturn(func(zoneID int64, daemonID int64, viewName string, filter *dbmodel.GetZoneRRsFilter, options ...dnsop.GetZoneRRsOption) iter.Seq[*dnsop.RRResponse] {
 		return func(yield func(*dnsop.RRResponse) bool) {
 			yield(dnsop.NewErrorRRResponse(&testError{}))
 		}
