@@ -4,7 +4,10 @@
 
 -- Configure pg_hba.conf file.
 CREATE TEMPORARY TABLE hba ( line text );
-COPY hba FROM '/var/lib/postgresql/data/pg_hba.conf';
+DO $$
+BEGIN
+    EXECUTE format('COPY hba FROM %L', current_setting('hba_file'));
+END $$;
 DELETE FROM hba WHERE line ~* '^host\s+all.*$';
 INSERT INTO hba (line) VALUES
 --    TYPE  DB   USER                         ADDR METHOD
@@ -13,7 +16,10 @@ INSERT INTO hba (line) VALUES
     ('host  all  stork_scram-sha-256          all  scram-sha-256'),
     ('host  all  root                         all  ident'),
     ('host  all  all                          all  md5');
-COPY hba TO '/var/lib/postgresql/data/pg_hba.conf';
+DO $$
+BEGIN
+    EXECUTE format('COPY hba TO %L', current_setting('hba_file'));
+END $$;
 SELECT pg_reload_conf();
 
 -- Create users.
