@@ -1,5 +1,4 @@
 import functools
-import re
 from contextlib import contextmanager
 from datetime import datetime, timezone, timedelta
 from typing import Callable, List, Optional, TypeVar
@@ -31,7 +30,6 @@ from openapi_client.exceptions import ServiceException
 from openapi_client.models.zone_inventory_states import ZoneInventoryStates
 from openapi_client.models.zones import Zones
 
-
 T1 = TypeVar("T1")
 T2 = TypeVar("T2")
 
@@ -195,12 +193,12 @@ class Server(ComposeServiceWrapper):  # pylint: disable=too-many-public-methods)
         return api_instance.get_machines(**params)
 
     def list_subnets(
-        self, app_id=None, family: int = None, limit=10, start=0
+        self, daemon_id=None, family: int = None, limit=10, start=0
     ) -> Subnets:
-        """Lists the subnets from a given application and/or family."""
+        """Lists the subnets from a given daemon and/or family."""
         params = {"start": start, "limit": limit}
-        if app_id is not None:
-            params["app_id"] = app_id
+        if daemon_id is not None:
+            params["daemon_id"] = daemon_id
         if family is not None:
             params["dhcp_version"] = family
 
@@ -209,8 +207,8 @@ class Server(ComposeServiceWrapper):  # pylint: disable=too-many-public-methods)
 
     def list_events(
         self,
-        daemon_type=None,
-        app_type=None,
+        daemon_name=None,
+        daemon_id=None,
         machine_id=None,
         user_id=None,
         limit=10,
@@ -221,10 +219,10 @@ class Server(ComposeServiceWrapper):  # pylint: disable=too-many-public-methods)
 
         Parameters
         ----------
-        daemon_type : str, optional
-            Daemon type, e.g. 'named', 'dhcp4', 'dhcp6', 'ca', by default None
-        app_type : str, optional
-            App type, e.g. 'kea' or 'bind9', by default None
+        daemon_name : str, optional
+            Daemon name, e.g. 'named', 'dhcp4', 'dhcp6', 'ca', by default None
+        daemon_id : int, optional
+            Daemon ID, by default None
         machine_id : int, optional
             Machine ID, by default None
         user_id : int, optional
@@ -240,10 +238,10 @@ class Server(ComposeServiceWrapper):  # pylint: disable=too-many-public-methods)
             List of events
         """
         params = {"start": start, "limit": limit}
-        if daemon_type is not None:
-            params["daemon_type"] = daemon_type
-        if app_type is not None:
-            params["app_type"] = app_type
+        if daemon_name is not None:
+            params["daemon_name"] = daemon_name
+        if daemon_id is not None:
+            params["daemon_id"] = daemon_id
         if machine_id is not None:
             params["machine"] = machine_id
         if user_id is not None:
@@ -277,7 +275,11 @@ class Server(ComposeServiceWrapper):  # pylint: disable=too-many-public-methods)
             params["host_id"] = host_id
 
         api_instance = DHCPApi(self._api_client)
-        return api_instance.get_leases(**params)
+        results = api_instance.get_leases(**params)
+        if results.items is not None:
+            items = sorted(results.items, key=lambda i: i.ip_address)
+            results.items = items
+        return results
 
     def list_hosts(self, text=None, limit=100, start=0) -> Hosts:
         """Lists the hosts based on the host identifier."""
@@ -352,7 +354,7 @@ class Server(ComposeServiceWrapper):  # pylint: disable=too-many-public-methods)
             # situation.
             if (
                 e.status == 500
-                and "Problem storing application state in the database" in e.body
+                and "Problem storing daemon state in the database" in e.body
             ):
                 raise DatabaseDeadlockError() from e
             raise
@@ -378,11 +380,13 @@ class Server(ComposeServiceWrapper):  # pylint: disable=too-many-public-methods)
         response = api_instance.get_machines_server_token()
         return response.token
 
-    def read_access_point_key(self, app_id) -> str:
+    def read_access_point_key(self, daemon_id) -> str:
         """Read the access point key."""
         api_instance = ServicesApi(self._api_client)
         # Currently, only the control access points support the key.
-        response = api_instance.get_access_point_key(app_id=app_id, type="control")
+        response = api_instance.get_access_point_key(
+            daemon_id=daemon_id, type="control"
+        )
         return response
 
     def get_zone_inventory_states(self) -> ZoneInventoryStates:
@@ -411,7 +415,7 @@ class Server(ComposeServiceWrapper):  # pylint: disable=too-many-public-methods)
         """Updates the machine. It must to contain the valid ID."""
         api_instance = ServicesApi(self._api_client)
 
-        # This endpoint doesn't return the applications.
+        # This endpoint doesn't return the daemons.
         return api_instance.update_machine(
             id=machine.id,
             machine=machine,
@@ -463,7 +467,7 @@ class Server(ComposeServiceWrapper):  # pylint: disable=too-many-public-methods)
 
         def on_begin() -> CreateHostBeginResponse:
             # Begin transaction response contains the daemons without related
-            # app access points.
+            # access points.
             return api_instance.create_host_begin()
 
         def on_submit(transaction_id: int, host: Host):
@@ -480,7 +484,7 @@ class Server(ComposeServiceWrapper):  # pylint: disable=too-many-public-methods)
 
         def on_begin() -> UpdateHostBeginResponse:
             # Begin transaction response contains the daemons without related
-            # app access points.
+            # access points.
             return api_instance.update_host_begin(host_id=host_id)
 
         def on_submit(transaction_id: int, host: Host):
@@ -678,45 +682,45 @@ class Server(ComposeServiceWrapper):  # pylint: disable=too-many-public-methods)
 
     def _wait_for_states_pulling(self, start: datetime = None):
         """
-        Waits for finishing next execution of application state puller. Unlike
-        the `last_visited_at` property from the application entry, it waits
-        until the end of writing all application-related entries (subnets,
+        Waits for finishing next execution of daemon state puller. Unlike
+        the `last_visited_at` property from the daemon entry, it waits
+        until the end of writing all daemon-related entries (subnets,
         shared networks, hosts) to the database.
         """
         try:
             self._wait_for_puller("state_puller_interval", start)
         except openapi_client.exceptions.NotFoundException:
             # Applicable only when the server is running in the older version.
-            self._wait_for_puller("apps_state_puller_interval", start)
+            self._wait_for_puller("state_puller_interval", start)
 
     @wait_for_success(
         DatabaseDeadlockError, wait_msg="Waiting to fetch next machine state..."
     )
     def wait_for_next_machine_state(
-        self, machine_id: int, start: datetime = None, wait_for_apps=True
+        self, machine_id: int, start: datetime = None, wait_for_daemons=True
     ) -> Machine:
         """
         Waits for a next fetch of the machine state after a given date.
         If the date is None then the current moment is used.
-        By default, this function waits until some application is fetched.
+        By default, this function waits until some daemon is fetched.
         It may be suppressed by specifying a flag.
         """
         self._wait_for_states_pulling(start)
         state = self.read_machine_state(machine_id)
-        if wait_for_apps and len(state.apps) == 0:
-            raise NoSuccessException("the apps are missing")
+        if wait_for_daemons and len(state.daemons) == 0:
+            raise NoSuccessException("the daemons are missing")
         return state
 
     @wait_for_success(
         DatabaseDeadlockError, wait_msg="Waiting to fetch next machine states..."
     )
     def wait_for_next_machine_states(
-        self, start: datetime = None, wait_for_apps=True
+        self, start: datetime = None, wait_for_daemons=True
     ) -> List[Machine]:
         """
         Waits for the subsequent fetches of the machine states for all machines.
         The machines must be authorized. Returns list of states.
-        By default, this function waits until some application is fetched.
+        By default, this function waits until some daemon is fetched.
         It may be suppressed by specifying a flag.
         """
         self._wait_for_states_pulling(start)
@@ -724,22 +728,11 @@ class Server(ComposeServiceWrapper):  # pylint: disable=too-many-public-methods)
         states = []
         for machine in machines.items:
             state = self.read_machine_state(machine.id)
-            if wait_for_apps and len(state.apps) == 0:
-                raise NoSuccessException("the apps are missing")
+            if wait_for_daemons and len(state.daemons) == 0:
+                raise NoSuccessException("the daemons are missing")
             states.append(state)
         return states
 
-    # The different event message is used if the number of subnets is less or
-    # greater than 10. Additionally, if the number of subnets is less than 10,
-    # each subnet generates its event.
-    _pattern_added_subnets = re.compile(
-        # pylint: disable=implicit-str-concat
-        r"added (?:(?:\d+ subnets)|(?:<subnet.*>)) to <daemon "
-        r'id="(?P<daemon_id>\d+)" '
-        r'name="(?P<daemon_name>.*)" '
-        r'appId="(?P<app_id>\d+)"'
-    )
-
     def wait_for_failed_ca_communication(self, check_unauthorized=True):
         """
         Waits for a failed communication with CA daemon event due to an
@@ -783,9 +776,8 @@ class Server(ComposeServiceWrapper):  # pylint: disable=too-many-public-methods)
         for daemon in overview.dhcp_daemons:
             for relationship in daemon.ha_overview:
                 if relationship.ha_state not in valid_states:
-                    identifier = f"{daemon.app_name}@{daemon.machine}/{daemon.name}"
                     raise NoSuccessException(
-                        f"The {identifier} HA peer is {relationship.ha_state}"
+                        f"The {daemon.label} HA peer is {relationship.ha_state}"
                     )
 
     @wait_for_success(wait_msg="Waiting for zones fetching completion...")
