@@ -2,7 +2,6 @@ import { ComponentFixture, TestBed, fakeAsync, tick } from '@angular/core/testin
 
 import { AccessPointKeyComponent } from './access-point-key.component'
 import { provideHttpClientTesting } from '@angular/common/http/testing'
-import { ButtonModule } from 'primeng/button'
 import { ServicesService } from '../backend'
 import { of, throwError } from 'rxjs'
 import { HttpEvent, provideHttpClient, withInterceptorsFromDi } from '@angular/common/http'
@@ -14,9 +13,7 @@ describe('AccessPointKeyComponent', () => {
 
     beforeEach(async () => {
         await TestBed.configureTestingModule({
-            declarations: [AccessPointKeyComponent],
-            imports: [ButtonModule],
-            providers: [ServicesService, provideHttpClient(withInterceptorsFromDi()), provideHttpClientTesting()],
+            providers: [provideHttpClient(withInterceptorsFromDi()), provideHttpClientTesting()],
         }).compileComponents()
 
         servicesApi = TestBed.inject(ServicesService)
@@ -85,7 +82,7 @@ describe('AccessPointKeyComponent', () => {
     })
 
     it('should set loading state during the key fetching', fakeAsync(() => {
-        component.appId = 42
+        component.daemonId = 42
         component.accessPointType = 'control'
         spyOn(servicesApi, 'getAccessPointKey').and.returnValue(of('foobar' as string & HttpEvent<string>))
         component.onAuthenticationKeyRequest()
@@ -93,7 +90,7 @@ describe('AccessPointKeyComponent', () => {
     }))
 
     it('should fetch key from API', fakeAsync(() => {
-        component.appId = 42
+        component.daemonId = 42
         component.accessPointType = 'control'
         spyOn(servicesApi, 'getAccessPointKey').and.returnValue(of('foobar' as string & HttpEvent<string>))
         component.onAuthenticationKeyRequest()
@@ -103,7 +100,7 @@ describe('AccessPointKeyComponent', () => {
     }))
 
     it('should reset the key on error', fakeAsync(() => {
-        component.appId = 42
+        component.daemonId = 42
         component.accessPointType = 'control'
         spyOn(servicesApi, 'getAccessPointKey').and.returnValue(throwError('error'))
         component.onAuthenticationKeyRequest()
