@@ -1,33 +1,11 @@
-import { StoryObj, Meta, moduleMetadata, applicationConfig } from '@storybook/angular'
+import { StoryObj, Meta, applicationConfig } from '@storybook/angular'
 import { AddressPoolFormComponent } from './address-pool-form.component'
 import { toastDecorator } from '../utils-stories'
-import { FormControl, FormGroup, FormsModule, ReactiveFormsModule, UntypedFormArray } from '@angular/forms'
+import { FormControl, FormGroup, UntypedFormArray } from '@angular/forms'
 import { SharedParameterFormGroup } from '../forms/shared-parameter-form-group'
-import { SharedParametersFormComponent } from '../shared-parameters-form/shared-parameters-form.component'
-import { ToastModule } from 'primeng/toast'
-import { TableModule } from 'primeng/table'
 import { MessageService } from 'primeng/api'
-import { CheckboxModule } from 'primeng/checkbox'
-import { TagModule } from 'primeng/tag'
-import { DhcpClientClassSetFormComponent } from '../dhcp-client-class-set-form/dhcp-client-class-set-form.component'
-import { AutoCompleteModule } from 'primeng/autocomplete'
-import { ButtonModule } from 'primeng/button'
-import { PopoverModule } from 'primeng/popover'
-import { NoopAnimationsModule } from '@angular/platform-browser/animations'
-import { importProvidersFrom } from '@angular/core'
-import { FieldsetModule } from 'primeng/fieldset'
-import { MultiSelectModule } from 'primeng/multiselect'
 import { AddressPoolForm, AddressRangeForm, KeaPoolParametersForm } from '../forms/subnet-set-form.service'
-import { DhcpOptionSetFormComponent } from '../dhcp-option-set-form/dhcp-option-set-form.component'
-import { DhcpOptionFormComponent } from '../dhcp-option-form/dhcp-option-form.component'
-import { SelectModule } from 'primeng/select'
-import { SplitButtonModule } from 'primeng/splitbutton'
-import { HelpTipComponent } from '../help-tip/help-tip.component'
-import { InputNumberModule } from 'primeng/inputnumber'
-import { DividerModule } from 'primeng/divider'
 import { StorkValidators } from '../validators'
-import { FloatLabelModule } from 'primeng/floatlabel'
-import { InputTextModule } from 'primeng/inputtext'
 
 export default {
     title: 'App/AddressPoolForm',
@@ -41,36 +19,7 @@ export default {
     },
     decorators: [
         applicationConfig({
-            providers: [importProvidersFrom(NoopAnimationsModule), MessageService],
-        }),
-        moduleMetadata({
-            imports: [
-                ButtonModule,
-                CheckboxModule,
-                AutoCompleteModule,
-                DividerModule,
-                SelectModule,
-                FieldsetModule,
-                FormsModule,
-                InputNumberModule,
-                MultiSelectModule,
-                PopoverModule,
-                ReactiveFormsModule,
-                SplitButtonModule,
-                TableModule,
-                TagModule,
-                ToastModule,
-                FloatLabelModule,
-                InputTextModule,
-            ],
-            declarations: [
-                AddressPoolFormComponent,
-                DhcpClientClassSetFormComponent,
-                DhcpOptionFormComponent,
-                DhcpOptionSetFormComponent,
-                HelpTipComponent,
-                SharedParametersFormComponent,
-            ],
+            providers: [MessageService],
         }),
         toastDecorator,
     ],
@@ -135,17 +84,13 @@ export const AddressPool4: Story = {
         selectableDaemons: [
             {
                 id: 1,
-                appId: 1,
-                appType: 'kea',
-                name: 'first/dhcp4',
+                name: 'dhcp4',
                 version: '2.7.0',
                 label: 'first/dhcp4',
             },
             {
                 id: 2,
-                appId: 2,
-                appType: 'kea',
-                name: 'second/dhcp4',
+                name: 'dhcp4',
                 version: '2.7.0',
                 label: 'second/dhcp4',
             },
@@ -193,17 +138,13 @@ export const AddressPool6: Story = {
         selectableDaemons: [
             {
                 id: 1,
-                appId: 1,
-                appType: 'kea',
-                name: 'first/dhcp6',
+                name: 'dhcp6',
                 version: '2.7.0',
                 label: 'first/dhcp6',
             },
             {
                 id: 2,
-                appId: 2,
-                appType: 'kea',
-                name: 'second/dhcp6',
+                name: 'dhcp6',
                 version: '2.7.0',
                 label: 'second/dhcp6',
             },
