@@ -1,24 +1,21 @@
 import { TestBed, inject } from '@angular/core/testing'
 
 import { AuthGuard } from './auth.guard'
-import { RouterModule, Router } from '@angular/router'
+import { Router, provideRouter } from '@angular/router'
 import { provideHttpClientTesting } from '@angular/common/http/testing'
-import { UsersService } from './backend'
 import { MessageService } from 'primeng/api'
 import { provideHttpClient, withInterceptorsFromDi } from '@angular/common/http'
 
 describe('AuthGuard', () => {
     beforeEach(() => {
         TestBed.configureTestingModule({
-            imports: [RouterModule],
             providers: [
-                AuthGuard,
-                UsersService,
                 MessageService,
                 {
                     provide: Router,
                     useValue: {},
                 },
+                provideRouter([]),
                 provideHttpClient(withInterceptorsFromDi()),
                 provideHttpClientTesting(),
             ],
