@@ -11,6 +11,19 @@ import { SessionCredentials } from './backend'
 import { User } from './backend'
 import { getErrorMessage } from './utils'
 
+/**
+ * Indicates if the user in an active tab is managed by an internal
+ * authentication service
+ */
+export function isInternalUser(user: User) {
+    if (!user) {
+        return false
+    }
+    const authenticationMethodId = user.authenticationMethodId
+    // Empty or null or internal.
+    return !authenticationMethodId || authenticationMethodId === 'internal'
+}
+
 /**
  * System user groups enumeration.
  * IDs match group IDs in the backend.
@@ -31,7 +44,7 @@ export enum UserGroup {
 export type ManagedAccessEntity =
     | 'machines-server-token'
     | 'kea-config-hashes'
-    | 'app'
+    | 'daemon'
     | 'global-config-checkers'
     | 'daemon-config-checkers'
     | 'host-reservation'
@@ -40,7 +53,7 @@ export type ManagedAccessEntity =
     | 'shared-network'
     | 'subnet'
     | 'zones'
-    | 'app-access-point-key'
+    | 'access-point-key'
     | 'machine-address'
     | 'machine-authorization'
     | 'machine'
@@ -242,7 +255,7 @@ export class AuthService {
      * @returns true if the user was authenticated using the internal method.
      */
     isInternalUser(): boolean {
-        return this.currentUserValue?.authenticationMethodId === 'internal'
+        return isInternalUser(this.currentUserValue)
     }
 
     /**
@@ -275,7 +288,7 @@ export class AuthService {
             return true
         } else if (this.isAdmin()) {
             switch (entityKey) {
-                case 'app-access-point-key': // Admin role is not enough to see Access Point Key (it is secret).
+                case 'access-point-key': // Admin role is not enough to see Access Point Key (it is secret).
                 case 'machines-server-token': // Admin role is not enough to see server token (it is secret).
                 case 'machine-authorization': // Admin role is not enough to authorize or unauthorize machine.
                 case 'users': // Admin role can't even read all users.
@@ -283,16 +296,16 @@ export class AuthService {
                     return false
                 case 'user':
                     return accessType === 'read' // Admin group can only read their own user data.
-                case 'machine':
-                    return accessType !== 'delete' // Admin group can't delete machines.
+                case 'machine': // Admin group can't delete: machines, events, daemons.
                 case 'events':
-                    return accessType !== 'delete' // Admin group can't delete events either.
+                case 'daemon':
+                    return accessType !== 'delete'
                 default:
                     return true
             }
         } else if (this.isInReadOnlyGroup()) {
             switch (entityKey) {
-                case 'app-access-point-key':
+                case 'access-point-key':
                 case 'machines-server-token':
                 case 'users':
                 case 'json-config-secret':
