@@ -1,23 +1,16 @@
 import { ComponentFixture, TestBed } from '@angular/core/testing'
 
 import { Bind9DaemonComponent } from './bind9-daemon.component'
-import { AppsVersions, Bind9DaemonView } from '../backend'
+import { AppsVersions, Bind9DaemonView, Daemon } from '../backend'
 import { By } from '@angular/platform-browser'
 import { VersionStatusComponent } from '../version-status/version-status.component'
 import { Severity, VersionService } from '../version.service'
-import { MessageService } from 'primeng/api'
-import { DurationPipe } from '../pipes/duration.pipe'
-import { LocaltimePipe } from '../pipes/localtime.pipe'
-import { PlaceholderPipe } from '../pipes/placeholder.pipe'
+import { ConfirmationService, MessageService } from 'primeng/api'
 import { of } from 'rxjs'
-import { provideRouter, RouterModule } from '@angular/router'
-import { TooltipModule } from 'primeng/tooltip'
-
-class Daemon {
-    id = 1
-    name = 'named'
-    version = '9.18.30'
-}
+import { provideRouter } from '@angular/router'
+import { provideHttpClientTesting } from '@angular/common/http/testing'
+import { provideHttpClient, withInterceptorsFromDi } from '@angular/common/http'
+import { Bind9DaemonControlsComponent } from '../bind9-daemon-controls/bind9-daemon-controls.component'
 
 describe('Bind9DaemonComponent', () => {
     let component: Bind9DaemonComponent
@@ -31,15 +24,24 @@ describe('Bind9DaemonComponent', () => {
             getSoftwareVersionFeedback: () => ({ severity: Severity.success, messages: ['test feedback'] }),
         }
         await TestBed.configureTestingModule({
-            declarations: [Bind9DaemonComponent, DurationPipe, LocaltimePipe, PlaceholderPipe, VersionStatusComponent],
-            imports: [RouterModule, TooltipModule],
-            providers: [provideRouter([]), { provide: VersionService, useValue: versionServiceStub }, MessageService],
+            providers: [
+                { provide: VersionService, useValue: versionServiceStub },
+                MessageService,
+                ConfirmationService,
+                provideRouter([]),
+                provideHttpClient(withInterceptorsFromDi()),
+                provideHttpClientTesting(),
+            ],
         }).compileComponents()
 
         fixture = TestBed.createComponent(Bind9DaemonComponent)
         fixture.debugElement.injector.get(VersionService)
         component = fixture.componentInstance
-        const daemon = new Daemon()
+        const daemon: Daemon = {
+            id: 1,
+            name: Daemon.NameEnum.Named,
+            version: '9.18.30',
+        }
         component.daemon = daemon
         fixture.detectChanges()
     })
@@ -64,9 +66,14 @@ describe('Bind9DaemonComponent', () => {
         expect(versionStatus).toBeTruthy()
         expect(versionStatus.length).toEqual(1)
         // Stubbed success icon for BIND 9.18.30 is expected.
-        expect(versionStatus[0].properties.outerHTML).toContain('9.18.30')
-        expect(versionStatus[0].properties.outerHTML).toContain('bind9')
-        expect(versionStatus[0].properties.outerHTML).toContain('text-green-500')
-        expect(versionStatus[0].properties.outerHTML).toContain('test feedback')
+        expect(versionStatus[0].nativeElement.innerHTML).toContain('9.18.30')
+        expect(versionStatus[0].nativeElement.innerHTML).not.toContain('named')
+        expect(versionStatus[0].nativeElement.innerHTML).toContain('text-green-500')
+        expect(versionStatus[0].nativeElement.innerHTML).toContain('test feedback')
+    })
+
+    it('should include bind9 daemon controls', () => {
+        const bind9DaemonControls = fixture.debugElement.query(By.directive(Bind9DaemonControlsComponent))
+        expect(bind9DaemonControls).toBeTruthy()
     })
 })
