@@ -1,11 +1,7 @@
 import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
 import { BreadcrumbsComponent } from './breadcrumbs.component'
-import { BreadcrumbModule } from 'primeng/breadcrumb'
-import { HelpTipComponent } from '../help-tip/help-tip.component'
-import { PopoverModule } from 'primeng/popover'
-import { NoopAnimationsModule } from '@angular/platform-browser/animations'
-import { provideRouter, RouterModule } from '@angular/router'
-import { ButtonModule } from 'primeng/button'
+import { provideNoopAnimations } from '@angular/platform-browser/animations'
+import { provideRouter } from '@angular/router'
 
 describe('BreadcrumbsComponent', () => {
     let component: BreadcrumbsComponent
@@ -13,9 +9,7 @@ describe('BreadcrumbsComponent', () => {
 
     beforeEach(waitForAsync(() => {
         TestBed.configureTestingModule({
-            imports: [RouterModule, BreadcrumbModule, PopoverModule, NoopAnimationsModule, ButtonModule],
-            declarations: [BreadcrumbsComponent, HelpTipComponent],
-            providers: [provideRouter([])],
+            providers: [provideNoopAnimations(), provideRouter([])],
         }).compileComponents()
     }))
 
