@@ -2,14 +2,12 @@ import { ChangeDetectorRef, Component, OnDestroy, OnInit } from '@angular/core'
 
 import { MessageService } from 'primeng/api'
 
-import { Bind9Daemon, DHCPService, DNSService, PdnsDaemon, ServicesService } from '../backend'
-import { AppsStats } from '../backend'
+import { Bind9Daemon, DaemonsStats, DHCPService, DNSService, PdnsDaemon, ServicesService } from '../backend'
 import {
     datetimeToLocal,
     durationToString,
     getGrafanaUrl,
-    daemonStatusIconName,
-    daemonStatusIconColor,
+    daemonStatusIconClass,
     daemonStatusIconTooltip,
     getGrafanaSubnetTooltip,
     getErrorMessage,
@@ -19,17 +17,23 @@ import { ServerDataService } from '../server-data.service'
 import { concatMap, lastValueFrom, Subscription } from 'rxjs'
 import { map } from 'rxjs/operators'
 import { parseSubnetsStatisticValues } from '../subnets'
-import {
-    App,
-    DhcpDaemon,
-    DhcpDaemonHARelationshipOverview,
-    DhcpOverview,
-    Settings,
-    ZoneInventoryState,
-} from '../backend'
+import { DhcpDaemon, DhcpDaemonHARelationshipOverview, DhcpOverview, Settings, ZoneInventoryState } from '../backend'
 import { ModifyDeep } from '../utiltypes'
-import { TableLazyLoadEvent } from 'primeng/table'
+import { TableLazyLoadEvent, TableModule } from 'primeng/table'
 import { getSeverity, getTooltip } from '../zone-inventory-utils'
+import { NgIf, NgFor, NgStyle, NgTemplateOutlet, DecimalPipe, TitleCasePipe } from '@angular/common'
+import { Panel } from 'primeng/panel'
+import { RouterLink } from '@angular/router'
+import { Button } from 'primeng/button'
+import { HelpTipComponent } from '../help-tip/help-tip.component'
+import { SubnetBarComponent } from '../subnet-bar/subnet-bar.component'
+import { EntityLinkComponent } from '../entity-link/entity-link.component'
+import { VersionStatusComponent } from '../version-status/version-status.component'
+import { Tooltip } from 'primeng/tooltip'
+import { Tag } from 'primeng/tag'
+import { EventsPanelComponent } from '../events-panel/events-panel.component'
+import { HumanCountPipe } from '../pipes/human-count.pipe'
+import { SurroundPipe } from '../pipes/surround.pipe'
 
 type DhcpOverviewParsed = ModifyDeep<
     DhcpOverview,
@@ -81,9 +85,29 @@ type DhcpOverviewParsed = ModifyDeep<
  */
 @Component({
     selector: 'app-dashboard',
-    standalone: false,
     templateUrl: './dashboard.component.html',
     styleUrls: ['./dashboard.component.sass'],
+    imports: [
+        NgIf,
+        Panel,
+        RouterLink,
+        Button,
+        HelpTipComponent,
+        NgFor,
+        SubnetBarComponent,
+        EntityLinkComponent,
+        TableModule,
+        VersionStatusComponent,
+        Tooltip,
+        NgStyle,
+        Tag,
+        NgTemplateOutlet,
+        EventsPanelComponent,
+        DecimalPipe,
+        TitleCasePipe,
+        HumanCountPipe,
+        SurroundPipe,
+    ],
 })
 export class DashboardComponent implements OnInit, OnDestroy {
     /**
@@ -98,9 +122,9 @@ export class DashboardComponent implements OnInit, OnDestroy {
     loaded = false
 
     /**
-     * Application statistics fetched from the server.
+     * Daemon statistics fetched from the server.
      */
-    appsStats: AppsStats
+    stats: DaemonsStats
 
     /**
      * The overview data of DHCP daemons.
@@ -127,14 +151,14 @@ export class DashboardComponent implements OnInit, OnDestroy {
     grafanaDhcp6DashboardId: string
 
     /**
-     * List of DNS Apps displayed in the DNS dashboard.
+     * List of DNS Daemons displayed in the DNS dashboard.
      */
-    dnsApps: App[] = []
+    dnsDaemons: Array<Bind9Daemon | PdnsDaemon> = []
 
     /**
-     * Total count of DNS Apps returned by the backend.
+     * Total count of DNS Daemons returned by the backend.
      */
-    dnsAppsTotalCount: number = 0
+    dnsDaemonsTotalCount: number = 0
 
     /**
      * Flag stating whether DNS Service Status table data is loading or not.
@@ -142,24 +166,24 @@ export class DashboardComponent implements OnInit, OnDestroy {
     dnsServiceStatusLoading: boolean = false
 
     /**
-     * Key-value map where keys are DNS app IDs and values are information about zone fetching for particular DNS server.
+     * Key-value map where keys are DNS daemon IDs and values are information about zone fetching for particular DNS server.
      */
     zoneInventoryStateMap: Map<number, ZoneInventoryState> = new Map()
 
     /**
-     * Returns true when no kea and no DNS apps exist among authorized machines;
+     * Indicates when no kea and no DNS daemons exist among authorized machines;
      * false otherwise.
      */
-    get noApps(): boolean {
-        return this.appsStats.keaAppsTotal === 0 && this.appsStats.dnsAppsTotal === 0
+    get noDaemons(): boolean {
+        return this.stats.dhcpDaemonsTotal === 0 && this.stats.dnsDaemonsTotal === 0
     }
 
     /**
-     * Returns true when both DHCP and DNS apps exist among authorized machines;
+     * Returns true when both DHCP and DNS daemons exist among authorized machines;
      * false otherwise.
      */
-    get bothDHCPAndDNSAppsExist(): boolean {
-        return this.appsStats.keaAppsTotal > 0 && this.appsStats.dnsAppsTotal > 0
+    get bothDHCPAndDNSDaemonsExist(): boolean {
+        return this.stats.dhcpDaemonsTotal > 0 && this.stats.dnsDaemonsTotal > 0
     }
 
     /**
@@ -213,27 +237,27 @@ export class DashboardComponent implements OnInit, OnDestroy {
             dhcp6Stats: { assignedNAs: 0, totalNAs: 0, assignedPDs: 0, totalPDs: 0 },
             dhcpDaemons: [],
         }
-        this.appsStats = {
-            keaAppsTotal: 0,
-            keaAppsNotOk: 0,
-            dnsAppsTotal: 0,
-            dnsAppsNotOk: 0,
+        this.stats = {
+            dhcpDaemonsTotal: 0,
+            dhcpDaemonsNotOk: 0,
+            dnsDaemonsTotal: 0,
+            dnsDaemonsNotOk: 0,
         }
 
-        // get stats about apps
+        // get stats about daemons
         this.subscriptions.add(
-            this.serverData.getAppsStats().subscribe(
+            this.serverData.getDaemonsStats().subscribe(
                 (data) => {
                     this.loaded = true
-                    this.appsStats = { ...this.appsStats, ...data }
+                    this.stats = { ...this.stats, ...data }
                 },
                 (err) => {
                     this.loaded = true
                     let msg = getErrorMessage(err)
                     this.msgSrv.add({
                         severity: 'error',
-                        summary: 'Cannot get application statistics',
-                        detail: 'Error getting application statistics: ' + msg,
+                        summary: 'Cannot get daemon statistics',
+                        detail: 'Error getting daemon statistics: ' + msg,
                         life: 10000,
                     })
                 }
@@ -328,16 +352,16 @@ export class DashboardComponent implements OnInit, OnDestroy {
                     if (zonesFetch?.items?.length > 0) {
                         this.zoneInventoryStateMap = new Map()
                         zonesFetch.items.forEach((s) => {
-                            this.zoneInventoryStateMap.set(s.appId, s)
+                            this.zoneInventoryStateMap.set(s.daemonId, s)
                         })
                     }
-                    return this.servicesApi.getApps(event?.first ?? 0, event?.rows ?? 5, null, ['bind9', 'pdns'])
+                    return this.servicesApi.getDaemons(event?.first ?? 0, event?.rows ?? 5, null, ['named', 'pdns'])
                 })
             )
         )
             .then((data) => {
-                this.dnsApps = data.items ?? []
-                this.dnsAppsTotalCount = data.total ?? 0
+                this.dnsDaemons = data.items ?? []
+                this.dnsDaemonsTotalCount = data.total ?? 0
             })
             .catch((err) => {
                 const msg = getErrorMessage(err)
@@ -399,7 +423,8 @@ export class DashboardComponent implements OnInit, OnDestroy {
     }
 
     /**
-     * Returns the name of the icon to be used in the Status column
+     * Returns the CSS classes to specify the icon to be used in the Status
+     * column.
      *
      * The icon selected depends on whether the daemon is active or not
      * active and whether there is a communication with the daemon or
@@ -407,25 +432,10 @@ export class DashboardComponent implements OnInit, OnDestroy {
      *
      * @param daemon data structure holding the information about the daemon.
      *
-     * @returns ban icon if the daemon is not active, times icon if the daemon
-     *          should be active but the communication with it is broken and
-     *          check icon if the communication with the active daemon is ok.
+     * @returns the CSS classes
      */
-    daemonStatusIconName(daemon) {
-        return daemonStatusIconName(daemon)
-    }
-
-    /**
-     * Returns the color of the icon used in the Status column
-     *
-     * @param daemon data structure holding the information about the daemon.
-     *
-     * @returns grey color if the daemon is not active, red if the daemon is
-     *          active but there are communication issues, green if the
-     *          communication with the active daemon is ok.
-     */
-    daemonStatusIconColor(daemon) {
-        return daemonStatusIconColor(daemon)
+    daemonStatusIconClass(daemon) {
+        return daemonStatusIconClass(daemon)
     }
 
     /**
@@ -617,7 +627,7 @@ export class DashboardComponent implements OnInit, OnDestroy {
     isDNSDashboardHidden(): boolean {
         const hidden =
             localStorage.getItem(this._dnsDashboardHiddenStorageKey) ??
-            (this.bothDHCPAndDNSAppsExist ? 'true' : 'false')
+            (this.bothDHCPAndDNSDaemonsExist ? 'true' : 'false')
         return hidden === 'true'
     }
 
@@ -635,7 +645,7 @@ export class DashboardComponent implements OnInit, OnDestroy {
     isDHCPDashboardHidden(): boolean {
         const hidden =
             localStorage.getItem(this._dhcpDashboardHiddenStorageKey) ??
-            (this.bothDHCPAndDNSAppsExist ? 'true' : 'false')
+            (this.bothDHCPAndDNSDaemonsExist ? 'true' : 'false')
         return hidden === 'true'
     }
 
@@ -646,18 +656,4 @@ export class DashboardComponent implements OnInit, OnDestroy {
     storeDHCPDashboardHidden(hidden: boolean): void {
         localStorage.setItem(this._dhcpDashboardHiddenStorageKey, JSON.stringify(hidden))
     }
-
-    /**
-     * Returns a DNS daemon for a given app.
-     *
-     * @param app an app holding a daemon.
-     * @returns BIND 9 or PowerDNS daemon.
-     */
-    getDNSDaemon(app: App): Bind9Daemon | PdnsDaemon {
-        if (app.details?.daemon) {
-            return app.details.daemon
-        } else {
-            return app.details.pdnsDaemon
-        }
-    }
 }
