@@ -1,10 +1,7 @@
 import { DhcpClientClassSetViewComponent } from './dhcp-client-class-set-view.component'
 
-import { StoryObj, Meta, moduleMetadata, applicationConfig } from '@storybook/angular'
-import { ChipModule } from 'primeng/chip'
-import { NoopAnimationsModule } from '@angular/platform-browser/animations'
+import { StoryObj, Meta, applicationConfig } from '@storybook/angular'
 import { toastDecorator } from '../utils-stories'
-import { ToastModule } from 'primeng/toast'
 import { MessageService } from 'primeng/api'
 
 export default {
@@ -14,9 +11,6 @@ export default {
         applicationConfig({
             providers: [MessageService],
         }),
-        moduleMetadata({
-            imports: [ChipModule, NoopAnimationsModule, ToastModule],
-        }),
         toastDecorator,
     ],
 } as Meta
