@@ -1,20 +1,10 @@
 import { ComponentFixture, TestBed } from '@angular/core/testing'
-import { UntypedFormBuilder, FormsModule, ReactiveFormsModule } from '@angular/forms'
+import { UntypedFormBuilder } from '@angular/forms'
 import { By } from '@angular/platform-browser'
-import { NoopAnimationsModule } from '@angular/platform-browser/animations'
-import { CheckboxModule } from 'primeng/checkbox'
-import { SelectModule } from 'primeng/select'
-import { InputNumberModule } from 'primeng/inputnumber'
-import { PopoverModule } from 'primeng/popover'
-import { ToggleButtonModule } from 'primeng/togglebutton'
-import { SplitButtonModule } from 'primeng/splitbutton'
-import { DhcpOptionFormComponent } from '../dhcp-option-form/dhcp-option-form.component'
+import { provideNoopAnimations } from '@angular/platform-browser/animations'
 import { createDefaultDhcpOptionFormGroup } from '../forms/dhcp-option-form'
 import { DhcpOptionSetFormComponent } from '../dhcp-option-set-form/dhcp-option-set-form.component'
-import { HelpTipComponent } from '../help-tip/help-tip.component'
 import { IPType } from '../iptype'
-import { ButtonModule } from 'primeng/button'
-import { TagModule } from 'primeng/tag'
 
 describe('DhcpOptionSetFormComponent', () => {
     let component: DhcpOptionSetFormComponent
@@ -23,21 +13,7 @@ describe('DhcpOptionSetFormComponent', () => {
 
     beforeEach(async () => {
         await TestBed.configureTestingModule({
-            providers: [UntypedFormBuilder],
-            imports: [
-                CheckboxModule,
-                SelectModule,
-                FormsModule,
-                InputNumberModule,
-                NoopAnimationsModule,
-                PopoverModule,
-                ReactiveFormsModule,
-                SplitButtonModule,
-                ToggleButtonModule,
-                ButtonModule,
-                TagModule,
-            ],
-            declarations: [DhcpOptionFormComponent, DhcpOptionSetFormComponent, HelpTipComponent],
+            providers: [UntypedFormBuilder, provideNoopAnimations()],
         }).compileComponents()
     })
 
