@@ -1,8 +1,8 @@
 import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
 import { EntityLinkComponent } from './entity-link.component'
 import { By } from '@angular/platform-browser'
-import { SurroundPipe } from '../pipes/surround.pipe'
-import { provideRouter, RouterModule } from '@angular/router'
+import { provideRouter } from '@angular/router'
+import { Daemon, LeasesSearchErredDaemon, LocalHost, LocalSharedNetwork, LocalSubnet, LocalZone } from '../backend'
 
 describe('EntityLinkComponent', () => {
     let component: EntityLinkComponent
@@ -10,8 +10,6 @@ describe('EntityLinkComponent', () => {
 
     beforeEach(waitForAsync(() => {
         TestBed.configureTestingModule({
-            imports: [RouterModule],
-            declarations: [EntityLinkComponent, SurroundPipe],
             providers: [provideRouter([])],
         }).compileComponents()
     }))
@@ -28,12 +26,13 @@ describe('EntityLinkComponent', () => {
 
     it('should construct daemon link', () => {
         component.entity = 'daemon'
-        component.attrs = { id: 98, appType: 'kea', appId: 1, name: 'dhcp4' }
+        component.attrs = { id: 98, name: 'dhcp4' }
         component.showEntityName = false
         fixture.detectChanges()
         const link = fixture.debugElement.query(By.css('#daemon-link-98'))
-        expect(link.attributes.href).toEqual('/apps/1?daemon=dhcp4')
-        expect(link.nativeElement.innerText).toEqual('[98] DHCPv4')
+        expect(link.attributes.href).toEqual('/daemons/98')
+        expect(link.nativeElement.innerText).toEqual('[98]\u00a0DHCPv4')
+        expect(link.attributes.href).toEqual('/daemons/98')
 
         // Test entity name is not displayed.
         let native = fixture.nativeElement
@@ -44,26 +43,104 @@ describe('EntityLinkComponent', () => {
         fixture.detectChanges()
         native = fixture.nativeElement
         expect(native.textContent).toContain('daemon')
-    })
-
-    it('should construct app link', () => {
-        component.entity = 'app'
-        component.attrs = { type: 'kea', id: 1, name: 'mouse' }
         component.showEntityName = false
-        fixture.detectChanges()
-        const link = fixture.debugElement.query(By.css('#app-link-1'))
-        expect(link.attributes.href).toEqual('/apps/1')
-        expect(link.nativeElement.innerText).toEqual('mouse')
 
-        // Test entity name is not displayed.
-        let native = fixture.nativeElement
-        expect(native.textContent).not.toContain('app')
-
-        // Display entity name.
-        component.showEntityName = true
+        // Test that entity link from LocalSubnet.
+        const subnet: LocalSubnet = {
+            id: 24,
+            daemonId: 42,
+            daemonLabel: 'DHCPv4@localhost',
+        }
+        component.attrs = subnet
         fixture.detectChanges()
-        native = fixture.nativeElement
-        expect(native.textContent).toContain('app')
+        expect(link.nativeElement.innerText).toEqual('[42]\u00a0DHCPv4@localhost')
+        expect(link.attributes.href).toEqual('/daemons/42')
+
+        // Test entity link from LocalSharedNetwork.
+        const sharedNetwork: LocalSharedNetwork = {
+            daemonId: 42,
+            daemonLabel: 'DHCPv4@localhost',
+        }
+        component.attrs = sharedNetwork
+        fixture.detectChanges()
+        expect(link.nativeElement.innerText).toEqual('[42]\u00a0DHCPv4@localhost')
+        expect(link.attributes.href).toEqual('/daemons/42')
+
+        // Test entity link from LocalHost.
+        const host: LocalHost = {
+            bootFileName: 'pxelinux.0',
+            clientClasses: ['class1', 'class2'],
+            dataSource: 'api',
+            hostname: 'host',
+            serverHostname: 'server',
+            daemonId: 42,
+            daemonLabel: 'DHCPv4@localhost',
+        }
+        component.attrs = host
+        fixture.detectChanges()
+        expect(link.nativeElement.innerText).toEqual('[42]\u00a0DHCPv4@localhost')
+        expect(link.attributes.href).toEqual('/daemons/42')
+
+        // Test entity link from LocalZone.
+        const zone: LocalZone = {
+            daemonId: 42,
+            daemonLabel: 'DHCPv4@localhost',
+            loadedAt: '2024-06-01T12:00:00Z',
+            rpz: true,
+            serial: 12345,
+            view: 'default',
+            zoneClass: 'IN',
+            zoneType: 'primary',
+        }
+        component.attrs = zone
+        fixture.detectChanges()
+        expect(link.nativeElement.innerText).toEqual('[42]\u00a0DHCPv4@localhost')
+        expect(link.attributes.href).toEqual('/daemons/42')
+
+        // Test entity link from Daemon.
+        const daemon: Daemon = {
+            id: 42,
+            name: 'dhcp4',
+            label: 'DHCPv4@localhost',
+            active: true,
+            machineId: 1,
+            machineLabel: 'localhost',
+            monitored: true,
+            pid: 1234,
+            version: '1.0.0',
+        }
+        component.attrs = daemon
+        fixture.detectChanges()
+        expect(link.nativeElement.innerText).toEqual('[42]\u00a0DHCPv4')
+        expect(link.attributes.href).toEqual('/daemons/42')
+
+        // Test entity link from LeasesSearchErredDaemon.
+        const erredDaemon: LeasesSearchErredDaemon = {
+            id: 42,
+            label: 'DHCPv4@localhost',
+        }
+        component.attrs = erredDaemon
+        fixture.detectChanges()
+        expect(link.nativeElement.innerText).toEqual('[42]\u00a0DHCPv4@localhost')
+        expect(link.attributes.href).toEqual('/daemons/42')
+
+        // Test entity link for missing daemon ID.
+        component.attrs = { name: 'dhcp4' }
+        fixture.detectChanges()
+        expect(link.nativeElement.innerText).toEqual('DHCPv4')
+        expect(link.attributes.href).toEqual('/daemons')
+
+        // Test entity link for numeric zero daemon ID.
+        component.attrs = { id: 0, name: 'dhcp4' }
+        fixture.detectChanges()
+        expect(link.nativeElement.innerText).toEqual('DHCPv4')
+        expect(link.attributes.href).toEqual('/daemons')
+
+        // Test entity link for string zero daemon ID.
+        component.attrs = { id: '0', name: 'dhcp4' }
+        fixture.detectChanges()
+        expect(link.nativeElement.innerText).toEqual('DHCPv4')
+        expect(link.attributes.href).toEqual('/daemons')
     })
 
     it('should construct machine link', () => {
@@ -73,7 +150,7 @@ describe('EntityLinkComponent', () => {
         fixture.detectChanges()
         const link = fixture.debugElement.query(By.css('#machine-link'))
         expect(link.attributes.href).toEqual('/machines/5')
-        expect(link.nativeElement.innerText).toEqual('[5] 192.0.2.10')
+        expect(link.nativeElement.innerText).toEqual('[5]\u00a0192.0.2.10')
 
         // Test entity name is not displayed.
         let native = fixture.nativeElement
@@ -93,7 +170,7 @@ describe('EntityLinkComponent', () => {
         fixture.detectChanges()
         const link = fixture.debugElement.query(By.css('#user-link'))
         expect(link.attributes.href).toEqual('/users/7')
-        expect(link.nativeElement.innerText).toEqual('[7] turtle')
+        expect(link.nativeElement.innerText).toEqual('[7]\u00a0turtle')
 
         // Test entity name is not displayed.
         let native = fixture.nativeElement
@@ -113,7 +190,7 @@ describe('EntityLinkComponent', () => {
         fixture.detectChanges()
         const link = fixture.debugElement.query(By.css('#user-link'))
         expect(link.attributes.href).toEqual('/users/7')
-        expect(link.nativeElement.innerText).toEqual('[7] mouse@example.org')
+        expect(link.nativeElement.innerText).toEqual('[7]\u00a0mouse@example.org')
 
         // Test entity name is not displayed.
         let native = fixture.nativeElement
@@ -144,6 +221,11 @@ describe('EntityLinkComponent', () => {
         fixture.detectChanges()
         native = fixture.nativeElement
         expect(native.textContent).toContain('host')
+
+        // Show the identifier.
+        fixture.componentRef.setInput('showIdentifier', true)
+        fixture.detectChanges()
+        expect(link.nativeElement.innerText).toEqual('[8]\u00a0mouse.example.org')
     })
 
     it('should construct subnet link', () => {
@@ -164,6 +246,11 @@ describe('EntityLinkComponent', () => {
         fixture.detectChanges()
         native = fixture.nativeElement
         expect(native.textContent).toContain('subnet')
+
+        // Show the identifier.
+        fixture.componentRef.setInput('showIdentifier', true)
+        fixture.detectChanges()
+        expect(link.nativeElement.innerText).toEqual('[8] fe80::/64')
     })
 
     it('should construct a shared network link', () => {
@@ -184,5 +271,10 @@ describe('EntityLinkComponent', () => {
         fixture.detectChanges()
         native = fixture.nativeElement
         expect(native.textContent).toContain('shared network')
+
+        // Show the identifier.
+        fixture.componentRef.setInput('showIdentifier', true)
+        fixture.detectChanges()
+        expect(link.nativeElement.innerText).toEqual('[9]\u00a0frog')
     })
 })
