@@ -1,24 +1,27 @@
-import { Component, Input } from '@angular/core'
-import { daemonNameToFriendlyName } from '../utils'
+import { Component, input, Input } from '@angular/core'
+import { NgSwitch, NgClass, NgSwitchCase, NgSwitchDefault, NgIf } from '@angular/common'
+import { RouterLink } from '@angular/router'
+import { DaemonNiceNamePipe } from '../pipes/daemon-name.pipe'
 
 /**
  * A component that displays given entity as a link with rounded border
  * and a background color. It can be used for making a link to:
  * - machine
- * - app
  * - daemon
  * - subnet
- * - host
+ * - host reservation
+ * - user
+ * - shared network
  */
 @Component({
     selector: 'app-entity-link',
-    standalone: false,
     templateUrl: './entity-link.component.html',
     styleUrls: ['./entity-link.component.sass'],
+    imports: [NgSwitch, NgIf, NgClass, NgSwitchCase, RouterLink, NgSwitchDefault, DaemonNiceNamePipe],
 })
 export class EntityLinkComponent {
     /**
-     * Entity name, one of: machine, app, daemon, subnet, host.
+     * Entity name, one of: machine, daemon, subnet, host.
      */
     @Input() entity: string
 
@@ -37,11 +40,13 @@ export class EntityLinkComponent {
      */
     @Input() styleClass: string
 
-    constructor() {}
-
     /**
-     * Reference to daemonNameToFriendlyName() function to be used in html template.
-     * @protected
+     * Input boolean flag controlling whether subnet, host reservation or shared network entity link
+     * should include the entity identifier as well.
+     * For daemon, machine or user entity, the identifier is always included.
+     * It defaults to false.
      */
-    protected readonly daemonNameToFriendlyName = daemonNameToFriendlyName
+    showIdentifier = input<boolean>(false)
+
+    constructor() {}
 }
