@@ -1,5 +1,8 @@
 import { Component, OnInit } from '@angular/core'
 import { ActivatedRoute } from '@angular/router'
+import { Daemon } from '../backend'
+import { BreadcrumbsComponent } from '../breadcrumbs/breadcrumbs.component'
+import { EventsPanelComponent } from '../events-panel/events-panel.component'
 
 /**
  * Component responsible for showing a full page list of events,
@@ -7,36 +10,30 @@ import { ActivatedRoute } from '@angular/router'
  */
 @Component({
     selector: 'app-events-page',
-    standalone: false,
     templateUrl: './events-page.component.html',
     styleUrls: ['./events-page.component.sass'],
+    imports: [BreadcrumbsComponent, EventsPanelComponent],
 })
 export class EventsPageComponent implements OnInit {
-    machineId = null
-    appType = null
-    daemonType = null
-    userId = null
+    machineId: number = null
+    daemonName: Daemon.NameEnum = null
+    userId: number = null
     breadcrumbs = [{ label: 'Monitoring' }, { label: 'Events' }]
 
     constructor(private route: ActivatedRoute) {}
 
     ngOnInit(): void {
-        const machineId = this.route.snapshot.queryParams.machine
+        const machineId = this.route.snapshot.queryParams.machineId
         if (machineId) {
             this.machineId = parseInt(machineId, 10)
         }
 
-        const appType = this.route.snapshot.queryParams.appType
-        if (appType) {
-            this.appType = appType
+        const daemonName = this.route.snapshot.queryParams.daemonName
+        if (daemonName) {
+            this.daemonName = daemonName as Daemon.NameEnum
         }
 
-        const daemonType = this.route.snapshot.queryParams.daemonType
-        if (daemonType) {
-            this.daemonType = daemonType
-        }
-
-        const userId = this.route.snapshot.queryParams.user
+        const userId = this.route.snapshot.queryParams.userId
         if (userId) {
             this.userId = parseInt(userId, 10)
         }
