@@ -1,20 +1,14 @@
 import { provideHttpClientTesting } from '@angular/common/http/testing'
 import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
-import { ActivatedRoute, RouterModule } from '@angular/router'
+import { provideRouter } from '@angular/router'
 import { MessageService, ConfirmationService, Confirmation } from 'primeng/api'
-import { ButtonModule } from 'primeng/button'
-import { PaginatorModule } from 'primeng/paginator'
-import { TableModule } from 'primeng/table'
-import { ToastModule } from 'primeng/toast'
-import { ConfirmDialogModule } from 'primeng/confirmdialog'
 
-import { EventsService, ServicesService, UsersService } from '../backend'
-import { EventTextComponent } from '../event-text/event-text.component'
-import { LocaltimePipe } from '../pipes/localtime.pipe'
+import { EventsService } from '../backend'
 import { EventsPanelComponent } from './events-panel.component'
 import { ServerSentEventsService, ServerSentEventsTestingService } from '../server-sent-events.service'
 import { of } from 'rxjs'
 import { provideHttpClient, withInterceptorsFromDi } from '@angular/common/http'
+import { SelectChangeEvent } from 'primeng/select'
 
 /**
  * Fake event value.
@@ -27,7 +21,8 @@ class TestEventValue {
 /**
  * Fake event object.
  */
-class TestEvent {
+class TestEvent implements SelectChangeEvent {
+    public originalEvent: Event
     public value: TestEventValue
     constructor() {
         this.value = new TestEventValue()
@@ -43,21 +38,13 @@ describe('EventsPanelComponent', () => {
 
     beforeEach(waitForAsync(() => {
         TestBed.configureTestingModule({
-            declarations: [EventsPanelComponent, LocaltimePipe, EventTextComponent],
-            imports: [PaginatorModule, RouterModule, TableModule, ToastModule, ButtonModule, ConfirmDialogModule],
             providers: [
-                EventsService,
-                UsersService,
-                ServicesService,
                 MessageService,
                 ConfirmationService,
-                {
-                    provide: ActivatedRoute,
-                    useValue: {},
-                },
                 { provide: ServerSentEventsService, useClass: ServerSentEventsTestingService },
                 provideHttpClient(withInterceptorsFromDi()),
                 provideHttpClientTesting(),
+                provideRouter([]),
             ],
         }).compileComponents()
     }))
@@ -77,10 +64,9 @@ describe('EventsPanelComponent', () => {
 
     it('should establish SSE connection with correct filtering rules', () => {
         component.filter.level = 1
-        component.filter.machine = 2
-        component.filter.appType = 'kea'
-        component.filter.daemonType = 'dhcp4'
-        component.filter.user = 3
+        component.filter.machineId = 2
+        component.filter.daemonName = 'dhcp4'
+        component.filter.userId = 3
 
         spyOn(sseService, 'receivePriorityAndMessageEvents').and.returnValue(
             of({
@@ -129,7 +115,7 @@ describe('EventsPanelComponent', () => {
         component.ngOnInit()
         fixture.detectChanges()
 
-        // Select specific machine, app type, daemon type and user. In each
+        // Select specific machine, daemon name and user. In each
         // case, the SSE connection should be re-established with appropriate
         // filtering parameters.
 
@@ -137,22 +123,17 @@ describe('EventsPanelComponent', () => {
 
         event.value.id = 1
         component.onMachineSelect(event)
-        expect(component.filter.machine).toBe(1)
-        expect(sseService.receivePriorityAndMessageEvents).toHaveBeenCalledWith(component.filter)
-
-        event.value.value = 'kea'
-        component.onAppTypeSelect(event)
-        expect(component.filter.appType).toBe('kea')
+        expect(component.filter.machineId).toBe(1)
         expect(sseService.receivePriorityAndMessageEvents).toHaveBeenCalledWith(component.filter)
 
         event.value.value = 'dhcp4'
-        component.onDaemonTypeSelect(event)
-        expect(component.filter.daemonType).toBe('dhcp4')
+        component.onDaemonNameSelect(event)
+        expect(component.filter.daemonName).toBe('dhcp4')
         expect(sseService.receivePriorityAndMessageEvents).toHaveBeenCalledWith(component.filter)
 
         event.value.id = 5
         component.onUserSelect(event)
-        expect(component.filter.user).toBe(5)
+        expect(component.filter.userId).toBe(5)
         expect(sseService.receivePriorityAndMessageEvents).toHaveBeenCalledWith(component.filter)
     })
 
