@@ -5,10 +5,31 @@ import { LazyLoadEvent, MessageService, ConfirmationService } from 'primeng/api'
 import { EventsService, UsersService, ServicesService } from '../backend/api/api'
 import { AuthService } from '../auth.service'
 import { Subscription, filter, lastValueFrom } from 'rxjs'
-import { getErrorMessage } from '../utils'
-import { Events, EventSortField, Machine } from '../backend'
-import { ServerSentEventsService } from '../server-sent-events.service'
+import { daemonNameToFriendlyName, getErrorMessage } from '../utils'
+import { Daemon, Event, Events, EventSortField, Machine, User } from '../backend'
+import { ServerSentEventsService, SSEFilter } from '../server-sent-events.service'
 import { convertSortingFields } from '../table'
+import { NgIf, NgClass } from '@angular/common'
+import { FormsModule } from '@angular/forms'
+import { Button } from 'primeng/button'
+import { ConfirmDialog } from 'primeng/confirmdialog'
+import { Select } from 'primeng/select'
+import { SelectButton } from 'primeng/selectbutton'
+import { TableModule } from 'primeng/table'
+import { EventTextComponent } from '../event-text/event-text.component'
+import { ManagedAccessDirective } from '../managed-access.directive'
+import { LocaltimePipe } from '../pipes/localtime.pipe'
+import { Tooltip } from 'primeng/tooltip'
+import { SelectChangeEvent } from 'primeng/select'
+
+/**
+ * Option for daemon name selection.
+ */
+interface DaemonNameOption {
+    value: Daemon.NameEnum
+    name: string
+    id: string
+}
 
 /**
  * A component that presents the events list. Each event has its own row.
@@ -16,10 +37,22 @@ import { convertSortingFields } from '../table'
  */
 @Component({
     selector: 'app-events-panel',
-    standalone: false,
     templateUrl: './events-panel.component.html',
     styleUrls: ['./events-panel.component.sass'],
-    providers: [ConfirmationService],
+    imports: [
+        NgIf,
+        SelectButton,
+        FormsModule,
+        Select,
+        ManagedAccessDirective,
+        Button,
+        Tooltip,
+        ConfirmDialog,
+        TableModule,
+        NgClass,
+        EventTextComponent,
+        LocaltimePipe,
+    ],
 })
 export class EventsPanelComponent implements OnInit, OnChanges, OnDestroy {
     /**
@@ -40,13 +73,7 @@ export class EventsPanelComponent implements OnInit, OnChanges, OnDestroy {
 
     @Input() ui: 'bare' | 'table' = 'bare'
 
-    @Input() filter = {
-        level: 0,
-        machine: null,
-        appType: null,
-        daemonType: null,
-        user: null,
-    }
+    @Input() filter: SSEFilter = { level: 0 }
 
     /**
      * When set to true, rowsPerPageOptions will be displayed in the paginator.
@@ -74,24 +101,23 @@ export class EventsPanelComponent implements OnInit, OnChanges, OnDestroy {
         },
     ]
 
-    users: any
+    users: User[]
     machines: Machine[] = []
-    appTypes = [
-        { value: 'kea', name: 'Kea', id: 'kea-events' },
-        { value: 'bind9', name: 'BIND 9', id: 'bind-events' },
-    ]
-    daemonTypes = [
-        { value: 'dhcp4', name: 'DHCPv4', id: 'kea4-events' },
-        { value: 'dhcp6', name: 'DHCPv6', id: 'kea6-events' },
-        { value: 'named', name: 'named', id: 'named-events' },
-        { value: 'd2', name: 'DDNS', id: 'ddns-events' },
-        { value: 'ca', name: 'CA', id: 'ca-events' },
-        { value: 'netconf', name: 'NETCONF', id: 'netconf-events' },
-    ]
-    selectedMachine: any
-    selectedAppType: any
-    selectedDaemonType: any
-    selectedUser: any
+    daemonNames: DaemonNameOption[] = (() => {
+        const names: DaemonNameOption[] = []
+        for (const dt of Object.values(Daemon.NameEnum)) {
+            names.push({
+                value: dt,
+                name: daemonNameToFriendlyName(dt),
+                id: `${dt}-events`,
+            })
+        }
+        return names
+    })()
+
+    selectedMachine: Machine
+    selectedDaemonName: DaemonNameOption
+    selectedUser: User
 
     /**
      * Indicates if the component was initialized.
@@ -146,18 +172,10 @@ export class EventsPanelComponent implements OnInit, OnChanges, OnDestroy {
                 this.eventHandler(event.originalEvent)
             })
 
-        if (this.filter.appType) {
-            for (const at of this.appTypes) {
-                if (at.value === this.filter.appType) {
-                    this.selectedAppType = at
-                    break
-                }
-            }
-        }
-        if (this.filter.daemonType) {
-            for (const dt of this.daemonTypes) {
-                if (dt.value === this.filter.daemonType) {
-                    this.selectedDaemonType = dt
+        if (this.filter.daemonName) {
+            for (const dt of this.daemonNames) {
+                if (dt.value === this.filter.daemonName) {
+                    this.selectedDaemonName = dt
                     break
                 }
             }
@@ -193,9 +211,9 @@ export class EventsPanelComponent implements OnInit, OnChanges, OnDestroy {
                 .then((data) => {
                     this.users = data.items
 
-                    if (this.filter.user) {
+                    if (this.filter.userId) {
                         for (const u of this.users) {
-                            if (u.id === this.filter.user) {
+                            if (u.id === this.filter.userId) {
                                 this.selectedUser = u
                             }
                         }
@@ -215,9 +233,9 @@ export class EventsPanelComponent implements OnInit, OnChanges, OnDestroy {
             .then((data) => {
                 this.machines = data.items ?? []
 
-                if (this.filter.machine) {
+                if (this.filter.machineId) {
                     for (const m of this.machines) {
-                        if (m.id === this.filter.machine) {
+                        if (m.id === this.filter.machineId) {
                             this.selectedMachine = m
                         }
                     }
@@ -270,10 +288,10 @@ export class EventsPanelComponent implements OnInit, OnChanges, OnDestroy {
                 this.start,
                 this.limit,
                 this.filter.level,
-                this.filter.machine,
-                this.filter.appType,
-                this.filter.daemonType,
-                this.filter.user,
+                this.filter.machineId,
+                this.filter.daemonName,
+                this.filter.daemonId,
+                this.filter.userId,
                 ...convertSortingFields<EventSortField>(event)
             )
         )
@@ -299,7 +317,7 @@ export class EventsPanelComponent implements OnInit, OnChanges, OnDestroy {
      * Take an event received via SSE and put it to list of all events
      * so it is presented in events panel.
      */
-    eventHandler(event) {
+    eventHandler(event: Event) {
         // if currently presented page of events is not the first one
         // then do not add new events to the list
         if (this.start !== 0) {
@@ -307,10 +325,10 @@ export class EventsPanelComponent implements OnInit, OnChanges, OnDestroy {
         }
         // decapitalize fields
         const ev = {
-            text: event.Text,
-            details: event.Details,
-            level: event.Level,
-            createdAt: event.CreatedAt,
+            text: event.text,
+            details: event.details,
+            level: event.level,
+            createdAt: event.createdAt,
         }
 
         // put new event in front of all events
@@ -324,41 +342,31 @@ export class EventsPanelComponent implements OnInit, OnChanges, OnDestroy {
     }
 
     /** Callback called on selecting a machine in dropdown. */
-    onMachineSelect(event) {
+    onMachineSelect(event: SelectChangeEvent) {
         if (event.value === null) {
-            this.filter.machine = null
+            this.filter.machineId = null
         } else {
-            this.filter.machine = event.value.id
+            this.filter.machineId = event.value.id
         }
         this.applyFilter()
     }
 
-    /** Callback called on selecting an application in dropdown. */
-    onAppTypeSelect(event) {
+    /** Callback called on selecting a daemon name in dropdown. */
+    onDaemonNameSelect(event: SelectChangeEvent) {
         if (event.value === null) {
-            this.filter.appType = null
+            this.filter.daemonName = null
         } else {
-            this.filter.appType = event.value.value
-        }
-        this.applyFilter()
-    }
-
-    /** Callback called on selecting a daemon type in dropdown. */
-    onDaemonTypeSelect(event) {
-        if (event.value === null) {
-            this.filter.daemonType = null
-        } else {
-            this.filter.daemonType = event.value.value
+            this.filter.daemonName = event.value.value
         }
         this.applyFilter()
     }
 
     /** Callback called on selecting a user in dropdown. */
-    onUserSelect(event) {
+    onUserSelect(event: SelectChangeEvent) {
         if (event.value === null) {
-            this.filter.user = null
+            this.filter.userId = null
         } else {
-            this.filter.user = event.value.id
+            this.filter.userId = event.value.id
         }
         this.applyFilter()
     }
