@@ -13,14 +13,12 @@ describe('SharedNetworkFormState', () => {
                 name: 'stanza',
                 localSharedNetworks: [
                     {
-                        appId: 111,
                         daemonId: 1,
-                        appName: 'server 1',
+                        daemonLabel: 'DHCPv4@myhost.example.org',
                     },
                     {
-                        appId: 222,
                         daemonId: 2,
-                        appName: 'server 2',
+                        daemonLabel: 'DHCPv4@yourhost.example.org',
                     },
                 ],
             },
@@ -28,51 +26,31 @@ describe('SharedNetworkFormState', () => {
                 {
                     id: 1,
                     name: 'dhcp4',
-                    app: {
-                        id: 1,
-                        name: 'one',
-                        type: 'kea',
-                    },
+                    label: 'DHCPv4@myhost.example.org',
                     version: '3.0.0',
                 },
                 {
                     id: 3,
                     name: 'dhcp6',
-                    app: {
-                        id: 3,
-                        name: 'three',
-                        type: 'kea',
-                    },
+                    label: 'DHCPv6@myhost.example.org',
                     version: '3.0.0',
                 },
                 {
                     id: 2,
                     name: 'dhcp4',
-                    app: {
-                        id: 2,
-                        name: 'two',
-                        type: 'kea',
-                    },
+                    label: 'DHCPv4@yourhost.example.org',
                     version: '3.0.0',
                 },
                 {
                     id: 4,
                     name: 'dhcp6',
-                    app: {
-                        id: 4,
-                        name: 'four',
-                        type: 'kea',
-                    },
+                    label: 'DHCPv6@yourhost.example.org',
                     version: '3.0.0',
                 },
                 {
                     id: 5,
                     name: 'dhcp6',
-                    app: {
-                        id: 5,
-                        name: 'five',
-                        type: 'kea',
-                    },
+                    label: 'DHCPv6@theirhost.example.org',
                     version: '3.0.0',
                 },
             ],
@@ -117,43 +95,33 @@ describe('SharedNetworkFormState', () => {
         // Filtered daemons.
         expect(state.filteredDaemons).toContain({
             id: 1,
-            appId: 1,
-            appType: 'kea',
             name: 'dhcp4',
             version: '3.0.0',
-            label: 'one/dhcp4',
+            label: 'DHCPv4@myhost.example.org',
         })
         expect(state.filteredDaemons).toContain({
             id: 3,
-            appId: 3,
-            appType: 'kea',
             name: 'dhcp6',
             version: '3.0.0',
-            label: 'three/dhcp6',
+            label: 'DHCPv6@myhost.example.org',
         })
         expect(state.filteredDaemons).toContain({
             id: 2,
-            appId: 2,
-            appType: 'kea',
             name: 'dhcp4',
             version: '3.0.0',
-            label: 'two/dhcp4',
+            label: 'DHCPv4@yourhost.example.org',
         })
         expect(state.filteredDaemons).toContain({
             id: 4,
-            appId: 4,
-            appType: 'kea',
             name: 'dhcp6',
             version: '3.0.0',
-            label: 'four/dhcp6',
+            label: 'DHCPv6@yourhost.example.org',
         })
         expect(state.filteredDaemons).toContain({
             id: 5,
-            appId: 5,
-            appType: 'kea',
             name: 'dhcp6',
             version: '3.0.0',
-            label: 'five/dhcp6',
+            label: 'DHCPv6@theirhost.example.org',
         })
 
         // Form group.
@@ -167,7 +135,7 @@ describe('SharedNetworkFormState', () => {
         expect(state.savedSharedNetworkBeginData).toBeFalsy()
 
         // Servers selection.
-        expect(state.servers).toEqual(['one/dhcp4', 'two/dhcp4'])
+        expect(state.servers).toEqual(['DHCPv4@myhost.example.org', 'DHCPv4@yourhost.example.org'])
 
         // Identifiers.
         expect(state.sharedNetworkId).toBe(123)
@@ -183,14 +151,10 @@ describe('SharedNetworkFormState', () => {
                 universe: 6,
                 localSharedNetworks: [
                     {
-                        appId: 111,
                         daemonId: 3,
-                        appName: 'server 1',
                     },
                     {
-                        appId: 222,
                         daemonId: 4,
-                        appName: 'server 2',
                     },
                 ],
             },
@@ -198,51 +162,31 @@ describe('SharedNetworkFormState', () => {
                 {
                     id: 1,
                     name: 'dhcp4',
-                    app: {
-                        id: 1,
-                        name: 'one',
-                        type: 'kea',
-                    },
+                    label: 'DHCPv4@myhost.example.org',
                     version: '3.0.0',
                 },
                 {
                     id: 3,
                     name: 'dhcp6',
-                    app: {
-                        id: 3,
-                        name: 'three',
-                        type: 'kea',
-                    },
+                    label: 'DHCPv6@myhost.example.org',
                     version: '3.0.0',
                 },
                 {
                     id: 2,
                     name: 'dhcp4',
-                    app: {
-                        id: 2,
-                        name: 'two',
-                        type: 'kea',
-                    },
+                    label: 'DHCPv4@yourhost.example.org',
                     version: '3.0.0',
                 },
                 {
                     id: 4,
                     name: 'dhcp6',
-                    app: {
-                        id: 4,
-                        name: 'four',
-                        type: 'kea',
-                    },
+                    label: 'DHCPv6@yourhost.example.org',
                     version: '3.0.0',
                 },
                 {
                     id: 5,
                     name: 'dhcp6',
-                    app: {
-                        id: 5,
-                        name: 'five',
-                        type: 'kea',
-                    },
+                    label: 'DHCPv6@theirhost.example.com',
                     version: '3.0.0',
                 },
             ],
@@ -268,43 +212,33 @@ describe('SharedNetworkFormState', () => {
         // Filtered daemons.
         expect(state.filteredDaemons).toContain({
             id: 1,
-            appId: 1,
-            appType: 'kea',
             name: 'dhcp4',
             version: '3.0.0',
-            label: 'one/dhcp4',
+            label: 'DHCPv4@myhost.example.org',
         })
         expect(state.filteredDaemons).toContain({
             id: 3,
-            appId: 3,
-            appType: 'kea',
             name: 'dhcp6',
             version: '3.0.0',
-            label: 'three/dhcp6',
+            label: 'DHCPv6@myhost.example.org',
         })
         expect(state.filteredDaemons).toContain({
             id: 2,
-            appId: 2,
-            appType: 'kea',
             name: 'dhcp4',
             version: '3.0.0',
-            label: 'two/dhcp4',
+            label: 'DHCPv4@yourhost.example.org',
         })
         expect(state.filteredDaemons).toContain({
             id: 4,
-            appId: 4,
-            appType: 'kea',
             name: 'dhcp6',
             version: '3.0.0',
-            label: 'four/dhcp6',
+            label: 'DHCPv6@yourhost.example.org',
         })
         expect(state.filteredDaemons).toContain({
             id: 5,
-            appId: 5,
-            appType: 'kea',
             name: 'dhcp6',
             version: '3.0.0',
-            label: 'five/dhcp6',
+            label: 'DHCPv6@theirhost.example.com',
         })
 
         // Form group.
@@ -318,7 +252,7 @@ describe('SharedNetworkFormState', () => {
         expect(state.savedSharedNetworkBeginData).toBeFalsy()
 
         // Servers selection.
-        expect(state.servers).toEqual(['three/dhcp6', 'four/dhcp6'])
+        expect(state.servers).toEqual(['DHCPv6@myhost.example.org', 'DHCPv6@yourhost.example.org'])
 
         // Identifiers.
         expect(state.sharedNetworkId).toBe(234)
@@ -336,9 +270,9 @@ describe('SharedNetworkFormState', () => {
         let state = new SharedNetworkFormState()
         state.sharedNetworkId = 123
         state.initStateFromServerResponse(response)
-        expect(state.servers).toEqual(['one/dhcp4', 'two/dhcp4'])
+        expect(state.servers).toEqual(['DHCPv4@myhost.example.org', 'DHCPv4@yourhost.example.org'])
         state.updateServers([2])
-        expect(state.servers).toEqual(['two/dhcp4'])
+        expect(state.servers).toEqual(['DHCPv4@yourhost.example.org'])
     })
 
     it('should update universe for selected daemons', () => {
@@ -355,27 +289,21 @@ describe('SharedNetworkFormState', () => {
         expect(state.filteredDaemons.length).toBe(3)
         expect(state.filteredDaemons).toContain({
             id: 3,
-            appId: 3,
-            appType: 'kea',
             name: 'dhcp6',
             version: '3.0.0',
-            label: 'three/dhcp6',
+            label: 'DHCPv6@myhost.example.org',
         })
         expect(state.filteredDaemons).toContain({
             id: 4,
-            appId: 4,
-            appType: 'kea',
             name: 'dhcp6',
             version: '3.0.0',
-            label: 'four/dhcp6',
+            label: 'DHCPv6@yourhost.example.org',
         })
         expect(state.filteredDaemons).toContain({
             id: 5,
-            appId: 5,
-            appType: 'kea',
             name: 'dhcp6',
             version: '3.0.0',
-            label: 'five/dhcp6',
+            label: 'DHCPv6@theirhost.example.org',
         })
     })
 })
