@@ -253,16 +253,7 @@ export class SharedNetworkFormState implements FormState {
         // daemons to select.
         this._transactionID = response.id
         this._allDaemons = []
-        this._allDaemons = response.daemons.map((d) => {
-            return {
-                id: d.id,
-                appId: d.app?.id,
-                appType: d.app?.type,
-                name: d.name,
-                version: d.version,
-                label: `${d.app?.name}/${d.name}`,
-            }
-        })
+        this._allDaemons = response.daemons as SelectableDaemon[]
         // Initially, list all daemons.
         this._filteredDaemons = this._allDaemons
         this._allSharedNetworks4 =
