@@ -3,8 +3,14 @@ import { Component, OnInit, ViewChild } from '@angular/core'
 import { Popover } from 'primeng/popover'
 
 import { SearchService } from '../backend/api/api'
+import { FormsModule } from '@angular/forms'
+import { InputText } from 'primeng/inputtext'
+import { NgIf, NgFor } from '@angular/common'
+import { RouterLink } from '@angular/router'
+import { EntityLinkComponent } from '../entity-link/entity-link.component'
+import { SearchResult } from '../backend'
 
-const recordTypes = ['subnets', 'sharedNetworks', 'hosts', 'machines', 'apps', 'users', 'groups']
+const recordTypes = ['subnets', 'sharedNetworks', 'hosts', 'machines', 'daemons', 'users', 'groups']
 
 /**
  * Component for handling global search. It provides box
@@ -12,15 +18,15 @@ const recordTypes = ['subnets', 'sharedNetworks', 'hosts', 'machines', 'apps', '
  */
 @Component({
     selector: 'app-global-search',
-    standalone: false,
     templateUrl: './global-search.component.html',
     styleUrls: ['./global-search.component.sass'],
+    imports: [FormsModule, InputText, Popover, NgIf, NgFor, RouterLink, EntityLinkComponent],
 })
 export class GlobalSearchComponent implements OnInit {
     @ViewChild('searchResultsBox') searchResultsBox: Popover
 
     searchText: string
-    searchResults: any
+    searchResults: Required<SearchResult>
 
     constructor(protected searchApi: SearchService) {}
 
@@ -32,10 +38,11 @@ export class GlobalSearchComponent implements OnInit {
      * Reset results to be empty.
      */
     resetResults() {
-        this.searchResults = {}
+        const searchResults: SearchResult = {}
         for (const rt of recordTypes) {
-            this.searchResults[rt] = { items: [] }
+            searchResults[rt] = { items: [] }
         }
+        this.searchResults = searchResults as Required<SearchResult>
     }
 
     /**
@@ -50,11 +57,7 @@ export class GlobalSearchComponent implements OnInit {
             this.searchApi.searchRecords(this.searchText).subscribe((data) => {
                 this.resetResults()
                 for (const k of recordTypes) {
-                    if (data[k] && data[k].items) {
-                        this.searchResults[k] = data[k]
-                    } else {
-                        this.searchResults[k] = { items: [] }
-                    }
+                    this.searchResults[k] = data[k]?.items ? data[k] : { items: [] }
                 }
                 this.searchResultsBox.show(event)
                 // this is a workaround to fix position when content of overlay panel changes
