@@ -1,26 +1,10 @@
-import { Meta, StoryObj, applicationConfig, moduleMetadata } from '@storybook/angular'
-import { MessageModule } from 'primeng/message'
-import { PanelModule } from 'primeng/panel'
-import { ProgressSpinnerModule } from 'primeng/progressspinner'
-import { TooltipModule } from 'primeng/tooltip'
+import { Meta, StoryObj, applicationConfig } from '@storybook/angular'
 import { HaStatusComponent } from './ha-status.component'
-import { LocaltimePipe } from '../pipes/localtime.pipe'
 import { ServicesService, ServicesStatus } from '../backend'
 import { MessageService } from 'primeng/api'
-import { importProvidersFrom } from '@angular/core'
-import { HttpClientModule } from '@angular/common/http'
-import { PlaceholderPipe } from '../pipes/placeholder.pipe'
-import { HelpTipComponent } from '../help-tip/help-tip.component'
-import { NoopAnimationsModule } from '@angular/platform-browser/animations'
+import { provideHttpClient, withInterceptorsFromDi } from '@angular/common/http'
 import { toastDecorator } from '../utils-stories'
-import { PopoverModule } from 'primeng/popover'
-import { ToastModule } from 'primeng/toast'
-import { TagModule } from 'primeng/tag'
-import { EntityLinkComponent } from '../entity-link/entity-link.component'
-import { ProgressBarModule } from 'primeng/progressbar'
-import { TableModule } from 'primeng/table'
-import { ButtonModule } from 'primeng/button'
-import { provideRouter, RouterModule } from '@angular/router'
+import { provideRouter, withHashLocation } from '@angular/router'
 
 let mockHubAndSpokeStatus: ServicesStatus = {
     items: [
@@ -31,8 +15,7 @@ let mockHubAndSpokeStatus: ServicesStatus = {
                     relationship: 'server1',
                     primaryServer: {
                         age: 0,
-                        appId: 234,
-                        controlAddress: '192.0.2.1:8080',
+                        label: 'DHCPv4@localhost',
                         failoverTime: null,
                         id: 1,
                         inTouch: true,
@@ -48,8 +31,7 @@ let mockHubAndSpokeStatus: ServicesStatus = {
                     },
                     secondaryServer: {
                         age: 0,
-                        appId: 123,
-                        controlAddress: '192.0.2.2:8080',
+                        label: 'DHCPv4@remotehost',
                         failoverTime: null,
                         id: 1,
                         inTouch: true,
@@ -73,8 +55,7 @@ let mockHubAndSpokeStatus: ServicesStatus = {
                     relationship: 'server3',
                     primaryServer: {
                         age: 0,
-                        appId: 345,
-                        controlAddress: '192.0.2.3:8080',
+                        label: 'DHCPv4@localhost',
                         failoverTime: null,
                         id: 1,
                         inTouch: true,
@@ -90,8 +71,7 @@ let mockHubAndSpokeStatus: ServicesStatus = {
                     },
                     secondaryServer: {
                         age: 0,
-                        appId: 123,
-                        controlAddress: '192.0.2.2:8081',
+                        label: 'DHCPv4@remotehost',
                         failoverTime: null,
                         id: 1,
                         inTouch: true,
@@ -120,8 +100,7 @@ let mockPassiveBackupStatus: ServicesStatus = {
                     relationship: 'server1',
                     primaryServer: {
                         age: 0,
-                        appId: 234,
-                        controlAddress: '192.0.2.1:8080',
+                        label: 'DHCPv4@localhost',
                         failoverTime: null,
                         id: 1,
                         inTouch: true,
@@ -142,34 +121,10 @@ export default {
     decorators: [
         applicationConfig({
             providers: [
-                importProvidersFrom(HttpClientModule),
-                importProvidersFrom(NoopAnimationsModule),
-                provideRouter([]),
+                provideHttpClient(withInterceptorsFromDi()),
                 ServicesService,
                 MessageService,
-            ],
-        }),
-        moduleMetadata({
-            imports: [
-                ButtonModule,
-                PanelModule,
-                TooltipModule,
-                MessageModule,
-                PopoverModule,
-                ProgressBarModule,
-                ProgressSpinnerModule,
-                RouterModule,
-                TableModule,
-                TagModule,
-                ToastModule,
-            ],
-            declarations: [
-                EntityLinkComponent,
-                HaStatusComponent,
-                HaStatusComponent,
-                HelpTipComponent,
-                LocaltimePipe,
-                PlaceholderPipe,
+                provideRouter([{ path: '**', component: HaStatusComponent }], withHashLocation()),
             ],
         }),
         toastDecorator,
@@ -177,14 +132,14 @@ export default {
     parameters: {
         mockData: [
             {
-                url: 'http://localhost/api/apps/123/services/status',
+                url: 'http://localhost/api/daemons/123/services/status',
                 method: 'GET',
                 status: 200,
                 delay: 200,
                 response: mockHubAndSpokeStatus,
             },
             {
-                url: 'http://localhost/api/apps/234/services/status',
+                url: 'http://localhost/api/daemons/234/services/status',
                 method: 'GET',
                 status: 200,
                 delay: 200,
@@ -198,14 +153,14 @@ type Story = StoryObj<HaStatusComponent>
 
 export const hubAndSpoke: Story = {
     args: {
-        appId: 123,
+        daemonId: 123,
         daemonName: 'dhcp4',
     },
 }
 
 export const passiveBackup: Story = {
     args: {
-        appId: 234,
+        daemonId: 234,
         daemonName: 'dhcp4',
     },
 }
