@@ -4,6 +4,13 @@ import { ServicesService } from '../backend/api/api'
 import { KeaHAServerStatus, ServiceStatus } from '../backend'
 import { MessageService } from 'primeng/api'
 import { datetimeToLocal, getErrorMessage } from '../utils'
+import { NgIf, NgFor, NgSwitch, NgSwitchCase, LowerCasePipe } from '@angular/common'
+import { Button } from 'primeng/button'
+import { ProgressBar } from 'primeng/progressbar'
+import { ProgressSpinner } from 'primeng/progressspinner'
+import { TableModule } from 'primeng/table'
+import { EntityLinkComponent } from '../entity-link/entity-link.component'
+import { HelpTipComponent } from '../help-tip/help-tip.component'
 
 /**
  * An interface representing HA table cell data.
@@ -13,8 +20,8 @@ import { datetimeToLocal, getErrorMessage } from '../utils'
  */
 interface RelationshipNodeCell {
     iconType?: string
-    appId?: number
-    appName?: string
+    daemonId?: number
+    daemonLabel?: string
     value?: string | number
     progress?: number
 }
@@ -55,9 +62,21 @@ type RelationshipNodeCellFunction = (serverStatus: KeaHAServerStatus) => Relatio
  */
 @Component({
     selector: 'app-ha-status',
-    standalone: false,
     templateUrl: './ha-status.component.html',
     styleUrls: ['./ha-status.component.sass'],
+    imports: [
+        NgIf,
+        TableModule,
+        Button,
+        NgFor,
+        EntityLinkComponent,
+        NgSwitch,
+        NgSwitchCase,
+        ProgressBar,
+        HelpTipComponent,
+        ProgressSpinner,
+        LowerCasePipe,
+    ],
 })
 export class HaStatusComponent implements OnInit, OnDestroy {
     /**
@@ -71,13 +90,13 @@ export class HaStatusComponent implements OnInit, OnDestroy {
     private readonly refreshInterval = 10
 
     /**
-     * ID of the Kea application for which the High Availability state
+     * ID of the Kea daemon for which the High Availability state
      * is presented.
      *
      * This should be id of one of the active Kea servers. The HA status
      * of this server and its partner (if it has any) is fetched and presented.
      */
-    @Input() appId: number
+    @Input() daemonId: number
 
     /**
      * A name of the Kea daemon for which the HA status is displayed.
@@ -154,7 +173,7 @@ export class HaStatusComponent implements OnInit, OnDestroy {
      * no local server status.
      */
     getLocalServerStatus(relationship: ServiceStatus): KeaHAServerStatus | null {
-        return relationship.status?.haServers?.primaryServer.appId === this.appId
+        return relationship.status?.haServers?.primaryServer.id === this.daemonId
             ? relationship.status?.haServers.primaryServer
             : relationship.status?.haServers.secondaryServer
     }
@@ -168,7 +187,7 @@ export class HaStatusComponent implements OnInit, OnDestroy {
      * no remote server status.
      */
     getRemoteServerStatus(relationship: ServiceStatus): KeaHAServerStatus | null {
-        return relationship.status?.haServers?.primaryServer.appId !== this.appId
+        return relationship.status?.haServers?.primaryServer.id !== this.daemonId
             ? relationship.status?.haServers.primaryServer
             : relationship.status?.haServers.secondaryServer
     }
@@ -203,8 +222,8 @@ export class HaStatusComponent implements OnInit, OnDestroy {
      * This function is invoked periodically to refresh the status.
      */
     private refreshStatus() {
-        // Get the services status for the app from the server.
-        lastValueFrom(this.servicesApi.getAppServicesStatus(this.appId))
+        // Get the services status for the daemon from the server.
+        lastValueFrom(this.servicesApi.getDaemonServicesStatus(this.daemonId))
             .then((data) => {
                 if (data.items) {
                     let status: RelationshipTableDataRow[] = []
@@ -236,11 +255,11 @@ export class HaStatusComponent implements OnInit, OnDestroy {
                                     let cell: RelationshipNodeCell = {
                                         value: s.role,
                                     }
-                                    // It only makes sense to add an app link if it is a remote
+                                    // It only makes sense to add a daemon link if it is a remote
                                     // server. The local server is currently displayed.
                                     if (index > 0) {
-                                        cell.appId = s.appId
-                                        cell.appName = `Kea@${s.controlAddress}`
+                                        cell.daemonId = s.id
+                                        cell.daemonLabel = s.label
                                     }
                                     return cell
                                 }),
@@ -332,7 +351,7 @@ export class HaStatusComponent implements OnInit, OnDestroy {
             .catch((err) => {
                 this.messageService.add({
                     severity: 'error',
-                    summary: `Failed to fetch the HA status for Kea application ID: ${this.appId}`,
+                    summary: `Failed to fetch the HA status for daemon ID: ${this.daemonId}`,
                     detail: getErrorMessage(err),
                 })
                 this.status = []
