@@ -1,18 +1,13 @@
 import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
 
 import { HelpTipComponent } from './help-tip.component'
-import { PopoverModule } from 'primeng/popover'
-import { ButtonModule } from 'primeng/button'
 
 describe('HelpTipComponent', () => {
     let component: HelpTipComponent
     let fixture: ComponentFixture<HelpTipComponent>
 
     beforeEach(waitForAsync(() => {
-        TestBed.configureTestingModule({
-            imports: [PopoverModule, ButtonModule],
-            declarations: [HelpTipComponent],
-        }).compileComponents()
+        TestBed.configureTestingModule({}).compileComponents()
     }))
 
     beforeEach(() => {
