@@ -8,6 +8,8 @@ import {
     Validators,
     ValidationErrors,
     UntypedFormControl,
+    FormsModule,
+    ReactiveFormsModule,
 } from '@angular/forms'
 import { MessageService, SelectItem } from 'primeng/api'
 import { map } from 'rxjs/operators'
@@ -30,6 +32,20 @@ import { getErrorMessage, stringToHex } from '../utils'
 import { SelectableClientClass } from '../forms/selectable-client-class'
 import { hasDifferentLocalHostData } from '../hosts'
 import { GenericFormService } from '../forms/generic-form.service'
+import { NgIf, NgFor, NgSwitch, NgSwitchCase, NgTemplateOutlet } from '@angular/common'
+import { RouterLink } from '@angular/router'
+import { Button } from 'primeng/button'
+import { Fieldset } from 'primeng/fieldset'
+import { FloatLabel } from 'primeng/floatlabel'
+import { InputNumber } from 'primeng/inputnumber'
+import { InputText } from 'primeng/inputtext'
+import { Message } from 'primeng/message'
+import { MultiSelect } from 'primeng/multiselect'
+import { Select } from 'primeng/select'
+import { ToggleSwitch } from 'primeng/toggleswitch'
+import { DhcpClientClassSetFormComponent } from '../dhcp-client-class-set-form/dhcp-client-class-set-form.component'
+import { DhcpOptionSetFormComponent } from '../dhcp-option-set-form/dhcp-option-set-form.component'
+import { HelpTipComponent } from '../help-tip/help-tip.component'
 
 /**
  * A form validator checking if a subnet has been selected for
@@ -174,9 +190,30 @@ export interface MappedHostBeginData {
  */
 @Component({
     selector: 'app-host-form',
-    standalone: false,
     templateUrl: './host-form.component.html',
     styleUrls: ['./host-form.component.sass'],
+    imports: [
+        NgIf,
+        FormsModule,
+        ReactiveFormsModule,
+        Fieldset,
+        ToggleSwitch,
+        FloatLabel,
+        MultiSelect,
+        Select,
+        InputText,
+        NgFor,
+        NgSwitch,
+        NgSwitchCase,
+        NgTemplateOutlet,
+        InputNumber,
+        Button,
+        RouterLink,
+        DhcpClientClassSetFormComponent,
+        DhcpOptionSetFormComponent,
+        HelpTipComponent,
+        Message,
+    ],
 })
 export class HostFormComponent implements OnInit, OnDestroy {
     /**
@@ -461,28 +498,15 @@ export class HostFormComponent implements OnInit, OnDestroy {
     /**
      * Processes and converts received data when new transaction is begun.
      *
-     * For each daemon, it generates a user friendly label by concatenating
-     * app name and daemon name. The list of friendly names is displayed in
-     * the dropdown where a user selects servers. Other data is returned with
-     * no change.
+     * The list of daemon labels is displayed in the dropdown where a user
+     * selects servers. Other data is returned with no change.
      *
      * @param data a response received as a result of beginning a transaction
      *             to create a new host or to update an existing host.
      * @returns processed data that includes friendly daemon names.
      */
     private _mapHostBeginData(data: CreateHostBeginResponse | UpdateHostBeginResponse): MappedHostBeginData {
-        const daemons: Array<SelectableDaemon> = []
-        for (const d of data.daemons) {
-            const daemon = {
-                id: d.id,
-                appId: d.app.id,
-                appType: 'kea',
-                name: d.name,
-                version: d.name,
-                label: `${d.app.name}/${d.name}`,
-            }
-            daemons.push(daemon)
-        }
+        const daemons = data.daemons as SelectableDaemon[]
         const clientClasses: Array<SelectableClientClass> = []
         for (const c of data.clientClasses) {
             clientClasses.push({
